import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useRef, useState } from "react";
import { Dialog, DialogBody, DialogContent, DialogFooter, DialogHeader, DialogTitle, DialogTrigger, } from "../../../dialog";
import { LeverageEditor } from "../sections/leverageEditor";
import Button from "../../../button";
import { useLeverage } from "@orderly.network/hooks";
import { toast } from "../../../toast";
import { useMarginRatio } from "@orderly.network/hooks";
import { Numeral } from "../../../text/numeral";
export const LeverageDialog = (props) => {
    const [open, setOpen] = useState(false);
    const { currentLeverage } = useMarginRatio();
    const [maxLeverage, { update, config: leverageLevers, isMutating }] = useLeverage();
    const nextLeverage = useRef(maxLeverage ?? 0);
    const onSave = (value) => {
        return Promise.resolve().then(() => {
            //   console.log("value", value);
            nextLeverage.current = value.leverage;
        });
    };
    const onSubmit = () => {
        if (nextLeverage.current === maxLeverage)
            return;
        update({ leverage: nextLeverage.current }).then((res) => {
            setOpen(false);
            toast.success("Leverage updated");
        }, (err) => {
            console.dir(err);
            toast.error(err.message);
        });
    };
    return (_jsxs(Dialog, { open: open, onOpenChange: setOpen, children: [_jsx(DialogTrigger, { asChild: true, children: props.children }), _jsxs(DialogContent, { onOpenAutoFocus: (e) => e.preventDefault(), closable: true, children: [_jsx(DialogHeader, { children: _jsx(DialogTitle, { children: "Account Leverage" }) }), _jsxs(DialogBody, { children: [_jsxs("div", { className: "orderly-flex orderly-text-base-contrast-54 orderly-py-5 desktop:orderly-text-xs", children: [_jsx("div", { className: "orderly-flex-1", children: "Max account leverage" }), _jsxs("div", { className: "orderly-flex orderly-gap-1", children: [_jsx("span", { children: "Current:" }), _jsx(Numeral, { className: "orderly-text-base-contrast", surfix: "x", children: currentLeverage })] })] }), _jsx("div", { className: "ordelry-my-5 orderly-h-[80px]", children: _jsx(LeverageEditor, { maxLeverage: maxLeverage, leverageLevers: leverageLevers, onSave: onSave }) })] }), _jsxs(DialogFooter, { children: [_jsx(Button, { fullWidth: true, color: "tertiary", onClick: () => {
                                    setOpen(false);
                                }, children: "Cancel" }), _jsx(Button, { fullWidth: true, onClick: () => onSubmit(), loading: isMutating, children: "Save" })] })] })] }));
};
//# sourceMappingURL=leverageDialog.js.map