import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useCallback, useContext, useMemo, useState, } from "react";
import { WalletConnectButton } from "../sections/walletConnectButton";
import { AccountStatusEnum } from "@orderly.network/types";
import { useAccount, useChains, useWalletConnector, } from "@orderly.network/hooks";
import { DropdownMenu, DropdownMenuContent, DropdownMenuTrigger, } from "@radix-ui/react-dropdown-menu";
import { Blockie } from "../../../avatar";
import { Text } from "../../../text";
import { toast } from "../../../toast";
import { Tooltip, TooltipArrow, TooltipContent, TooltipTrigger, } from "@radix-ui/react-tooltip";
import { Divider } from "../../../divider";
import { OrderlyAppContext } from "@orderly.network/react";
import { isTestnet } from "@orderly.network/utils";
import { CopyDesktopIcon, DisconnectIcon, ShareIcon } from "../../../icon";
import { cn } from "../../../utils";
const IconTooltip = (props) => (_jsxs(Tooltip, { children: [_jsx(TooltipTrigger, { children: props.trigger }), _jsxs(TooltipContent, { align: "center", className: "data-[state=delayed-open]:data-[side=top]:orderly-animate-slideDownAndFade data-[state=delayed-open]:data-[side=right]:orderly-animate-slideLeftAndFade data-[state=delayed-open]:data-[side=left]:orderly-animate-slideRightAndFade data-[state=delayed-open]:data-[side=bottom]:orderly-animate-slideUpAndFade orderly-text-base-contrast orderly-select-none orderly-rounded orderly-bg-base-400 orderly-px-[15px] orderly-py-[10px] orderly-text-3xs orderly-leading-none orderly-shadow-[hsl(206_22%_7%_/_35%)_0px_10px_38px_-10px,_hsl(206_22%_7%_/_20%)_0px_10px_20px_-15px] orderly-will-change-[transform,opacity]", children: [props.tooltipContent, _jsx(TooltipArrow, { className: "orderly-fill-base-400" })] })] }));
const MenuItem = (props) => (_jsxs("div", { className: cn("orderly-flex orderly-cursor-pointer orderly-items-center orderly-w-full orderly-fill-base-contrast-36 orderly-text-base-contrast-36 hover:orderly-fill-base-contrast hover:orderly-text-base-contrast orderly-py-4", props.className), onClick: props.onClick, children: [props.icon, _jsx("span", { className: "orderly-text-xs orderly-pl-2 orderly-font-semibold", children: props.title })] }));
export const DesktopWalletConnnectButton = (props) => {
    const { status = AccountStatusEnum.NotConnected, dropMenuItem, onClickDropMenuItem, } = props;
    const { account, state } = useAccount();
    const [open, setOpen] = useState(false);
    // @ts-ignore
    const { onWalletDisconnect } = useContext(OrderlyAppContext);
    const { connectedChain } = useWalletConnector();
    const [allChains] = useChains(undefined, {
        pick: "network_infos",
        filter: (chain) => chain.network_infos?.bridge_enable || chain.network_infos?.bridgeless,
        // filter: (chain: API.Chain) => isTestnet(chain.network_infos?.chain_id),
    });
    const chains = useMemo(() => {
        if (Array.isArray(allChains))
            return allChains;
        if (allChains === undefined)
            return [];
        // @ts-ignore
        if (connectedChain && isTestnet(parseInt(connectedChain.id))) {
            return allChains.testnet ?? [];
        }
        return allChains.mainnet;
    }, [allChains, connectedChain]);
    const onCopy = useCallback(() => {
        navigator.clipboard.writeText(state.address).then(() => {
            toast.success("Copied to clipboard");
            setOpen(false);
        });
    }, [state]);
    const onOpenExploer = useCallback(() => {
        const chainInfo = chains.find((item) => item.chain_id === account.chainId);
        if (chainInfo) {
            // @ts-ignore
            const { explorer_base_url } = chainInfo;
            if (explorer_base_url) {
                if (explorer_base_url.endsWith("/")) {
                    window.open(`${explorer_base_url}address/${account.address}`);
                }
                else {
                    window.open(`${explorer_base_url}/address/${account.address}`);
                }
            }
        }
        setOpen(false);
    }, [state, connectedChain]);
    const customsMenuItems = useMemo(() => {
        if (Array.isArray(props.dropMenuItem)) {
            return props.dropMenuItem.map((item) => {
                return (_jsxs("div", { children: [_jsx(MenuItem, { icon: item.icon, title: item.title, className: item.className, onClick: () => {
                                item.onClick?.();
                                onClickDropMenuItem?.(item);
                            } }), _jsx(Divider, {})] }, item.key || item.title));
            });
        }
        return (_jsx(_Fragment, { children: props.dropMenuItem }));
    }, [props.dropMenuItem, props.onClickDropMenuItem]);
    return (_jsxs(DropdownMenu, { open: state.address ? open : false, onOpenChange: state.address ? setOpen : undefined, children: [_jsx(DropdownMenuTrigger, { children: _jsx("div", { className: "orderly-h-[48px] orderly-flex orderly-items-center", children: _jsx(WalletConnectButton, { status: status, address: props.address, className: "orderly-rounded-full", onConnect: props.onConnect }) }) }), _jsxs(DropdownMenuContent, { align: "end", className: "orderly-bg-base-800 orderly-w-[220px] orderly-px-4 orderly-rounded-borderRadius orderly-shadow-[0px_12px_20px_0px_rgba(0,0,0,0.25)] orderly-z-20", alignOffset: 10, onCloseAutoFocus: (e) => e.preventDefault(), children: [_jsxs("div", { className: "orderly-flex  orderly-gap-3 orderly-py-5", children: [_jsxs("div", { className: "orderly-flex-1 orderly-flex orderly-items-center", children: [_jsx(Blockie, { address: state.address }), _jsx(Text, { className: "orderly-text-xs orderly-text-base-contrast-80 orderly-ml-2", rule: "address", children: account.address })] }), _jsx(IconTooltip, { trigger: _jsx(CopyDesktopIcon, { onClick: onCopy, size: 20, className: "orderly-text-base-contrast-36 hover:orderly-text-base-contrast" }), tooltipContent: "Copy address" }), _jsx(IconTooltip, { trigger: _jsx(ShareIcon, { onClick: onOpenExploer, size: 20, className: "orderly-text-base-contrast-36 hover:orderly-text-base-contrast" }), tooltipContent: "View in block explorer" })] }), customsMenuItems, _jsx(MenuItem, { icon: _jsx(DisconnectIcon, { size: 24 }), title: "Disconnect", className: "hover:orderly-fill-danger-light hover:orderly-text-danger-light", onClick: () => {
                            setOpen(false);
                            onWalletDisconnect?.();
                        } })] })] }));
};
//# sourceMappingURL=walletConnectButton.desktop.js.map