import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Blockie } from "../../../avatar";
import Button, { IconButton } from "../../../button";
import { useCallback } from "react";
import { Text } from "../../../text";
import { useAccount, useMutation, useConfig } from "@orderly.network/hooks";
import { toast } from "../../../toast";
import { modal } from "../../../modal";
import { AccountStatusEnum } from "@orderly.network/types";
import { WalletConnectSheet } from "../../../block/walletConnect";
import { CopyIcon } from "../../../icon";
import { useGetChains } from "./useGetChains";
export const AccountInfo = (props) => {
    const { onDisconnect } = props;
    const { account, state } = useAccount();
    // const [loading,setLoading] = React.useState(false);
    const config = useConfig();
    const [getTestUSDC, { isMutating }] = useMutation(`${config.get("operatorUrl")}/v1/faucet/usdc`);
    const chainName = useGetChains();
    const onCopy = useCallback(() => {
        navigator.clipboard.writeText(state.address).then(() => {
            toast.success("Copied to clipboard");
        });
    }, [state]);
    const onGetClick = useCallback(() => {
        if (state.status < AccountStatusEnum.EnableTrading) {
            return modal.show(WalletConnectSheet, {
                status: state.status,
            });
        }
        return getTestUSDC({
            chain_id: account.wallet?.chainId.toString(),
            user_address: state.address,
            broker_id: config.get("brokerId"),
        }).then((res) => {
            if (res.success) {
                props.close?.();
                return modal.confirm({
                    title: "Get test USDC",
                    content: "1,000 USDC will be added to your balance. Please note this may take up to 3 minutes. Please check back later.",
                    onOk: () => {
                        return Promise.resolve();
                    },
                });
            }
            res.message && toast.error(res.message);
            // return Promise.reject(res);
        }, (error) => {
            toast.error(error.message);
        });
    }, [state]);
    return (_jsxs("div", { id: "orderly-account-info", children: [_jsxs("div", { className: "orderly-flex orderly-py-6", children: [_jsxs("div", { className: "orderly-flex-1 orderly-flex orderly-items-center orderly-gap-2", children: [_jsx(Blockie, { address: state.address }), _jsxs("div", { className: "orderly-flex orderly-flex-col", children: [_jsx(Text, { className: "orderly-text-xs", rule: "address", children: account.address }), _jsx("div", { className: "orderly-text-4xs orderly-text-base-contrast-80", children: chainName })] })] }), _jsx("div", { className: "orderly-flex orderly-items-center orderly-gap-2", children: _jsx(IconButton, { type: "button", onClick: onCopy, className: "orderly-px-0", children: _jsx(CopyIcon, { size: 40 }) }) })] }), props.showGetTestUSDC ? (_jsxs("div", { className: "orderly-py-4 orderly-grid orderly-grid-cols-2 orderly-gap-3", children: [_jsx(Button, { variant: "outlined", onClick: onGetClick, disabled: isMutating, loading: isMutating, className: "orderly-text-xs orderly-text-primary orderly-font-bold orderly-border-primary hover:orderly-bg-transparent hover:orderly-text-primary-light", children: "Get test USDC" }), _jsx(Button, { variant: "outlined", color: "danger", fullWidth: true, className: "orderly-text-xs orderly-font-bold orderly-text-danger-light orderly-border-danger-light hover:orderly-bg-transparent hover:orderly-text-danger-light", onClick: () => {
                            onDisconnect?.();
                        }, children: "Disconnect" })] })) : (_jsx("div", { className: "orderly-flex orderly-justify-center", children: _jsx(Button, { variant: "outlined", color: "danger", fullWidth: true, className: "orderly-text-xs orderly-font-bold orderly-text-danger-light orderly-border-danger-light hover:orderly-bg-transparent hover:orderly-text-danger-light", onClick: () => {
                        onDisconnect?.();
                    }, children: "Disconnect" }) }))] }));
};
//# sourceMappingURL=accountInfo.js.map