import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { SymbolContext } from "../../provider";
import { Statistic } from "../../statistic";
import { Tag } from "../../tag";
import { Text } from "../../text";
import { upperCaseFirstLetter } from "../../utils/string";
import { OrderSide, OrderType } from "@orderly.network/types";
import { useContext, useMemo } from "react";
export const Cell = (props) => {
    const { item } = props;
    const { quote, quote_dp, base, base_dp } = useContext(SymbolContext);
    const typeTag = useMemo(() => {
        if (item.side === OrderSide.SELL) {
            return (_jsx(Tag, { color: "sell", size: "small", children: "Sell" }));
        }
        return (_jsx(Tag, { color: "buy", size: "small", children: "Buy" }));
    }, [item]);
    const onSymbol = () => {
        props.onSymbolChange?.({ symbol: item.symbol });
        // go to the top of page
        window.scrollTo(0, 0);
    };
    const state = useMemo(() => {
        const status = item.status || item.algo_status;
        if (status === "NEW") {
            return upperCaseFirstLetter("pending");
        }
        return upperCaseFirstLetter(status);
    }, [
        item.status,
        item.algo_status
    ]);
    return (_jsxs("div", { className: "orderly-p-4", children: [_jsxs("div", { className: "orderly-flex orderly-justify-between orderly-items-center", children: [_jsxs("div", { className: "orderly-flex-1 orderly-flex orderly-items-center", children: [typeTag, _jsx("div", { className: "orderly-px-2 orderly-text-2xs", onClick: onSymbol, children: _jsx(Text, { rule: "symbol", children: item.symbol }) })] }), _jsx("div", { className: "orderly-text-4xs orderly-text-base-contrast-36", children: _jsx(Text, { rule: "date", children: item.created_time }) })] }), _jsxs("div", { className: "orderly-grid orderly-grid-cols-3 orderly-gap-2", children: [_jsx(Statistic, { label: "Qty.", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs", value: item.quantity ?? "-", rule: "price", precision: base_dp, className: item.side === OrderSide.BUY
                            ? "orderly-text-trade-profit"
                            : "orderly-text-trade-loss" }), _jsx(Statistic, { label: "Filled", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", 
                        // @ts-ignore
                        value: item.total_executed_quantity ?? "-", rule: "price", precision: base_dp }), _jsx(Statistic, { label: "Status", rule: "status", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", value: state, align: "right" }), _jsx(Statistic, { label: _jsx(_Fragment, { children: _jsx("span", { className: "orderly-text-base-contrast-36", children: "Avg. price" }) }), labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", rule: "price", precision: quote_dp, value: item.average_executed_price ?? "-" }), _jsx(Statistic, { labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", label: _jsx(_Fragment, { children: _jsx("span", { className: "orderly-text-base-contrast-36", children: "Order price" }) }), value: item.type === OrderType.MARKET ? "Market" : item.price }), _jsx(Statistic, { labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", label: _jsx(_Fragment, { children: _jsx("span", { className: "orderly-text-base-contrast-36", children: "Trigger price" }) }), value: item.type === OrderType.MARKET ||
                            item.type === OrderType.STOP_MARKET
                            ? "Market"
                            : item.trigger_price, align: "right" })] })] }));
};
//# sourceMappingURL=cell.js.map