import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Spinner } from "../../spinner";
import { Numeral } from "../../text";
import { usePrivateQuery, useSymbolsInfo } from "@orderly.network/hooks";
import { Decimal, timestampToString } from "@orderly.network/utils";
import { useMemo } from "react";
export const OrderTrades = (props) => {
    const { record, index } = props;
    const path = record.algo_order_id !== undefined
        ? `/v1/algo/order/${record.algo_order_id}/trades`
        : `/v1/order/${record.order_id}/trades`;
    const { data } = usePrivateQuery(path);
    const base = record?.symbol?.split("_")?.[1] || "";
    const config = useSymbolsInfo();
    if (config.isNil)
        return null;
    const symbolInfo = config[record.symbol];
    const baseDp = symbolInfo("quote_dp", 2);
    const body = useMemo(() => {
        if (data === undefined) {
            return (_jsx("tr", { children: _jsx("td", { colSpan: 5, children: _jsxs("div", { className: "orderly-flex orderly-h-[27.5px]", children: [_jsx("div", { className: "orderly-flex-1" }), _jsx(Spinner, { size: "small", className: "orderly-block" }), _jsx("div", { className: "orderly-flex-1" })] }) }) }));
        }
        if (data.length === 0) {
            return (_jsxs("tr", { className: "orderly-text-base-contrast-54", children: [_jsx("td", { className: "orderly-py-1", children: "-" }), _jsx("td", { className: "orderly-py-1", children: "-" }), _jsx("td", { className: "orderly-py-1", children: "-" }), _jsx("td", { className: "orderly-py-1", children: "-" }), _jsx("td", { className: "orderly-py-1", children: "-" })] }));
        }
        return data.map((item) => {
            const data = timestampToString(item.executed_timestamp);
            const price = item.executed_price;
            const qty = item.executed_quantity;
            const total = new Decimal(price).mul(qty).toNumber();
            return (_jsxs("tr", { className: "orderly-text-base-contrast-54", children: [_jsx("td", { className: "orderly-py-1", children: item.id }), _jsx("td", { className: "orderly-py-1", children: data }), _jsx("td", { className: "orderly-py-1", children: _jsx(Numeral, { precision: baseDp, children: price }) }), _jsx("td", { className: "orderly-py-1", children: _jsx(Numeral, { precision: baseDp, children: qty }) }), _jsx("td", { className: "orderly-py-1", children: _jsx(Numeral, { precision: baseDp, children: total }) })] }));
        });
    }, [data]);
    return (_jsx("div", { className: "orderly-flex orderly-min-h-[50px] orderly-pb-1 orderly-max-h-[266px] orderly-overflow-auto", children: _jsxs("table", { className: "orderly-w-full orderly-mx-6 orderly-text-2xs", children: [_jsx("thead", { className: "orderly-py-2 orderly-text-left orderly-text-base-contrast-36 orderly-sticky", children: _jsxs("tr", { className: "orderly-bg-base-700", children: [_jsx("th", { className: "orderly-w-1/5 orderly-pt-2 orderly-bg-base-700 orderly-sticky orderly-top-0", children: "Transaction ID" }), _jsx("th", { className: "orderly-w-1/5 orderly-pt-2 orderly-bg-base-700 orderly-sticky orderly-top-0", children: "Date" }), _jsx("th", { className: "orderly-w-1/5 orderly-pt-2 orderly-bg-base-700 orderly-sticky orderly-top-0", children: "Price (USDC)" }), _jsx("th", { className: "orderly-w-1/5 orderly-pt-2 orderly-bg-base-700 orderly-sticky orderly-top-0", children: `Qty (${base})` }), _jsx("th", { className: "orderly-w-1/5 orderly-pt-2 orderly-bg-base-700 orderly-sticky orderly-top-0", children: "Total (USDC)" })] }) }), _jsx("tbody", { children: body })] }) }));
};
//# sourceMappingURL=orderTrades.js.map