import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useCallback, useContext, useMemo, useState } from "react";
import { DesktopOrderBookCell } from "./cell.desktop";
import { OrderBookContext } from "../orderContext";
import { OrderBookCellType } from "../types";
import { Tooltip, TooltipArrow, TooltipContent, TooltipTrigger } from "@radix-ui/react-tooltip";
import { SymbolContext } from "../../../provider";
import { Numeral } from "../../../text";
export const DesktopListBox = (props) => {
    const { data, type } = props;
    const { depth } = useContext(OrderBookContext);
    const { base, quote, base_dp, quote_dp } = useContext(SymbolContext);
    const findMaxItem = useCallback(() => {
        if ((data?.length || 0) === 0) {
            return null;
        }
        if (type === OrderBookCellType.ASK) {
            const index = data.findIndex((item) => !Number.isNaN(item[0]));
            if (index != -1) {
                return data[index];
            }
            return null;
        }
        else {
            for (let index = data.length - 1; index >= 0; index--) {
                const item = data[index];
                if (!Number.isNaN(item[0])) {
                    return item;
                }
            }
            return null;
        }
    }, [data, type]);
    const priceDp = useMemo(() => {
        if (depth?.toString().includes(".")) {
            return depth.toString().split(".")[1].length;
        }
        return 0;
    }, [depth]);
    const maxQty = useMemo(() => {
        return data.reduce((a, b) => Math.max(a, b[1]), 0);
    }, [data]);
    const [hoverIndex, setHoverIndex] = useState(-1);
    return _jsx("div", { id: "orderly-order-book-list", className: "orderly-flex orderly-flex-col orderly-gap-[1px]", children: data.map((item, index) => {
            return (_jsx(Tip, { index: index, item: item, countQty: props.countQty, setHoverIndex: setHoverIndex, hoverIndex: hoverIndex, type: type, maxQty: maxQty, base: base, quote: quote, priceDp: priceDp, baseDp: base_dp, quoteDp: quote_dp, findMaxItem: findMaxItem }, index));
        }) });
};
const Tip = (props) => {
    const { index, item, setHoverIndex, type, maxQty, hoverIndex, base, quote, priceDp, baseDp, quoteDp } = props;
    const isHover = hoverIndex !== -1 ? (type === OrderBookCellType.ASK ?
        index >= hoverIndex :
        index <= hoverIndex) : false;
    const [open, setOpen] = useState(false);
    const calcHintInfo = (item) => {
        if (item === null) {
            return {
                sumQty: 0,
                sumQtyAmount: 0,
                avgPrice: 0,
            };
        }
        let totalInfo = { sumQty: 0, sumQtyAmount: 0 };
        if (!Number.isNaN(item[2])) {
            totalInfo = {
                sumQty: item[2],
                sumQtyAmount: item[3]
            };
        }
        return {
            ...totalInfo,
            avgPrice: totalInfo.sumQtyAmount == 0 ? 0 : totalInfo.sumQtyAmount / totalInfo.sumQty
        };
    };
    let hintInfo = calcHintInfo(item);
    if (hintInfo.avgPrice === 0) {
        hintInfo = calcHintInfo(props.findMaxItem());
    }
    return (_jsxs(Tooltip, { open: open, onOpenChange: setOpen, children: [_jsx(TooltipTrigger, { children: _jsx(DesktopOrderBookCell, { background: "", price: item[0], quantity: item[1], accumulated: item[2], count: props.countQty, type: props.type, accumulatedAmount: item[3], maxQty: maxQty, isHover: isHover, onMouseEnter: () => {
                        setHoverIndex(index);
                        setOpen(true);
                    }, onMouseLeave: () => {
                        setHoverIndex(-1);
                        setOpen(false);
                    } }) }), _jsxs(TooltipContent, { className: "orderly-max-w-[400px] orderly-w-full orderly-text-3xs orderly-shadow-md orderly-rounded orderly-p-3 orderly-bg-base-700 orderly-animate-in orderly-fade-in-0 orderly-zoom-in-95 data-[state=closed]:orderly-animate-out data-[state=closed]:orderly-fade-out-0 data-[state=closed]:orderly-zoom-out-95 data-[side=bottom]:orderly-slide-in-from-top-2 data-[side=left]:orderly-slide-in-from-right-2 data-[side=right]:orderly-slide-in-from-left-2 data-[side=top]:orderly-slide-in-from-bottom-2", align: "center", side: "left", sideOffset: 12, onPointerEnter: (e) => e.preventDefault(), children: [_jsx(Row, { title: "Avg. Price\u2248", content: hintInfo.avgPrice, contentDp: priceDp }), _jsx(Row, { title: `Sum (${base})`, content: hintInfo.sumQty, contentDp: baseDp }), _jsx(Row, { title: `Sum (${quote})`, content: hintInfo.sumQtyAmount, contentDp: quoteDp }), _jsx(TooltipArrow, { className: "orderly-fill-base-700" })] })] }));
};
const Row = (props) => {
    const { title, content, contentDp } = props;
    return (_jsxs("div", { className: "orderly-flex orderly-flex-row orderly-justify-between orderly-gap-4", children: [_jsx("div", { className: "orderly-text-base-contrast-36", children: title }), _jsx("div", { className: "orderly-text-right", children: _jsx(Numeral, { precision: contentDp, children: content }) })] }));
};
//# sourceMappingURL=listBox.desktop.js.map