import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import Button from "../../button";
import { Statistic } from "../../statistic";
import { Tag } from "../../tag";
import { useCallback, useContext, useMemo, useState } from "react";
import { OrderSide } from "@orderly.network/types";
import { Text } from "../../text";
import { NumeralTotal } from "../../text/numeralTotal";
import { OrderListContext } from "./shared/orderListContext";
import { SymbolContext } from "../../provider";
export const OrderCell = (props) => {
    const { order } = props;
    const [loading, setLoading] = useState(false);
    const { onCancelOrder, onEditOrder } = useContext(OrderListContext);
    const { quote, quote_dp, base, base_dp } = useContext(SymbolContext);
    const isAlgoOrder = order?.algo_order_id !== undefined;
    // console.log("price node", order);
    const isStopMarket = order?.type === "MARKET" && isAlgoOrder;
    const typeTag = useMemo(() => {
        return (_jsx(Tag, { color: order.side === "BUY" ? "buy" : "sell", size: "small", children: order.side === "BUY" ? "Buy" : "Sell" }));
    }, [order]);
    const cancelOrder = useCallback(() => {
        if (loading)
            return;
        setLoading(true);
        onCancelOrder(order).finally(() => setLoading(false));
    }, [loading, order]);
    const onSymbol = () => {
        props.onSymbolChange?.({ symbol: order.symbol });
        // go to the top of page
        window.scrollTo(0, 0);
    };
    return (_jsxs("div", { className: "orderly-px-4 orderly-py-2", children: [_jsxs("div", { className: "orderly-flex orderly-items-center orderly-gap-2 orderly-mb-1", children: [typeTag, _jsx("div", { className: "orderly-flex-1 orderly-text-2xs", onClick: onSymbol, children: _jsx(Text, { rule: "symbol", children: order.symbol }) }), _jsx("div", { className: "orderly-text-4xs orderly-text-base-contrast-36", children: _jsx(Text, { rule: "date", children: order.created_time }) })] }), _jsxs("div", { className: "orderly-grid orderly-grid-cols-3 orderly-gap-2", children: [_jsx(Statistic, { label: "Qty.", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", value: order.quantity ?? "-", precision: base_dp, rule: "price", valueClassName: order.side === OrderSide.BUY
                            ? "orderly-text-trade-profit orderly-text-3xs"
                            : "orderly-text-trade-loss orderly-text-3xs" }), _jsx(Statistic, { label: "Filled", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", 
                        // @ts-ignore
                        value: order.total_executed_quantity ?? "-", rule: "price", precision: base_dp }), _jsx(Statistic, { label: _jsxs(_Fragment, { children: [_jsx("span", { className: "orderly-text-base-contrast-36", children: "Est. total" }), _jsx("span", { className: "orderly-text-base-contrast-20", children: "(USDC)" })] }), labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", value: _jsx(NumeralTotal, { price: props.order.price ?? 1, quantity: props.order.quantity, precision: quote_dp }), align: "right" }), _jsx(Statistic, { label: _jsx(_Fragment, { children: _jsx("span", { className: "orderly-text-base-contrast-36", children: "Trigger price" }) }), labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", rule: "price", precision: quote_dp, value: order.trigger_price }), _jsx(Statistic, { label: _jsx(_Fragment, { children: _jsx("span", { className: "orderly-text-base-contrast-36", children: "Limit price" }) }), labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", value: isStopMarket ? _jsx("span", { children: "Market" }) : order.price ?? "-", rule: "price", precision: quote_dp }), _jsx(Statistic, { label: _jsx(_Fragment, { children: _jsx("span", { className: "orderly-text-base-contrast-36", children: "Mark price" }) }), labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", rule: "price", precision: quote_dp, value: order.mark_price, align: "right" })] }), _jsxs("div", { className: "orderly-flex orderly-gap-3 orderly-text-4xs orderly-justify-end orderly-mt-2", children: [_jsx(Button, { id: "orderly-pending-cell-edit-button", variant: "outlined", size: "small", color: "tertiary", className: "orderly-w-[120px] orderly-text-4xs", onClick: () => onEditOrder(order), children: "Edit" }), _jsx(Button, { id: "orderly-pending-cell-cancel-button", variant: "outlined", color: "tertiary", size: "small", className: "orderly-w-[120px] orderly-text-4xs", loading: loading, onClick: cancelOrder, children: "Cancel" })] })] }));
};
//# sourceMappingURL=cell.js.map