import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useMemo, useRef } from "react";
import { Table } from "../../../table";
import { Numeral, Text } from "../../../text";
import { OrderStatus, OrderSide } from "@orderly.network/types";
import { cx } from "class-variance-authority";
import { upperCaseFirstLetter } from "../../../utils/string";
import { SymbolProvider } from "../../../provider";
import { CancelButton } from "./cancelButton";
import { OrderQuantity } from "./quantity";
import { Price } from "./price";
import { EndReachedBox } from "../../../listView/endReachedBox";
import { cn } from "../../../utils/css";
import { columnsBasis } from "../columnsUtil";
import { OrderTrades } from "../../../block/orderHistory/orderTrades";
import { TriggerPrice } from "./triggerPrice";
import { OrdersEmptyView } from "./ordersEmptyView";
export const Listview = (props) => {
    const columns = useMemo(() => {
        // const columns = columnsBasis();
        if (props.status === OrderStatus.INCOMPLETE) {
            const columns = [
                {
                    title: "Instrument",
                    dataIndex: "symbol",
                    className: "orderly-h-[48px]",
                    width: 120,
                    onSort: props.status === OrderStatus.INCOMPLETE
                        ? (r1, r2, sortOrder) => {
                            if (sortOrder === "asc") {
                                return r1.symbol.localeCompare(r2.symbol);
                            }
                            return r2.symbol.localeCompare(r1.symbol);
                        }
                        : undefined,
                    render: (value) => (_jsx(Text, { rule: "symbol", className: "orderly-font-semibold", onClick: (e) => {
                            props.onSymbolChange?.({ symbol: value });
                            e.stopPropagation();
                            e.preventDefault();
                        }, children: value })),
                },
                {
                    title: "Type",
                    width: 100,
                    className: "orderly-h-[48px] orderly-font-semibold",
                    dataIndex: "type",
                    formatter: (value, record) => {
                        const type = typeof record.type === "string"
                            ? record.type.replace("_ORDER", "").toLowerCase()
                            : record.type;
                        if (record.algo_order_id) {
                            return `Stop ${type}`;
                        }
                        return upperCaseFirstLetter(value);
                    },
                },
                {
                    title: "Side",
                    width: 100,
                    className: "orderly-h-[48px]",
                    dataIndex: "side",
                    onSort: props.status === OrderStatus.INCOMPLETE
                        ? (r1, r2, sortOrder) => {
                            if (sortOrder === "asc") {
                                return r2.side.localeCompare(r1.side);
                            }
                            return r1.side.localeCompare(r2.side);
                        }
                        : undefined,
                    render: (value) => (_jsx("span", { className: cx("orderly-font-semibold", value === OrderSide.BUY
                            ? "orderly-text-trade-profit"
                            : "orderly-text-trade-loss"), children: upperCaseFirstLetter(value) })),
                },
                {
                    title: "Filled / Quantity",
                    className: "orderly-h-[48px] orderly-ui-pending-list-input-container orderly-ui-pending-list-quantity-input-container",
                    dataIndex: "quantity",
                    width: 120,
                    onSort: props.status === OrderStatus.INCOMPLETE,
                    render: (value, record) => (_jsx(OrderQuantity, { order: record })),
                },
                {
                    title: "Price",
                    className: "orderly-h-[48px] orderly-ui-pending-list-input-container rderly-ui-pending-list-price-input-container",
                    dataIndex: "price",
                    width: 120,
                    onSort: props.status === OrderStatus.INCOMPLETE,
                    render: (value, record) => _jsx(Price, { order: record }),
                },
                {
                    title: "Trigger",
                    className: "orderly-h-[48px] orderly-ui-pending-list-input-container orderly-ui-pending-list-trigger-input-container",
                    dataIndex: "trigger_price",
                    width: 120,
                    // onSort: props.status === OrderStatus.INCOMPLETE,
                    render: (value, record) => (_jsx(TriggerPrice, { order: record })),
                },
                {
                    title: "Est. total",
                    width: 100,
                    className: "orderly-h-[48px] orderly-font-semibold",
                    dataIndex: "executed",
                    render: (value, record) => {
                        return (_jsx(Numeral, { className: "orderly-font-semibold orderly-text-2xs orderly-text-base-contrast-80", precision: 2, children: record.quantity === 0 ||
                                Number.isNaN(record.price) ||
                                record.price === null
                                ? "--"
                                : `${record.quantity * record.price}` }));
                    },
                },
                {
                    title: "Reduce",
                    dataIndex: "reduce_only",
                    width: 100,
                    className: "orderly-h-[48px] orderly-font-semibold",
                    render: (value) => {
                        return _jsx("span", { children: value ? "Yes" : "No" });
                    },
                },
                {
                    title: "Hidden",
                    dataIndex: "visible",
                    width: 100,
                    className: "orderly-h-[48px] orderly-font-semibold",
                    render: (value, record) => {
                        // @ts-ignore
                        return _jsx("span", { children: record.visible_quantity !== 0 ? "No" : "Yes" });
                    },
                },
                {
                    title: "Order time",
                    dataIndex: "created_time",
                    width: 150,
                    onSort: props.status === OrderStatus.INCOMPLETE,
                    className: "orderly-h-[48px]",
                    render: (value) => (_jsx(Text, { rule: "date", className: "orderly-break-normal orderly-whitespace-nowrap orderly-font-semibold", children: value })),
                },
                {
                    title: "",
                    dataIndex: "action",
                    className: "orderly-h-[48px]",
                    align: "right",
                    fixed: "right",
                    width: 100,
                    render: (_, record) => {
                        if (props.status === OrderStatus.INCOMPLETE) {
                            return _jsx(CancelButton, { order: record });
                        }
                        return null;
                    },
                },
            ];
            // columns.push();
            return columns;
        }
        else {
            return columnsBasis({
                status: props.status,
                onSymbolChange: props.onSymbolChange,
            });
        }
    }, [props.status]);
    const divRef = useRef(null);
    return (_jsx("div", { ref: divRef, className: "orderly-h-full orderly-overflow-y-auto", children: _jsxs(EndReachedBox, { onEndReached: () => {
                if (!props.loading) {
                    props.loadMore?.();
                }
            }, children: [_jsx(Table, { bordered: true, justified: true, showMaskElement: false, columns: columns, dataSource: props.dataSource, headerClassName: "orderly-text-2xs orderly-text-base-contrast-54 orderly-py-3 orderly-bg-base-900", className: cn("orderly-text-2xs orderly-text-base-contrast-80", props.className), generatedRowKey: (record, index) => `${index}${record.order_id || record.algo_order_id}`, renderRowContainer: (record, index, children) => {
                        return (_jsx(SymbolProvider, { symbol: record.symbol, children: children }, index));
                    }, expandRowRender: props.status === "FILLED"
                        ? (record, index) => {
                            return _jsx(OrderTrades, { record: record, index: index });
                        }
                        : undefined }), (!props.dataSource || props.dataSource.length <= 0) && (_jsx(OrdersEmptyView, { watchRef: divRef, left: 0, right: props.status === OrderStatus.INCOMPLETE ? 100 : 120 }))] }) }));
};
//# sourceMappingURL=listview.js.map