import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import Button from "../../../button";
import { Popover, PopoverAnchor, PopoverContent } from "../../../popover";
import { useSymbolContext } from "../../../provider/symbolProvider";
import { cn } from "../../../utils/css";
import { commify } from "@orderly.network/utils";
import { Check, X } from "lucide-react";
import { useContext, useEffect, useRef, useState } from "react";
import { OrderListContext } from "../shared/orderListContext";
import { toast } from "../../../toast";
import { Divider } from "../../../divider";
import { cleanStringStyle, useEventEmitter } from "@orderly.network/hooks";
import { Input } from "../../../input";
export const TriggerPrice = (props) => {
    const { order } = props;
    const [price, setPrice] = useState("");
    useEffect(() => {
        setPrice(order.trigger_price?.toString() ?? "0");
    }, [order.trigger_price]);
    const isAlgoOrder = order?.algo_order_id !== undefined;
    const [open, setOpen] = useState(0);
    const [editting, setEditting] = useState(false);
    if (!isAlgoOrder) {
        return _jsx("div", { children: "-" });
    }
    if (!editting && open <= 0) {
        return _jsx(NormalState, { order: order, price: price, setEditing: setEditting });
    }
    return (_jsx(EditingState, { order: order, price: price, setPrice: setPrice, editting: editting, setEditting: setEditting, open: open, setOpen: setOpen }));
};
const NormalState = (props) => {
    const { order, price } = props;
    return (_jsx("div", { className: cn("orderly-flex orderly-max-w-[110px] orderly-justify-start orderly-items-center orderly-gap-1 orderly-relative orderly-font-semibold"), onClick: (e) => {
            e.stopPropagation();
            e.preventDefault();
            props.setEditing(true);
        }, children: _jsx("div", { className: "orderly-px-2 orderly-flex orderly-min-w-[70px] orderly-items-center orderly-h-[28px] orderly-bg-base-700 orderly-text-2xs orderly-font-semibold orderly-rounded-lg", children: price }) }));
};
const EditingState = (props) => {
    const { order, price, setPrice, editting, setEditting, setOpen, open } = props;
    const [isSubmitting, setIsSubmitting] = useState(false);
    const { editAlgoOrder } = useContext(OrderListContext);
    const ee = useEventEmitter();
    const boxRef = useRef(null);
    const confirmRef = useRef(null);
    const { base, base_dp } = useSymbolContext();
    const closePopover = () => setOpen(0);
    const cancelPopover = () => {
        setOpen(-1);
        setPrice(order.trigger_price?.toString() ?? "0");
    };
    useEffect(() => {
        const clickHandler = (event) => {
            // close the input when click outside of boxRef
            const el = boxRef?.current;
            if (!el || el.contains(event.target)) {
                return;
            }
            const el2 = confirmRef?.current;
            if (!el2 || el2.contains(event.target)) {
                return;
            }
            setPrice(order.trigger_price?.toString() ?? "0");
            setEditting(false);
        };
        document.body.addEventListener("click", clickHandler);
        return () => {
            document.body.removeEventListener("click", clickHandler);
        };
    }, []);
    const onClick = () => {
        // event.stopPropagation();
        // event.preventDefault();
        setEditting(false);
        if (Number(price) === Number(order.trigger_price)) {
            return;
        }
        setOpen(1);
    };
    const handleKeyDown = (event) => {
        if (event.key === "Enter") {
            event.stopPropagation();
            event.preventDefault();
            onClick();
        }
    };
    const onClickCancel = (order) => {
        setPrice(order.trigger_price);
        setEditting(false);
    };
    const onConfirm = () => {
        // @ts-ignore
        const data = {
            // price: price,
            quantity: order.quantity,
            trigger_price: price,
            symbol: order.symbol,
            // order_type: order.type,
            // side: order.side,
            // reduce_only: Boolean(order.reduce_only),
            algo_order_id: order.algo_order_id,
        };
        // @ts-ignore
        editAlgoOrder(`${order.algo_order_id}`, data)
            .then((result) => {
            closePopover();
            setPrice(price);
            // setTimeout(() => inputRef.current?.blur(), 300);
        }, (err) => {
            toast.error(err.message);
            // @ts-ignore
            setPrice(order.trigger_price?.toString());
            cancelPopover();
        })
            .finally(() => setIsSubmitting(false));
    };
    const inputRef = useRef(null);
    return (_jsx(Popover, { open: open > 0, onOpenChange: (open) => setOpen(open ? 1 : 0), children: _jsxs("div", { className: "orderly-flex orderly-justify-start orderly-items-center orderly-gap-1 orderly-relative orderly-font-semibold", ref: boxRef, children: [_jsxs("div", { className: cn("orderly-absolute orderly-left-1 orderly-flex", {
                        "orderly-animate-in orderly-fade-in orderly-zoom-in": editting,
                        "orderly-animate-out orderly-fade-out orderly-zoom-out orderly-hidden": !editting,
                    }), children: [_jsx("button", { className: "hover:orderly-bg-base-contrast/10 orderly-h-[25px] orderly-rounded orderly-px-1 orderly-text-base-contrast-54 hover:orderly-text-base-contrast-80", onClick: () => onClickCancel(order), children: _jsx(X, { size: 14 }) }), _jsx(Divider, { vertical: true, className: "orderly-ml-[1px] before:orderly-h-[16px] orderly-min-w-[2px]" })] }), _jsx(PopoverAnchor, { asChild: true, children: _jsx(Input, { ref: inputRef, type: "text", value: commify(price), onChange: (e) => setPrice(cleanStringStyle(e.target.value)), onFocus: () => setEditting(true), onBlur: () => {
                            setTimeout(() => {
                                setEditting(false);
                                if (open <= 0) {
                                    setPrice(order.trigger_price?.toString() ?? "0");
                                }
                            }, 100);
                        }, autoFocus: true, onKeyDown: handleKeyDown, containerClassName: "orderly-h-auto orderly-pl-7", className: "orderly-w-full orderly-flex-1 orderly-pl-9 orderly-pr-9 orderly-bg-base-700 orderly-px-2 orderly-py-1 orderly-rounded " }) }), _jsxs("div", { className: cn("orderly-absolute orderly-right-1 orderly-flex", {
                        "orderly-animate-in orderly-fade-in orderly-zoom-in": editting,
                        "orderly-animate-out orderly-fade-out orderly-zoom-out  orderly-hidden": !editting,
                    }), children: [_jsx(Divider, { vertical: true, className: "before:orderly-h-[16px] orderly-min-w-[2px] orderly-mr-[1px]" }), _jsx("button", { className: "hover:orderly-bg-base-contrast/10 orderly-h-[25px] orderly-rounded orderly-px-1 orderly-text-base-contrast-54 hover:orderly-text-base-contrast-80", 
                            // @ts-ignore
                            onMouseDown: onClick, children: _jsx(Check, { size: 18 }) }), _jsx(PopoverContent, { align: "end", side: "top", className: "orderly-w-[340px]", onCloseAutoFocus: (e) => {
                                if (inputRef.current && open === -1) {
                                    inputRef.current.focus();
                                }
                            }, onOpenAutoFocus: (e) => e.preventDefault(), children: _jsxs("div", { className: "orderly-pt-5 orderly-relative", children: [_jsxs("div", { className: "orderly-text-base-contrast-54 orderly-text-2xs desktop:orderly-text-sm", children: ["You agree changing the trigger price of ", base, "-PERP order to", " ", _jsx("span", { className: "orderly-text-warning", children: commify(price) }), "."] }), _jsxs("div", { className: "orderly-grid orderly-grid-cols-2 orderly-gap-2 orderly-mt-5", children: [_jsx(Button, { color: "tertiary", onClick: cancelPopover, disabled: isSubmitting, children: "Cancel" }), _jsx(Button
                                            // @ts-ignore
                                            , { 
                                                // @ts-ignore
                                                ref: confirmRef, loading: isSubmitting, onClick: onConfirm, children: "Confirm" })] }), _jsx("button", { className: "orderly-absolute orderly-right-0 orderly-top-0 orderly-text-base-contrast-54", onClick: cancelPopover, children: _jsx(X, { size: 18 }) })] }) })] })] }) }));
};
//# sourceMappingURL=triggerPrice.js.map