import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Table } from "../../../table";
import { useContext, useMemo, useRef, } from "react";
import { Numeral, Text } from "../../../text";
import { PositionsRowProvider, } from "./positionRowContext";
import { PriceInput } from "./priceInput";
import { CloseButton } from "./closeButton";
import { SymbolProvider } from "../../../provider";
import { QuantityInput } from "./quantityInput";
import { NumeralWithCtx } from "../../../text/numeralWithCtx";
import { TabContext } from "../../../tab";
import { useTabContext } from "../../../tab/tabContext";
import { Divider } from "../../../divider";
import { UnrealizedPnLPopoverCard } from "./unrealPnLHover";
import { PositionEmptyView } from "./positionEmptyView";
import { SharePnLIcon } from "../../../block/shared/sharePnLIcon";
export const Listview = (props) => {
    const { height } = useContext(TabContext);
    // const { footerHeight } = useContext(LayoutContext);
    const { data: { pnlNotionalDecimalPrecision }, } = useTabContext();
    const columns = useMemo(() => {
        return [
            {
                title: "Instrument",
                dataIndex: "symbol",
                className: "orderly-h-[48px]",
                fixed: "left",
                width: 120,
                onSort: (r1, r2, sortOrder) => {
                    if (sortOrder === "asc") {
                        return r1.symbol.localeCompare(r2.symbol);
                    }
                    return r2.symbol.localeCompare(r1.symbol);
                },
                render: (value) => (_jsx(Text, { rule: "symbol", className: "orderly-font-semibold orderly-cursor-pointer", onClick: (e) => {
                        props.onSymbolChange?.({ symbol: value });
                        e.stopPropagation();
                        e.preventDefault();
                    }, children: value })),
            },
            {
                title: "Quantity",
                className: "orderly-h-[48px]",
                dataIndex: "position_qty",
                onSort: true,
                width: 100,
                render: (value) => (_jsx(NumeralWithCtx, { coloring: true, className: "orderly-font-semibold", tick: "base_dp", children: value })),
            },
            {
                title: "Avg. open",
                className: "orderly-h-[48px]",
                width: 120,
                onSort: true,
                dataIndex: "average_open_price",
                render: (value) => _jsx(NumeralWithCtx, { children: value }),
            },
            {
                title: "Mark price",
                dataIndex: "mark_price",
                width: 120,
                onSort: true,
                className: "orderly-h-[48px]",
                render: (value) => {
                    return (_jsx(NumeralWithCtx, { className: "orderly-font-semibold", children: value }));
                },
            },
            {
                title: "Liq. price",
                width: 100,
                onSort: true,
                className: "orderly-h-[48px]",
                hint: "Estimated price at which your position will be liquidated. Prices are estimated and depend on multiple factors across all positions.",
                dataIndex: "est_liq_price",
                render: (value) => {
                    return Number(value) === 0 ? ("--") : (_jsx(NumeralWithCtx, { className: "orderly-text-warning orderly-font-semibold", children: value }));
                },
            },
            {
                title: "Unreal. PnL",
                className: "orderly-h-[48px]",
                dataIndex: "unrealized_pnl",
                width: 150,
                onSort: true,
                hint: (_jsx(UnrealizedPnLPopoverCard, { unPnlPriceBasis: props.unPnlPriceBasis, setUnPnlPriceBasic: props.setUnPnlPriceBasic })),
                render: (value, record) => {
                    return (_jsxs("span", { children: [_jsx(Numeral, { precision: pnlNotionalDecimalPrecision, coloring: true, className: "orderly-font-semibold", children: value }), _jsx(Numeral, { rule: "percentages", precision: pnlNotionalDecimalPrecision, coloring: true, className: "orderly-font-semibold", prefix: "(", surfix: ")", children: record.unrealized_pnl_ROI }), _jsx(SharePnLIcon, { className: "orderly-ml-2", position: record })] }));
                },
            },
            // {
            //   title: "Unreal. ROI",
            //   className: "orderly-h-[48px]",
            //   dataIndex: "unsettled_pnl_ROI",
            //   width: 120,
            //   onSort: true,
            //   render: (value: string) => (
            //   ),
            // },
            // {
            //   title: "Daily real.",
            //   className: "orderly-h-[48px]",
            //   dataIndex: "open_price",
            // },
            {
                title: "Est. total",
                dataIndex: "notional",
                className: "orderly-h-[48px]",
                width: 100,
                onSort: true,
                render: (value) => (_jsx(Numeral, { precision: pnlNotionalDecimalPrecision, className: "orderly-font-semibold", children: value })),
            },
            {
                title: "Margin",
                className: "orderly-h-[48px]",
                dataIndex: "mm",
                onSort: true,
                width: 100,
                render: (value) => (_jsx(Numeral, { className: "orderly-font-semibold", children: value })),
                hint: (_jsxs("div", { children: [_jsx("span", { children: "The minimum equity to keep your position. " }), _jsx(Divider, { className: "orderly-py-2 orderly-border-white/10" }), _jsx("span", { children: "Margin = Position size * Mark price * MMR" })] })),
                hintClassName: "orderly-p-2",
            },
            {
                title: "Qty.",
                dataIndex: "close_qty",
                className: "orderly-h-[48px]",
                width: 100,
                fixed: "right",
                render: (value) => {
                    return _jsx(QuantityInput, {});
                },
            },
            {
                title: "Price",
                dataIndex: "close_price",
                width: 100,
                fixed: "right",
                className: "orderly-w-[100px] orderly-h-[48px]",
                render: (value) => _jsx(PriceInput, {}),
            },
            {
                title: "",
                dataIndex: "close_position",
                align: "right",
                width: 80,
                fixed: "right",
                className: "orderly-h-[48px]",
                render: (value) => {
                    return _jsx(CloseButton, {});
                },
            },
        ];
    }, [pnlNotionalDecimalPrecision, props.unPnlPriceBasis]);
    const divRef = useRef(null);
    return (_jsxs("div", { ref: divRef, 
        // className="orderly-overflow-y-auto"
        className: "orderly-relative", style: { height: `${(height?.content ?? 100) - 68}px` }, children: [_jsx(Table, { bordered: true, justified: true, showMaskElement: false, columns: columns, dataSource: props.dataSource, headerClassName: "orderly-text-2xs orderly-text-base-contrast-54 orderly-py-3 orderly-bg-base-900", className: "orderly-text-2xs orderly-text-base-contrast-80", generatedRowKey: (record) => record.symbol, renderRowContainer: (record, index, children) => {
                    return (_jsx(SymbolProvider, { symbol: record.symbol, children: _jsx(PositionsRowProvider, { position: record, children: children }) }));
                } }), (!props.dataSource || props.dataSource.length <= 0) && (_jsx(PositionEmptyView, { watchRef: divRef, left: 120, right: 280 }))] }));
};
//# sourceMappingURL=listview.js.map