import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Paper } from "../../layout";
import { ListTile } from "../../listView/listTile";
import { Switch } from "../../switch";
import { useCallback, useMemo, useState } from "react";
import { AccountStatusEnum } from "@orderly.network/types";
import { StepItem } from "./sections/step";
import { useAccount } from "@orderly.network/hooks";
import Button from "../../button";
import { toast } from "../../toast";
import { RememberMe } from "./sections/rememberMe";
export const WalletConnect = (props) => {
    // const { status = AccountStatusEnum.NotConnected } = props;
    const { state: { status }, } = useAccount();
    const [handleStep, setHandleStep] = useState(0);
    const [remember, setRemember] = useState(true);
    const buttonLabel = useMemo(() => {
        if (status < AccountStatusEnum.SignedIn) {
            return "Sign in";
        }
        if (status < AccountStatusEnum.EnableTrading) {
            return "Enable Trading";
        }
        return "--";
    }, [status]);
    const onClick = useCallback(() => {
        if (status < AccountStatusEnum.SignedIn) {
            setHandleStep(1);
            return props.onSignIn?.().finally(() => {
                setHandleStep(0);
            });
        }
        if (status < AccountStatusEnum.EnableTrading) {
            setHandleStep(2);
            return props
                .onEnableTrading?.(remember)
                .then(() => {
                props.onComplete?.();
            }, (error) => {
                toast.error(error.message);
            })
                .finally(() => {
                setHandleStep(0);
            });
        }
    }, [status, remember]);
    return (_jsxs("div", { children: [_jsx("div", { className: "orderly-text-base-contrast-54 orderly-text-2xs orderly-py-4 desktop:orderly-text-base", children: "Sign two requests to verify ownership of your wallet and enable trading. Signing is free." }), _jsxs(Paper, { className: "orderly-bg-base-500", children: [_jsx(ListTile, { className: "orderly-text-xs desktop:orderly-text-base", avatar: _jsx(StepItem, { active: status <= AccountStatusEnum.NotSignedIn, isLoading: handleStep === 1, isCompleted: status >= AccountStatusEnum.SignedIn, children: "1" }), title: "Sign in", disabled: status < AccountStatusEnum.NotConnected ||
                            status >= AccountStatusEnum.SignedIn, subtitle: "Confirm you own this wallet" }), _jsx(ListTile, { className: "orderly-text-xs desktop:orderly-text-base", disabled: status < AccountStatusEnum.SignedIn, avatar: _jsx(StepItem, { active: status >= AccountStatusEnum.SignedIn, isLoading: handleStep === 2, isCompleted: status >= AccountStatusEnum.EnableTrading, children: "2" }), title: "Enable Trading", subtitle: "Enable secure access to our API for lightning-fast trading" })] }), _jsxs("div", { className: "orderly-pt-5 orderly-pb-7 orderly-flex orderly-justify-between orderly-items-center", children: [_jsx(RememberMe, {}), _jsx("div", { children: _jsx(Switch, { id: "orderly-remember-me-switch", checked: remember, onCheckedChange: setRemember }) })] }), _jsx("div", { children: _jsx(Button, { className: "orderly-text-xs orderly-text-base-contrast", fullWidth: true, disabled: handleStep > 0, onClick: onClick, loading: handleStep > 0, children: buttonLabel }) })] }));
};
//# sourceMappingURL=walletConnect.js.map