import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { modal, useModal } from "../../modal";
import { create } from "../../modal/modalHelper";
import { MEDIA_TABLET } from "@orderly.network/types";
import { Sheet, SheetContent, SheetHeader, SheetTitle } from "../../sheet";
import { toast } from "../../toast";
import { useAccount } from "@orderly.network/hooks";
import { useCallback } from "react";
import { WalletConnect } from "./walletConnect";
import { Logo } from "../../logo";
import { Dialog, DialogBody, DialogContent, DialogHeader, DialogTitle, } from "../../dialog";
const useWalletConnect = () => {
    const { visible, hide, resolve, reject, onOpenChange } = useModal();
    // get account status and handle sign in and enable trading
    const { account, createOrderlyKey, createAccount } = useAccount();
    const onSignIn = useCallback(() => {
        return createAccount().catch((err) => {
            reject();
            toast.error(err.message);
            hide();
        });
    }, [account]);
    const onComplete = useCallback(() => {
        toast.success("Wallet connected");
        resolve();
        hide();
    }, []);
    return {
        visible,
        hide,
        resolve,
        reject,
        onOpenChange,
        onSignIn,
        onComplete,
        createOrderlyKey,
    };
};
export const WalletConnectSheet = create((props) => {
    // const { visible, hide, resolve, reject, onOpenChange } = useModal();
    // // get account status and handle sign in and enable trading
    // const { account, createOrderlyKey, createAccount } = useAccount();
    // // @ts-ignore
    // const { logoUrl } = useContext(OrderlyContext);
    // const onSignIn = useCallback(() => {
    //   return createAccount().catch((err: Error) => {
    //     reject();
    //     toast.error(err.message);
    //     hide();
    //   });
    // }, [account]);
    // const onComplete = useCallback(() => {
    //   toast.success("Wallet connected");
    //   resolve();
    //   hide();
    // }, []);
    const { visible, hide, resolve, reject, onOpenChange, onSignIn, onComplete, createOrderlyKey, } = useWalletConnect();
    return (_jsx(Sheet, { open: visible, onOpenChange: onOpenChange, children: _jsxs(SheetContent, { children: [_jsx(SheetHeader, { leading: _jsx(Logo, {}), children: _jsx(SheetTitle, { children: "Connect wallet" }) }), _jsx(WalletConnect, { onEnableTrading: createOrderlyKey, onSignIn: onSignIn, onComplete: onComplete, ...props })] }) }));
});
export const WalletConnectDialog = create((props) => {
    const { visible, hide, resolve, reject, onOpenChange, onSignIn, onComplete, createOrderlyKey, } = useWalletConnect();
    const _onOpenChange = useCallback((open) => {
        // console.log(open);
        if (!open)
            reject("cancel");
        onOpenChange(open);
    }, []);
    return (_jsx(Dialog, { open: visible, onOpenChange: _onOpenChange, children: _jsxs(DialogContent, { maxWidth: "sm", closable: true, children: [_jsx(DialogHeader, { children: _jsx(DialogTitle, { children: "Connect wallet" }) }), _jsx(DialogBody, { children: _jsx(WalletConnect, { onEnableTrading: createOrderlyKey, onSignIn: onSignIn, onComplete: onComplete, ...props }) })] }) }));
});
export const showAccountConnectorModal = async (props) => {
    const matches = window.matchMedia(MEDIA_TABLET).matches;
    if (matches) {
        return await modal.show(WalletConnectSheet, props);
    }
    else {
        return await modal.show(WalletConnectDialog, props);
    }
};
//# sourceMappingURL=walletModal.js.map