import React, { FC, PropsWithChildren, ReactNode } from "react";
import { ConfigProviderProps } from "@orderly.network/hooks";
import { IContract } from "@orderly.network/core";
import { FooterStatusBarProps } from "../block/systemStatusBar/index";
import { ShareConfigProps } from "../block/shared/shareConfigProps";
import { Chains } from "@orderly.network/hooks/esm/orderly/useChains";
import { DesktopDropMenuItem } from "../block/accountStatus/desktop/accountStatus.desktop";
export type AppStateErrors = {
    ChainNetworkNotSupport: boolean;
    IpNotSupport: boolean;
    NetworkError: boolean;
};
type Logo = {
    img?: string;
    component?: ReactNode;
    className?: string;
};
export type AppLogos = Partial<{
    main: Logo;
    secondary: Logo;
}>;
export type OrderlyAppContextState = {
    appIcons?: AppLogos;
    theme: any;
    onWalletConnect: () => Promise<any>;
    onWalletDisconnect: () => Promise<any>;
    onSetChain: (chainId: number) => Promise<any>;
    errors: AppStateErrors;
    onChainChanged?: (chainId: number, isTestnet: boolean) => void;
    brokerName?: string;
    footerStatusBarProps?: FooterStatusBarProps;
    shareOptions: ShareConfigProps;
    /** custom chains  */
    chains?: Chains<undefined, undefined>;
    accountMenuItems?: DesktopDropMenuItem[] | React.ReactNode;
    onClickAccountMenuItem?: (item: DesktopDropMenuItem) => void;
};
export declare const OrderlyAppContext: React.Context<OrderlyAppContextState>;
export interface OrderlyAppProviderProps {
    appIcons?: AppLogos;
    theme?: any;
    toastLimitCount?: number;
    contracts?: IContract;
    /**
     * are include testnet chains
     */
    includeTestnet?: boolean;
    onChainChanged?: (chainId: number, isTestnet: boolean) => void;
    brokerName?: string;
    footerStatusBarProps?: FooterStatusBarProps;
    shareOptions: ShareConfigProps;
    /** custom chains  */
    chains?: Chains<undefined, undefined>;
    accountMenuItems?: DesktopDropMenuItem[] | React.ReactNode;
    onClickAccountMenuItem?: (item: DesktopDropMenuItem) => void;
}
export declare const OrderlyAppProvider: FC<PropsWithChildren<OrderlyAppProviderProps & ConfigProviderProps>>;
export {};
//# sourceMappingURL=appProvider.d.ts.map