"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccountStatusBar = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const button_1 = __importDefault(require("../../button"));
const sheet_1 = require("../../sheet");
const accountInfo_1 = require("./sections/accountInfo");
const text_1 = require("../../text");
const accountTotal_1 = require("./sections/accountTotal");
const types_1 = require("@orderly.network/types");
const logo_1 = require("../../logo");
const chains_1 = require("./sections/chains");
const provider_1 = require("../../provider");
const AccountStatusBar = (props) => {
    const { status = types_1.AccountStatusEnum.NotConnected } = props;
    const { errors } = (0, react_1.useContext)(provider_1.OrderlyAppContext);
    const [infoOpen, setInfoOpen] = (0, react_1.useState)(false);
    const buttonLabel = (0, react_1.useMemo)(() => {
        switch (status) {
            case types_1.AccountStatusEnum.NotConnected:
                return "Connect wallet";
            case types_1.AccountStatusEnum.Connected:
            case types_1.AccountStatusEnum.NotSignedIn:
            case types_1.AccountStatusEnum.SignedIn:
            case types_1.AccountStatusEnum.DisabledTrading:
            case types_1.AccountStatusEnum.EnableTrading:
                return ((0, jsx_runtime_1.jsx)(text_1.Text, { rule: "address", range: [4, 4], children: props.address }));
        }
    }, [status, props.address]);
    return ((0, jsx_runtime_1.jsxs)("div", { id: "orderly-botom-bar", className: "orderly-flex orderly-items-center orderly-justify-between orderly-w-full", children: [status !== types_1.AccountStatusEnum.NotConnected &&
                !errors?.ChainNetworkNotSupport ? ((0, jsx_runtime_1.jsx)(accountTotal_1.AccountTotal, { status: status, currency: props.currency, totalValue: props.totalValue, accountInfo: props.accountInfo })) : ((0, jsx_runtime_1.jsx)("div", {})), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-gap-2", children: [(0, jsx_runtime_1.jsx)(chains_1.Chains, { disabled: status < types_1.AccountStatusEnum.NotConnected }), status === types_1.AccountStatusEnum.NotConnected ? ((0, jsx_runtime_1.jsx)(button_1.default, { id: "orderly-botom-bar-not-connect-button", size: "small", loading: props.loading, 
                        // variant={"gradient"}
                        className: "orderly-bg-primary orderly-text-base-contrast orderly-text-4xs hover:orderly-text-base-80 orderly-h-[30px]", onClick: () => props.onConnect?.(), children: buttonLabel })) : ((0, jsx_runtime_1.jsxs)(sheet_1.Sheet, { open: infoOpen, onOpenChange: setInfoOpen, children: [(0, jsx_runtime_1.jsx)(sheet_1.SheetTrigger, { asChild: true, children: (0, jsx_runtime_1.jsx)(button_1.default, { id: "orderly-botom-bar-connect-button", size: "small", 
                                    // variant={"gradient"}
                                    className: "orderly-bg-primary orderly-text-base-contrast orderly-text-4xs hover:orderly-text-base-80 orderly-h-[30px]", loading: props.loading, disabled: props.loading || errors?.ChainNetworkNotSupport, children: buttonLabel }) }), (0, jsx_runtime_1.jsxs)(sheet_1.SheetContent, { id: "my-account", forceMount: true, children: [(0, jsx_runtime_1.jsx)(sheet_1.SheetHeader, { id: "my-account-sheet-title", leading: (0, jsx_runtime_1.jsx)(logo_1.Logo.secondary, { size: 30 }), children: "My account" }), (0, jsx_runtime_1.jsx)(accountInfo_1.AccountInfo, { onDisconnect: props.onDisconnect, close: () => setInfoOpen(false), showGetTestUSDC: props.showGetTestUSDC })] })] }))] })] }));
};
exports.AccountStatusBar = AccountStatusBar;
//# sourceMappingURL=accountStatusBar.js.map