"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Assets = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const text_1 = require("../../../text");
const progress_1 = require("../../../progress");
const lucide_react_1 = require("lucide-react");
const hooks_1 = require("@orderly.network/hooks");
const collapsible_1 = require("../../../collapsible/collapsible");
const toast_1 = require("../../../toast");
const leverage_1 = require("../../../block/accountStatus/full/leverage");
const assetsDetail_1 = require("../../../block/accountStatus/full/assetsDetail");
const button_1 = __importDefault(require("../../../button"));
const icon_1 = require("../../../icon");
const types_1 = require("@orderly.network/types");
const walletConnect_1 = require("../../../block/walletConnect");
const modal_1 = require("../../../modal");
const utils_1 = require("@orderly.network/utils");
const KEY = "ORDERLY_WEB_ASSETS_COLLAPSED";
const Assets = (props) => {
    // const [expand, { toggle }] = useBoolean(false);
    const [collapsed, setCollapsed] = (0, hooks_1.useLocalStorage)(KEY, 1);
    const { totalCollateral, freeCollateral, totalValue, availableBalance } = (0, hooks_1.useCollateral)({
        dp: 2,
    });
    const [disableGetTestUSDC, setDisableGetTestUSDC] = (0, react_1.useState)(false);
    const { connectedChain } = (0, hooks_1.useWalletConnector)();
    const config = (0, hooks_1.useConfig)();
    const { account, state } = (0, hooks_1.useAccount)();
    const showGetTestUSDC = (0, react_1.useMemo)(() => {
        const chainId = connectedChain?.id;
        if (chainId === undefined) {
            return false;
        }
        return (state.status === types_1.AccountStatusEnum.EnableTrading &&
            // @ts-ignore
            (0, utils_1.isTestnet)(parseInt(chainId)));
    }, [state.status, connectedChain]);
    const [getTestUSDC, { isMutating }] = (0, hooks_1.useMutation)(`${config.get("operatorUrl")}/v1/faucet/usdc`);
    const onGetClick = (0, react_1.useCallback)(() => {
        if (state.status < types_1.AccountStatusEnum.EnableTrading) {
            return modal_1.modal.show(walletConnect_1.WalletConnectSheet, {
                status: state.status,
            });
        }
        setDisableGetTestUSDC(true);
        return getTestUSDC({
            chain_id: account.wallet?.chainId.toString(),
            user_address: state.address,
            broker_id: config.get("brokerId"),
        }).then((res) => {
            setDisableGetTestUSDC(false);
            if (res.success) {
                return modal_1.modal.confirm({
                    title: "Get test USDC",
                    content: "1,000 USDC will be added to your balance. Please note this may take up to 3 minutes. Please check back later.",
                    onOk: () => {
                        return Promise.resolve();
                    },
                });
            }
            res.message && toast_1.toast.error(res.message);
            // return Promise.reject(res);
        }, (error) => {
            toast_1.toast.error(error.message);
        });
    }, [state]);
    const [{ aggregated }, positionsInfo] = (0, hooks_1.usePositionStream)();
    const { marginRatio } = (0, hooks_1.useMarginRatio)();
    const marginRatioVal = (0, react_1.useMemo)(() => {
        return Math.min(10, aggregated.notional === 0
            ? // @ts-ignore
                positionsInfo["margin_ratio"](10)
            : marginRatio);
    }, [marginRatio, aggregated]);
    return ((0, jsx_runtime_1.jsxs)(collapsible_1.Collapsible, { open: collapsed > 0, onOpenChange: (value) => {
            setCollapsed(value ? 1 : 0);
        }, children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-py-3 orderly-flex orderly-justify-between orderly-items-center orderly-tabular-nums", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex-1", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-text-3xs orderly-text-base-contrast-54", children: "Total balance" }), (0, jsx_runtime_1.jsx)("div", { children: (0, jsx_runtime_1.jsx)(text_1.Numeral, { surfix: (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-36 orderly-font-medium", children: "USDC" }), className: "desktop:orderly-font-semibold", children: availableBalance }) })] }), (0, jsx_runtime_1.jsx)(collapsible_1.CollapsibleTrigger, { asChild: true, children: (0, jsx_runtime_1.jsx)("button", { className: "orderly-p-1 orderly-rounded hover:orderly-bg-base-900 data-[state=open]:orderly-rotate-180 orderly-transition-transform", children: (0, jsx_runtime_1.jsx)(lucide_react_1.ChevronDown, { size: 18, className: "orderly-text-base-contrast-54 orderly-z-0" }) }) })] }), showGetTestUSDC && ((0, jsx_runtime_1.jsx)("div", { className: "orderly-mb-3 orderly-w-full", children: (0, jsx_runtime_1.jsxs)(button_1.default, { variant: "outlined", fullWidth: true, size: "small", className: "orderly-border-base-contrast-54 hover:orderly-bg-base-700 orderly-h-[28px] orderly-rounded-borderRadius-lg", onClick: onGetClick, disabled: disableGetTestUSDC, children: [(0, jsx_runtime_1.jsx)(icon_1.NetworkImage, { type: "token", name: "USDC", size: 16, rounded: true }), (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast orderly-text-3xs", children: "Get 1,000 test USDC" })] }) })), (0, jsx_runtime_1.jsx)(collapsible_1.CollapsibleContent, { children: (0, jsx_runtime_1.jsx)(assetsDetail_1.MemorizedAssetsDetail, {}) }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-pb-4", children: (0, jsx_runtime_1.jsx)(progress_1.Progress, { value: marginRatioVal * 10, variant: "gradient" }) }), (0, jsx_runtime_1.jsx)(leverage_1.MemorizedLeverage, {})] }));
};
exports.Assets = Assets;
//# sourceMappingURL=assets.js.map