"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AssetAndMarginSheet = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const button_1 = __importDefault(require("../../../button"));
const divider_1 = require("../../../divider");
const networkImage_1 = require("../../../icon/networkImage");
const layout_1 = require("../../../layout");
const riskIndicator_1 = require("../../../riskIndicator");
const statistic_1 = require("../../../statistic");
const defaultStaticStyle_1 = require("../../../statistic/defaultStaticStyle");
const text_1 = require("../../../text");
const lucide_react_1 = require("lucide-react");
const hooks_1 = require("@orderly.network/hooks");
// import Slider from "rc-slider";
const modal_1 = require("../../../modal");
const toast_1 = require("../../../toast");
const assetsProvider_1 = require("../../../provider/assetsProvider");
const icon_1 = require("../../../icon");
const css_1 = require("../../../utils/css");
const class_variance_authority_1 = require("class-variance-authority");
const leverageEditor_1 = require("./leverageEditor");
const utils_1 = require("../utils");
// const leverageLevers = [1, 2, 3, 4, 5, 10];
const AssetAndMarginSheet = (props) => {
    const { totalCollateral, freeCollateral, totalValue, availableBalance } = (0, hooks_1.useCollateral)({
        dp: 2,
    });
    const [{ aggregated, totalUnrealizedROI }, positionsInfo] = (0, hooks_1.usePositionStream)();
    const { marginRatio, currentLeverage, mmr } = (0, hooks_1.useMarginRatio)();
    const { visible, toggleVisible, onDeposit, onWithdraw } = (0, react_1.useContext)(assetsProvider_1.AssetsContext);
    const [maxLeverage, { update, config: leverageLevers }] = (0, hooks_1.useLeverage)();
    // console.log("leverageLevers", leverageLevers);
    // const [leverage, setLeverage] = React.useState(() => maxLeverage ?? 0);
    // const leverageValue = useMemo(() => {
    //   const index = leverageLevers.findIndex((item) => item === leverage);
    //   return index;
    // }, [leverage, leverageLevers]);
    const onUnsettleClick = (0, react_1.useCallback)(() => {
        return modal_1.modal.confirm({
            title: "Settle PnL",
            maxWidth: "xs",
            content: ((0, jsx_runtime_1.jsx)("div", { className: "orderly-text-base-contrast-54 orderly-text-2xs desktop:orderly-text-sm", children: "Are you sure you want to settle your PnL? Settlement will take up to 1 minute before you can withdraw your available balance." })),
            onCancel: () => {
                return Promise.reject();
            },
            onOk: () => {
                if (typeof props.onSettle !== "function")
                    return Promise.resolve();
                return props.onSettle().catch((e) => { });
            },
        });
    }, []);
    const marginRatioVal = (0, react_1.useMemo)(() => {
        return Math.min(10, aggregated.notional === 0
            ? // @ts-ignore
                positionsInfo["margin_ratio"](10)
            : marginRatio);
    }, [marginRatio, aggregated]);
    const { isRed, isYellow, isGreen } = (0, utils_1.getMarginRatioColor)(marginRatioVal, mmr);
    return ((0, jsx_runtime_1.jsx)("div", { id: "orderly-asset-and-margin-sheet-content", children: (0, jsx_runtime_1.jsxs)(defaultStaticStyle_1.StatisticStyleProvider, { labelClassName: "orderly-text-4xs orderly-text-base-contrast/30", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-pt-5", children: (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center orderly-text-2xs orderly-text-base-contrast-54", children: [(0, jsx_runtime_1.jsx)("span", { children: "Total value (USDC)" }), (0, jsx_runtime_1.jsx)("button", { className: "orderly-text-link orderly-p-2", onClick: (event) => {
                                        event.stopPropagation();
                                        toggleVisible();
                                    }, children: visible ? (0, jsx_runtime_1.jsx)(icon_1.EyeOffIcon, { size: 16 }) : (0, jsx_runtime_1.jsx)(icon_1.EyeIcon, { size: 16 }) })] }), value: totalValue, rule: "price", visible: visible }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-grid orderly-grid-cols-2 orderly-py-4", children: [(0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Unreal. PnL(USDC)", labelClassName: "orderly-text-base-contrast-36", value: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-gap-1 orderly-items-center orderly-text-2xs", children: [(0, jsx_runtime_1.jsx)(text_1.Numeral, { coloring: true, visible: visible, children: aggregated.unrealPnL }), (0, jsx_runtime_1.jsx)(text_1.Numeral, { visible: visible, rule: "percentages", coloring: true, surfix: ")", prefix: "(", className: "orderly-text-4xs orderly-opacity-60", children: totalUnrealizedROI })] }), rule: "price", coloring: true }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Unsettled PnL(USDC)", labelClassName: "orderly-text-base-contrast-36", value: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between", children: [(0, jsx_runtime_1.jsx)(text_1.Numeral, { rule: "price", visible: visible, coloring: true, className: "orderly-text-2xs", children: aggregated.unsettledPnL }), (0, jsx_runtime_1.jsxs)("button", { className: "orderly-text-link orderly-text-3xs orderly-flex orderly-items-center orderly-gap-1 disabled:orderly-opacity-50 disabled:orderly-cursor-not-allowed", onClick: onUnsettleClick, disabled: aggregated.unsettledPnL === 0, children: [(0, jsx_runtime_1.jsx)(lucide_react_1.RotateCw, { size: 14 }), (0, jsx_runtime_1.jsx)("span", { children: "Settle PnL" })] })] }) })] }), (0, jsx_runtime_1.jsx)(divider_1.Divider, {}), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-grid orderly-grid-cols-2 orderly-py-4", children: [(0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Margin ratio", labelClassName: "orderly-text-base-contrast-36", value: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center orderly-gap-2 orderly-text-2xs", children: [(0, jsx_runtime_1.jsx)(text_1.Numeral, { rule: "percentages", className: (0, class_variance_authority_1.cx)({
                                            "orderly-text-primary-light": isGreen,
                                            "orderly-text-warning": isYellow,
                                            "orderly-text-danger": isRed,
                                        }), visible: visible, children: marginRatioVal }), (0, jsx_runtime_1.jsx)(riskIndicator_1.RiskIndicator, { className: (0, css_1.cn)({
                                            "orderly-rotate-0": isGreen,
                                            "orderly-rotate-90": isYellow,
                                            "orderly-rotate-180": isRed,
                                        }) })] }) }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Free / Total collateral(USDC)", labelClassName: "orderly-text-base-contrast-36", value: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-gap-1 orderly-text-2xs", children: [(0, jsx_runtime_1.jsx)(text_1.Numeral, { visible: visible, children: freeCollateral }), (0, jsx_runtime_1.jsx)("span", { children: "/" }), (0, jsx_runtime_1.jsx)(text_1.Numeral, { visible: visible, children: totalCollateral })] }) })] }), (0, jsx_runtime_1.jsx)("div", { children: (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between orderly-text-base-contrast-36", children: [(0, jsx_runtime_1.jsx)("span", { children: "Max account leverage" }), (0, jsx_runtime_1.jsxs)("span", { className: "orderly-flex", children: ["Current:", (0, jsx_runtime_1.jsx)(text_1.Numeral, { className: "orderly-text-base-contrast orderly-ml-1", surfix: "x", children: currentLeverage })] })] }), value: (0, jsx_runtime_1.jsx)("div", { className: "orderly-h-[50px] orderly-mt-2 orderly-mx-2 orderly-text-2xs", children: (0, jsx_runtime_1.jsx)(leverageEditor_1.LeverageEditor, { leverageLevers: leverageLevers, onSave: (value) => {
                                    return update(value).then((res) => {
                                        toast_1.toast.success("Leverage updated");
                                        return res;
                                    }, (err) => {
                                        //
                                        toast_1.toast.error(err.message);
                                        // setLeverage(maxLeverage ?? 1);
                                        throw err;
                                    });
                                }, maxLeverage: maxLeverage }) }) }) }), (0, jsx_runtime_1.jsx)(divider_1.Divider, { className: "orderly-py-4" }), (0, jsx_runtime_1.jsxs)(layout_1.Paper, { className: "orderly-bg-base-700", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between orderly-text-4xs orderly-text-base-contrast-36", children: [(0, jsx_runtime_1.jsx)("span", { children: "Instrument" }), (0, jsx_runtime_1.jsx)("span", { children: "Available balance" })] }), (0, jsx_runtime_1.jsx)(divider_1.Divider, { className: "orderly-py-3" }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between orderly-text-2xs", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center orderly-gap-2", children: [(0, jsx_runtime_1.jsx)(networkImage_1.NetworkImage, { name: "USDC", type: "token", size: 14 }), (0, jsx_runtime_1.jsx)("span", { children: "USDC" })] }), (0, jsx_runtime_1.jsx)(text_1.Numeral, { precision: 2, visible: visible, children: availableBalance })] })] }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-gap-3 orderly-py-5 orderly-text-xs", children: [(0, jsx_runtime_1.jsx)(button_1.default, { fullWidth: true, onClick: onDeposit, id: "orderly-assets-margin-deposit-button", children: "Deposit" }), (0, jsx_runtime_1.jsx)(button_1.default, { fullWidth: true, variant: "outlined", onClick: onWithdraw, id: "orderly-assets-margin-withdraw-button", className: "orderly-border-primary-darken hover:orderly-bg-transport orderly-text-primary", children: "Withdraw" })] })] }) }));
};
exports.AssetAndMarginSheet = AssetAndMarginSheet;
//# sourceMappingURL=assetAndMargin.js.map