"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Chains = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const chainPicker_1 = require("../../../block/pickers/chainPicker");
const button_1 = __importDefault(require("../../../button"));
const dialog_1 = require("../../../dialog");
const types_1 = require("@orderly.network/types");
const hooks_1 = require("@orderly.network/hooks");
const icon_1 = require("../../../icon");
const provider_1 = require("../../../provider");
const css_1 = require("../../../utils/css");
const utils_1 = require("@orderly.network/utils");
const Chains = (props) => {
    const { disabled } = props;
    const [open, setOpen] = (0, react_1.useState)(false);
    const { networkId } = (0, react_1.useContext)(hooks_1.OrderlyContext);
    const { onChainChanged } = (0, react_1.useContext)(provider_1.OrderlyAppContext);
    const [defaultChain, setDefaultChain] = (0, react_1.useState)(networkId === "mainnet"
        ? types_1.ARBITRUM_MAINNET_CHAINID_HEX
        : types_1.ARBITRUM_TESTNET_CHAINID_HEX);
    const [testChains] = (0, hooks_1.useChains)("testnet", {
        pick: "network_infos",
        filter: (item) => (0, utils_1.isTestnet)(item.network_infos?.chain_id),
    });
    const [mainChains, { findByChainId }] = (0, hooks_1.useChains)("mainnet", {
        pick: "network_infos",
        filter: (chain) => chain.network_infos?.bridge_enable || chain.network_infos?.bridgeless,
    });
    const { connectedChain, setChain, settingChain } = (0, hooks_1.useWalletConnector)();
    const resetDefaultChain = (0, react_1.useCallback)(() => {
        if (networkId === "mainnet" &&
            defaultChain !== types_1.ARBITRUM_MAINNET_CHAINID_HEX) {
            setDefaultChain(types_1.ARBITRUM_MAINNET_CHAINID_HEX);
        }
        else if (networkId === "testnet" &&
            defaultChain !== types_1.ARBITRUM_TESTNET_CHAINID_HEX) {
            setDefaultChain(types_1.ARBITRUM_TESTNET_CHAINID_HEX);
        }
    }, [defaultChain]);
    const chainName = (0, react_1.useMemo)(() => {
        const chain = findByChainId(
        // @ts-ignore
        parseInt(connectedChain?.id || defaultChain), "network_infos");
        if (!chain)
            return (0, jsx_runtime_1.jsx)("span", { children: "Unknown" });
        // @ts-ignore
        if ((0, utils_1.isTestnet)(chain.chain_id)) {
            return (0, jsx_runtime_1.jsx)("span", { children: "Testnet" });
        }
        // @ts-ignore
        return (0, jsx_runtime_1.jsx)(icon_1.NetworkImage, { id: chain.chain_id, type: "chain", size: 16 });
    }, [connectedChain, findByChainId, defaultChain]);
    const switchDomain = (chainId) => {
        // const domain = configStore.get("domain");
        // const url = isTestnet(chainId) ? domain?.testnet : domain?.mainnet;
        // window.location.href = url;
        // window.open(url); // test in storybook
        // console.log("onChainChanged", chainId, isTestnet(chainId), onChainChanged);
        if (onChainChanged) {
            onChainChanged(chainId, (0, utils_1.isTestnet)(chainId));
        }
    };
    return ((0, jsx_runtime_1.jsxs)(dialog_1.Dialog, { open: open, onOpenChange: setOpen, children: [(0, jsx_runtime_1.jsx)(dialog_1.DialogTrigger, { children: (0, jsx_runtime_1.jsxs)(button_1.default, { id: "orderly-botom-bar-switch-chain-button", variant: "outlined", size: "small", color: "buy", loading: settingChain, disabled: disabled, className: (0, css_1.cn)("orderly-border-primary orderly-gap-1 orderly-text-base-contrast orderly-h-[30px] hover:orderly-text-primary-light hover:orderly-bg-transparent active:orderly-bg-transparent", props.className), children: [chainName, (0, jsx_runtime_1.jsx)(icon_1.ArrowIcon, { size: 8, className: "orderly-text-base-contrast-54" })] }) }), (0, jsx_runtime_1.jsxs)(dialog_1.DialogContent, { onOpenAutoFocus: (event) => event.preventDefault(), closable: true, children: [(0, jsx_runtime_1.jsx)(dialog_1.DialogHeader, { className: "orderly-switch-network-dialog-title orderly-text-xs", children: "Switch network" }), (0, jsx_runtime_1.jsx)(dialog_1.DialogBody, { className: "orderly-max-h-[327.5px] orderly-overflow-y-auto", children: (0, jsx_runtime_1.jsx)(chainPicker_1.ChainListView
                        // @ts-ignore
                        , { 
                            // @ts-ignore
                            mainChains: mainChains, 
                            // @ts-ignore
                            testChains: testChains, 
                            // @ts-ignore
                            onItemClick: (item) => {
                                setOpen(false);
                                if (connectedChain) {
                                    setChain({ chainId: item.id }).then((success) => {
                                        // reset default chain when switch to connected chain
                                        resetDefaultChain();
                                        if (success) {
                                            switchDomain(item.id);
                                        }
                                    });
                                }
                                else {
                                    setDefaultChain(item.id);
                                    switchDomain(item.id);
                                }
                            }, 
                            // @ts-ignore
                            currentChainId: parseInt(connectedChain?.id || defaultChain) }) })] })] }));
};
exports.Chains = Chains;
//# sourceMappingURL=chains.js.map