"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DepositForm = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const quantityInput_1 = require("../../block/quantityInput");
const walletPicker_1 = require("../pickers/walletPicker");
const divider_1 = require("../../divider");
const tokenQtyInput_1 = require("../../input/tokenQtyInput");
const summary_1 = require("../../block/deposit/sections/summary");
const networkImage_1 = require("../../icon/networkImage");
const icon_1 = require("../../icon");
const actionButton_1 = require("./sections/actionButton");
const utils_1 = require("@orderly.network/utils");
const toast_1 = require("../../toast");
const num_1 = require("../../utils/num");
const provider_1 = require("../../provider");
const logo_1 = require("../../logo");
const DepositForm = (props) => {
    const { maxAmount, walletName, address, chains, chain, dst, switchChain, onOk, isNativeToken, quantity, setQuantity, depositFee, } = props;
    const { errors, brokerName, chains: customChains, } = (0, react_1.useContext)(provider_1.OrderlyAppContext);
    const [inputStatus, setInputStatus] = (0, react_1.useState)("default");
    const [hintMessage, setHintMessage] = (0, react_1.useState)();
    const [submitting, setSubmitting] = (0, react_1.useState)(false);
    const [tokens, setTokens] = (0, react_1.useState)([]);
    const cleanData = () => {
        setQuantity("");
    };
    const onDirectDeposit = (0, react_1.useCallback)(() => {
        props
            .deposit()
            .then((res) => {
            setQuantity("");
            toast_1.toast.success("Deposit requested");
            onOk?.(res);
        })
            .catch((error) => {
            toast_1.toast.error(error?.errorCode || "Deposit failed");
        })
            .finally(() => {
            setSubmitting(false);
        });
    }, [props.deposit]);
    const onDeposit = (0, react_1.useCallback)(() => {
        const num = Number(quantity);
        if (!props.token) {
            toast_1.toast.error("Please select a token");
            return;
        }
        if (isNaN(num) || num <= 0) {
            toast_1.toast.error("Please input a valid number");
            return;
        }
        if (inputStatus !== "default") {
            return;
        }
        if (submitting)
            return;
        setSubmitting(true);
        onDirectDeposit();
    }, [quantity, submitting, onDirectDeposit]);
    const onApprove = (0, react_1.useCallback)(async () => {
        return props.approve(quantity);
    }, [quantity, props.approve]);
    const onValueChange = (0, react_1.useCallback)((value) => {
        if (value.value === ".") {
            setQuantity("0.");
            return;
        }
        const result = value.value.match(num_1.NumberReg);
        if (Array.isArray(result)) {
            value = result[0];
            if (isNaN(parseFloat(value))) {
                setQuantity("");
            }
            else {
                let d = new utils_1.Decimal(value);
                if (d.dp() > dst.decimals) {
                    setQuantity(d.todp(Math.min(dst.decimals, 8)).toString());
                }
                else {
                    setQuantity(value);
                }
                if (d.gt(maxAmount)) {
                    setInputStatus("error");
                    setHintMessage("Insufficient balance");
                }
                else {
                    // reset input status
                    setInputStatus("default");
                    setHintMessage("");
                }
            }
        }
        else {
            setQuantity("");
            // reset input status when value is empty
            setInputStatus("default");
            setHintMessage("");
        }
    }, [dst.decimals, maxAmount]);
    const onTokenChange = (token) => {
        cleanData();
        props.switchToken?.(token);
    };
    const onChainChange = (0, react_1.useCallback)((value) => {
        if (!value)
            return;
        if (value.network_infos?.chain_id === chain?.id)
            return Promise.resolve();
        props
            .switchChain?.({
            chainId: (0, utils_1.int2hex)(Number(value.network_infos?.chain_id)),
            rpcUrl: value.network_infos?.public_rpc_url,
            token: value.network_infos?.currency_symbol,
            // name: chain.network_infos?.name,
            label: value.network_infos?.name,
        })
            .then(() => {
            // switch success，set tokens list
            setTokens(value?.token_infos ?? []);
            toast_1.toast.success("Network switched");
            cleanData();
        })
            .catch((error) => {
            toast_1.toast.error(`Switch chain failed: ${error.message}`);
        });
    }, [props.switchChain, chain]);
    // when chain changed and chain data ready then call this function
    const onChainInited = (0, react_1.useCallback)((chain) => {
        if (chain && chain.token_infos?.length > 0) {
            const tokens = chain.token_infos;
            const tokenObj = tokens.reduce((acc, item) => {
                acc[item.symbol] = item;
                return acc;
            }, {});
            const token = tokenObj["USDC"] || tokenObj["USDbC"] || tokens[0];
            if (!token || props.token?.symbol === token.symbol)
                return;
            setTokens(tokens);
            if (!token)
                return;
            props.switchToken?.(token);
        }
    }, [props.token?.symbol]);
    (0, react_1.useEffect)(() => {
        // check quantity
        if (isNaN(Number(quantity)) || !quantity)
            return;
        const d = new utils_1.Decimal(quantity);
        if (d.gt(maxAmount)) {
            setInputStatus("error");
            setHintMessage("Insufficient balance");
        }
        else {
            setInputStatus("default");
            setHintMessage("");
        }
    }, [maxAmount]);
    return ((0, jsx_runtime_1.jsxs)("div", { id: "orderly-deposit-form", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center orderly-py-2", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-flex-1 orderly-text-2xs desktop:orderly-text-base orderly-text-base-con", children: "Your web3 wallet" }), (0, jsx_runtime_1.jsx)(networkImage_1.NetworkImage, { type: typeof walletName === "undefined" ? "placeholder" : "wallet", name: walletName, rounded: true })] }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-pb-2", children: (0, jsx_runtime_1.jsx)(walletPicker_1.WalletPicker, { address: address, chain: chain, settingChain: props.settingChain, onChainChange: onChainChange, onChainInited: onChainInited, chains: customChains }) }), (0, jsx_runtime_1.jsx)(quantityInput_1.QuantityInput, { tokens: tokens, token: props.token, quantity: quantity, markPrice: 1, maxAmount: Number(maxAmount), onValueChange: onValueChange, status: inputStatus, decimals: dst.decimals, hintMessage: hintMessage, fetchBalance: props.fetchBalance, onTokenChange: onTokenChange, balanceRevalidating: props.balanceRevalidating, disabled: errors?.ChainNetworkNotSupport }), (0, jsx_runtime_1.jsx)(divider_1.Divider, { className: "orderly-py-4", children: (0, jsx_runtime_1.jsx)(icon_1.MoveDownIcon, { className: "orderly-text-primary-light" }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-py-2", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-flex-1 orderly-text-2xs orderly-text-base-contrast desktop:orderly-text-base", children: "Your " + brokerName + " account" }), (0, jsx_runtime_1.jsx)(logo_1.Logo.secondary, { size: 24 })] }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-py-2", children: (0, jsx_runtime_1.jsx)(tokenQtyInput_1.TokenQtyInput, { token: dst, amount: quantity, loading: false, readOnly: true, fee: 0 }) }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-flex orderly-items-start orderly-py-3 orderly-text-3xs orderly-text-tertiary", children: (0, jsx_runtime_1.jsx)(summary_1.Summary, { nativeToken: chain?.info?.nativeToken, src: props.token, dst: dst, price: 1, depositFee: depositFee }) }), (0, jsx_runtime_1.jsx)(actionButton_1.ActionButton, { chain: chain, chains: chains, token: props.token, onDeposit: onDeposit, allowance: props.isNativeToken ? Number.MAX_VALUE : Number(props.allowance), chainNotSupport: !!errors?.ChainNetworkNotSupport, disabled: !quantity || inputStatus === "error" || props.depositFeeRevalidating, loading: submitting || props.depositFeeRevalidating, submitting: submitting || props.depositFeeRevalidating, switchChain: switchChain, quantity: quantity, onApprove: onApprove, maxQuantity: maxAmount, warningMessage: "", onChainChange: onChainChange })] }));
};
exports.DepositForm = DepositForm;
//# sourceMappingURL=depositForm.js.map