"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Summary = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const utils_1 = require("@orderly.network/utils");
const num_1 = require("../../../utils/num");
const icon_1 = require("../../../icon");
const modal_1 = require("../../../modal");
const divider_1 = require("../../../divider");
const utils_2 = require("../utils");
const hooks_1 = require("@orderly.network/hooks");
exports.Summary = (0, react_1.memo)((props) => {
    const { nativeToken, depositFee = 0n } = props;
    const { data: symbolPrice } = (0, hooks_1.useIndexPrice)(`SPOT_${nativeToken?.symbol}_USDC`);
    const dstGasFee = new utils_1.Decimal(depositFee.toString())
        ?.div(new utils_1.Decimal(10).pow(18))
        .toString();
    const feeAmount = `${new utils_1.Decimal(dstGasFee).toFixed((0, utils_2.feeDecimalsOffset)(4), utils_1.Decimal.ROUND_UP)} ${nativeToken?.symbol}`;
    // Using useMemo causes a delay in data display
    const getFeeElement = () => {
        const totalFee = new utils_1.Decimal(dstGasFee)
            ?.mul(symbolPrice || 0)
            ?.toFixed(3, utils_1.Decimal.ROUND_UP);
        return `Fee ≈ $ ${totalFee || 0} ${Number(depositFee) ? `(${feeAmount})` : ""}`;
    };
    const onShowFee = (0, react_1.useCallback)(() => {
        const message = [];
        let dstGasFee = new utils_1.Decimal(depositFee.toString())
            ?.div(new utils_1.Decimal(10).pow(18))
            .toString();
        if (dstGasFee) {
            message.push((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsxs)("div", { children: ["Destination gas fee:", (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast/60 orderly-mx-2", children: feeAmount })] }), (0, jsx_runtime_1.jsx)("div", { children: "Additional gas tokens are required to cover operations on the destination chain." }), (0, jsx_runtime_1.jsx)(divider_1.Divider, {})] }));
        }
        modal_1.modal.alert({
            title: "Fee",
            message: ((0, jsx_runtime_1.jsx)("div", { className: "orderly-text-base-contrast/30 orderly-space-y-3 orderly-text-3xs desktop:orderly-text-xs", children: message })),
        });
    }, [nativeToken?.symbol, props.src?.symbol, depositFee]);
    return ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex-1 orderly-text-4xs orderly-text-base-contrast-36 desktop:orderly-text-3xs", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-flex orderly-items-center orderly-justify-between", children: (0, jsx_runtime_1.jsx)("div", { children: `1 ${props.src?.symbol || "USDC"} = ${props.price
                        ? (0, num_1.parseNumber)(props.price, {
                            precision: 3,
                            rule: "price",
                        })
                        : "-"} ${props.dst.symbol || "USDC"}` }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-mt-1 orderly-inline-flex orderly-items-center", onClick: onShowFee, children: [(0, jsx_runtime_1.jsx)(icon_1.InfoIcon, { size: 14, className: "orderly-mr-1" }), (0, jsx_runtime_1.jsx)("span", { children: getFeeElement() })] })] }));
});
//# sourceMappingURL=summary.js.map