"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDataSource = void 0;
const react_1 = require("react");
const types_1 = require("./shared/types");
const utils_1 = require("./utils");
const useDataSource = (data) => {
    const [searchKey, setSearchKey] = (0, react_1.useState)("");
    const [sortCondition, setSortCondition] = (0, react_1.useState)({});
    const onSearch = (key) => {
        setSearchKey(key);
    };
    const onSort = (key) => {
        setSortCondition(key);
    };
    const dataSource = (0, react_1.useMemo)(() => {
        let formattedData = [...(data ?? [])];
        if (searchKey) {
            formattedData = formattedData?.filter((item) => new RegExp(searchKey, "i").test(item.symbol));
        }
        if (typeof sortCondition.key !== "undefined" && sortCondition.direction !== 0) {
            formattedData?.sort(utils_1.sortFunc[sortCondition.key](sortCondition.direction ?? types_1.SortDirection.ASC));
        }
        return formattedData;
    }, [data, searchKey, sortCondition.key, sortCondition.direction]);
    return [
        dataSource,
        {
            searchKey,
            onSearch,
            onSort,
        },
    ];
};
exports.useDataSource = useDataSource;
//# sourceMappingURL=useDataSource.js.map