"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GetTestUSDC = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const lucide_react_1 = require("lucide-react");
const hooks_1 = require("@orderly.network/hooks");
const react_1 = require("react");
const modal_1 = require("../../modal");
const toast_1 = require("../../toast");
const localStorageItem = "Orderly_GetTestUSDC";
const GetTestUSDC = () => {
    const { account, state } = (0, hooks_1.useAccount)();
    const { configStore } = (0, react_1.useContext)(hooks_1.OrderlyContext);
    const [show, setShow] = (0, react_1.useState)(false);
    const config = (0, hooks_1.useConfig)();
    (0, react_1.useEffect)(() => {
        const value = localStorage.getItem(`${localStorageItem}_${state.accountId}`);
        if (!value) {
            setShow(() => true);
        }
    }, []);
    const [getTestUSDC, { isMutating }] = (0, hooks_1.useMutation)(`${config.get("operatorUrl")}/v1/faucet/usdc`);
    const onCloseClick = (0, react_1.useCallback)(() => {
        setShow(false);
        localStorage.setItem(`${localStorageItem}_${state.accountId}`, "1");
    }, []);
    const onGetClick = (0, react_1.useCallback)((event) => {
        event.preventDefault();
        const toastId = toast_1.toast.loading("Getting test USDC...");
        if (!account || !account.wallet) {
            return;
        }
        getTestUSDC({
            chain_id: account.wallet.chainId.toString(),
            user_address: state.address,
            broker_id: configStore.get("brokerId"),
        })
            .then((res) => {
            if (res.success) {
                toast_1.toast.dismiss(toastId);
                return modal_1.modal.confirm({
                    title: "Get test USDC",
                    content: "1,000 USDC will be added to your balance. Please note this may take up to 3 minutes. Please check back later.",
                    onOk: () => {
                        return Promise.resolve();
                    },
                });
            }
            else {
                return Promise.reject(res);
            }
        })
            .catch((err) => {
            toast_1.toast.dismiss(toastId);
            err.message && toast_1.toast.error(err.message);
        });
    }, [state]);
    if (!show) {
        return null;
    }
    return ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between orderly-items-center orderly-fixed orderly-left-0 orderly-right-0 orderly-bottom-[64px] orderly-h-[40px] orderly-bg-base-700 orderly-z-20 orderly-px-2 orderly-animate-in orderly-fade-in", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-text-3xs orderly-text-base-contrast/50 orderly-cursor-pointer", children: [(0, jsx_runtime_1.jsx)("span", { className: "orderly-text-primary-light", onClick: onGetClick, children: "Get test USDC" }), " ", "and start trading!"] }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-p-2", children: (0, jsx_runtime_1.jsx)("button", { className: "orderly-w-[16px] orderly-h-[16px] orderly-rounded-full orderly-bg-primary-light orderly-flex orderly-justify-center orderly-items-center", onClick: onCloseClick, children: (0, jsx_runtime_1.jsx)(lucide_react_1.X, { size: 14, className: "orderly-text-base-100" }) }) })] }));
};
exports.GetTestUSDC = GetTestUSDC;
//# sourceMappingURL=getTestUSDC.js.map