"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderEntry = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const button_1 = __importDefault(require("../../button"));
const text_1 = require("../../text");
const input_1 = require("../../input");
const slider_1 = require("../../slider");
const divider_1 = require("../../divider");
const orderOptions_1 = require("./sections/orderOptions");
const hooks_1 = require("@orderly.network/hooks");
const types_1 = require("@orderly.network/types");
const modal_1 = require("../../modal");
const orderConfirmView_new_1 = require("./sections/orderConfirmView.new");
const toast_1 = require("../../toast");
const statusGuardButton_1 = require("../../button/statusGuardButton");
const utils_1 = require("@orderly.network/utils");
const mSelect_1 = require("../../select/mSelect");
const css_1 = require("../../utils/css");
const utils_2 = require("../../slider/utils");
const freeCollat_1 = require("./sections/freeCollat");
const setInfo_1 = require("./sections/setInfo");
const { Segmented: SegmentedButton } = button_1.default;
var InputType;
(function (InputType) {
    InputType[InputType["PRICE"] = 0] = "PRICE";
    InputType[InputType["TRIGGER_PRICE"] = 1] = "TRIGGER_PRICE";
    InputType[InputType["QUANTITY"] = 2] = "QUANTITY";
    InputType[InputType["TOTAL"] = 3] = "TOTAL";
    InputType[InputType["NONE"] = 4] = "NONE";
})(InputType || (InputType = {}));
exports.OrderEntry = (0, react_1.forwardRef)((props, ref) => {
    const { freeCollateral, symbolConfig, maxQty, symbol, 
    // side,
    // onSideChange,
    // onReduceOnlyChange,
    metaState, formattedOrder, helper, disabled, markPrice, } = props;
    const { side, isStopOrder } = formattedOrder;
    // const totalInputFocused = useRef<boolean>(false);
    // const priceInputFocused = useRef<boolean>(false);
    const quantityInputFocused = (0, react_1.useRef)(false);
    const [errorsVisible, setErrorsVisible] = (0, react_1.useState)(false);
    const isClickForm = (0, react_1.useRef)(false);
    const currentFocusInput = (0, react_1.useRef)(InputType.NONE);
    const priceInputRef = (0, react_1.useRef)(null);
    const triggerPriceInputRef = (0, react_1.useRef)(null);
    const isTablet = (0, hooks_1.useMediaQuery)(types_1.MEDIA_TABLET);
    const [needConfirm, setNeedConfirm] = (0, hooks_1.useLocalStorage)("orderly_order_confirm", true);
    const ee = (0, hooks_1.useEventEmitter)();
    const isMarketOrder = [types_1.OrderType.MARKET, types_1.OrderType.STOP_MARKET].includes(formattedOrder.order_type || types_1.OrderType.LIMIT);
    (0, react_1.useEffect)(() => {
        // handle orderbook item click event
        const orderbookItemClickHandler = (item) => {
            if (currentFocusInput.current === InputType.TRIGGER_PRICE) {
                if (formattedOrder.order_type === types_1.OrderType.STOP_LIMIT ||
                    formattedOrder.order_type === types_1.OrderType.STOP_MARKET) {
                    props.onFieldChange("trigger_price", item[0].toString());
                    focusInputElement(triggerPriceInputRef.current);
                }
            }
            else {
                if (formattedOrder.order_type === types_1.OrderType.STOP_LIMIT ||
                    formattedOrder.order_type === types_1.OrderType.LIMIT) {
                    props.onFieldChange("order_price", item[0].toString());
                    focusInputElement(priceInputRef.current);
                }
                else {
                    // other order type
                    let newType;
                    if (formattedOrder.order_type === types_1.OrderType.STOP_MARKET) {
                        newType = types_1.OrderType.STOP_LIMIT;
                    }
                    else if (formattedOrder.order_type === types_1.OrderType.MARKET) {
                        newType = types_1.OrderType.LIMIT;
                    }
                    if (typeof newType !== "undefined") {
                        props.onFieldChange("order_type", newType);
                    }
                    props.onFieldChange("order_price", item[0].toString());
                    focusInputElement(priceInputRef.current);
                }
            }
            // if (formattedOrder.order_type === OrderType.STOP_LIMIT) {
            //   if (currentFocusInput.current === InputType.TRIGGER_PRICE) {
            //     // newType = OrderType.LIMIT;
            //     props.onFieldChange("trigger_price", item[0].toString());
            //     focusInputElement(triggerPriceInputRef.current);
            //   } else {
            //     props.onFieldChange("order_price", item[0].toString());
            //     focusInputElement(priceInputRef.current);
            //   }
            // } else {
            //   let newType;
            //   // if (formattedOrder.order_type === OrderType.STOP_MARKET) {
            //   //   newType = OrderType.STOP_LIMIT;
            //   // } else if (formattedOrder.order_type === OrderType.MARKET) {
            //   //   newType = OrderType.LIMIT;
            //   // }
            //   if (typeof newType !== "undefined") {
            //     props.onFieldChange("order_type", newType);
            //   }
            //   props.onFieldChange("order_price", item[0].toString());
            //   focusInputElement(priceInputRef.current);
            // }
            function focusInputElement(target) {
                setTimeout(() => {
                    target?.focus();
                }, 0);
            }
        };
        ee.on("orderbook:item:click", orderbookItemClickHandler);
        return () => {
            ee.off("orderbook:item:click", orderbookItemClickHandler);
        };
    }, [formattedOrder.order_type]);
    const [buttonText, setButtonText] = (0, react_1.useState)("Buy / Long");
    const isTable = (0, hooks_1.useMediaQuery)(types_1.MEDIA_TABLET);
    const onFocus = (type) => (_) => {
        currentFocusInput.current = type;
    };
    const onBlur = (type) => (_) => {
        setTimeout(() => {
            if (currentFocusInput.current !== type)
                return;
            currentFocusInput.current = InputType.NONE;
        }, 300);
    };
    const onSubmit = (event) => {
        //
        event.preventDefault();
        if (!symbolConfig) {
            return Promise.reject("symbolConfig is null");
        }
        return Promise.resolve()
            .then(() => {
            if (metaState.errors?.order_price?.message ||
                metaState.errors?.order_quantity?.message ||
                metaState.errors?.trigger_price?.message) {
                setErrorsVisible(true);
                return Promise.reject("cancel");
            }
            if (needConfirm) {
                return modal_1.modal.confirm({
                    maxWidth: "sm",
                    title: "Confirm Order",
                    onCancel: () => {
                        return Promise.reject("cancel");
                    },
                    footer: !isTable ? ((0, jsx_runtime_1.jsx)(orderConfirmView_new_1.OrderConfirmFooter, { onCancel: () => {
                            return Promise.reject("cancel");
                        } })) : undefined,
                    content: ((0, jsx_runtime_1.jsx)(orderConfirmView_new_1.OrderConfirmView, { order: {
                            ...formattedOrder,
                            side: side,
                            symbol: props.symbol,
                        }, symbol: symbol, base: symbolConfig?.base, quote: symbolConfig?.quote, isTable: isTable })),
                });
            }
            else {
                return Promise.resolve(true);
            }
        })
            .then((isOk) => {
            return props.submit().then((res) => {
                // props.setValues({
                //   trigger_price: "",
                //   order_price: "",
                //   order_quantity: "",
                //   total: "",
                // });
                // resetForm?.();
            }, (err) => {
                if (typeof err === "string") {
                    toast_1.toast.error(err);
                }
                else if (err.name === "ApiError") {
                    toast_1.toast.error(err.message);
                }
                else {
                    console.log("Create order failed:", err);
                    toast_1.toast.error(err?.message);
                }
            });
        })
            .catch((error) => {
            if (error !== "cancel" && !!error?.message) {
                toast_1.toast.error(error.message || "Failed");
            }
        });
    };
    const onDeposit = (0, react_1.useCallback)((event) => {
        event.preventDefault();
        props.onDeposit?.();
    }, []);
    (0, react_1.useEffect)(() => {
        if (side === types_1.OrderSide.BUY) {
            setButtonText("Buy / Long");
        }
        else {
            setButtonText("Sell / Short");
        }
        // methods.setValue("side", side);
        // methods.clearErrors();
    }, [side]);
    //
    const totalAmount = (0, react_1.useMemo)(() => {
        const quantity = formattedOrder.order_quantity;
        const type = formattedOrder.order_type;
        if (!markPrice ||
            (type !== types_1.OrderType.MARKET && type !== types_1.OrderType.STOP_MARKET) ||
            currentFocusInput.current === InputType.TOTAL ||
            !quantity) {
            return formattedOrder.total;
        }
        return new utils_1.Decimal(quantity).mul(markPrice).todp(2).toString();
    }, [
        markPrice,
        formattedOrder.total,
        formattedOrder.order_quantity,
        formattedOrder.order_type,
    ]);
    (0, react_1.useEffect)(() => {
        function handleClick() {
            // When the user clicks outside the form area, hide the error message
            if (!isClickForm.current) {
                setErrorsVisible(false);
            }
            isClickForm.current = false;
        }
        document.body.addEventListener("click", handleClick);
        return () => {
            document.body.removeEventListener("click", handleClick);
        };
    }, []);
    return (
    // @ts-ignore
    (0, jsx_runtime_1.jsx)("form", { onSubmit: onSubmit, onClick: () => {
            isClickForm.current = true;
        }, id: "orderEntryForm", children: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-flex-col orderly-gap-3 orderly-text-3xs", children: [(0, jsx_runtime_1.jsx)(SegmentedButton, { buttons: [
                        {
                            label: "Buy",
                            value: types_1.OrderSide.BUY,
                            disabled,
                            activeClassName: "orderly-bg-trade-profit orderly-text-base-contrast after:orderly-bg-trade-profit orderly-font-bold desktop:orderly-font-bold",
                            disabledClassName: "orderly-bg-base-400 orderly-text-base-contrast-20 after:orderly-bg-base-400 orderly-cursor-not-allowed orderly-font-bold desktop:orderly-font-bold",
                        },
                        {
                            label: "Sell",
                            value: types_1.OrderSide.SELL,
                            disabled,
                            activeClassName: "orderly-bg-trade-loss orderly-text-base-contrast after:orderly-bg-trade-loss orderly-font-bold desktop:orderly-font-bold",
                            disabledClassName: "orderly-bg-base-400 orderly-text-base-contrast-20 after:orderly-bg-base-400 orderly-cursor-not-allowed orderly-font-bold desktop:orderly-font-bold",
                        },
                    ], onChange: (value) => {
                        // onSideChange?.(value as OrderSide);
                        setErrorsVisible(false);
                        props.onFieldChange("side", value);
                    }, value: side }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between orderly-items-center", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-gap-1 orderly-text-base-contrast-54 orderly-text-4xs desktop:orderly-text-3xs", children: [(0, jsx_runtime_1.jsx)(freeCollat_1.FreeCollat, {}), (0, jsx_runtime_1.jsx)(text_1.Numeral, { rule: "price", className: "orderly-text-base-contrast-80", precision: 0, children: `${freeCollateral ?? "--"}` }), !isTable && ((0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-36", children: "USDC" }))] }), (0, jsx_runtime_1.jsx)(button_1.default, { id: "orderly-order-entry-deposit-button", variant: "text", size: "small", type: "button", onClick: onDeposit, className: "orderly-text-link orderly-text-4xs", children: "Deposit" })] }), (0, jsx_runtime_1.jsx)(mSelect_1.MSelect, { label: "Order Type", value: formattedOrder.order_type, className: "orderly-bg-base-600 orderly-font-semibold", color: side === types_1.OrderSide.BUY ? "buy" : "sell", fullWidth: true, options: [
                        { label: "Limit order", value: "LIMIT" },
                        { label: "Market order", value: "MARKET" },
                        { label: "Stop limit", value: "STOP_LIMIT" },
                        { label: "Stop market", value: "STOP_MARKET" },
                    ], onChange: (value) => {
                        // field.onChange(value);
                        // methods.setValue("order_price", "", {
                        //   shouldValidate: false,
                        // });
                        // methods.clearErrors();
                        props.onFieldChange("order_type", value);
                    } }), isStopOrder && ((0, jsx_runtime_1.jsx)(input_1.Input, { disabled: disabled, ref: triggerPriceInputRef, prefix: "Trigger", suffix: symbolConfig?.quote, type: "text", inputMode: "decimal", id: "order_trigger_price_input", name: "order_trigger_price_input", autoComplete: "off", error: !!metaState.errors?.trigger_price && errorsVisible, helpText: metaState.errors?.trigger_price?.message, className: "orderly-text-right orderly-font-semibold", value: (0, utils_1.commify)(formattedOrder.trigger_price || ""), containerClassName: "orderly-bg-base-600", onChange: (event) => {
                        // field.onChange(event.target.value);
                        props.onFieldChange("trigger_price", event.target.value);
                    }, onFocus: onFocus(InputType.TRIGGER_PRICE), onBlur: onBlur(InputType.TRIGGER_PRICE) })), (0, jsx_runtime_1.jsx)(input_1.Input, { disabled: disabled, ref: priceInputRef, prefix: "Price", suffix: symbolConfig?.quote, type: "text", inputMode: "decimal", id: "order_price_input", name: "order_price_input", error: !!metaState.errors?.order_price && errorsVisible, helpText: metaState.errors?.order_price?.message, className: "orderly-text-right orderly-font-semibold", autoComplete: "off", value: isMarketOrder
                        ? "Market"
                        : (0, utils_1.commify)(formattedOrder.order_price || ""), containerClassName: isMarketOrder ? "orderly-bg-base-700" : "orderly-bg-base-600", readOnly: isMarketOrder, onChange: (event) => {
                        // field.onChange(event.target.value);
                        props.onFieldChange("order_price", event.target.value);
                    }, onFocus: onFocus(InputType.PRICE), onBlur: onBlur(InputType.PRICE) }), (0, jsx_runtime_1.jsx)(input_1.Input, { disabled: disabled, prefix: "Quantity", type: "text", inputMode: "decimal", suffix: symbolConfig?.base, id: "order_quantity_input", name: "order_quantity_input", className: "orderly-text-right", containerClassName: "orderly-bg-base-600", error: !!metaState.errors?.order_quantity && errorsVisible, helpText: metaState.errors?.order_quantity?.message, autoComplete: "off", value: (0, utils_1.commify)(formattedOrder.order_quantity || ""), onChange: (event) => {
                        props.onFieldChange("order_quantity", event.target.value);
                    }, onFocus: onFocus(InputType.QUANTITY), onBlur: onBlur(InputType.QUANTITY) }), (0, jsx_runtime_1.jsx)(slider_1.Slider, { color: side === types_1.OrderSide.BUY ? "buy" : "sell", markLabelVisible: false, min: 0, max: maxQty === 0 ? 1 : maxQty, markCount: 4, disabled: maxQty === 0, step: symbolConfig?.["base_tick"], value: [Number(formattedOrder.order_quantity ?? 0)], onValueChange: (value) => {
                        //
                        if (typeof value[0] !== "undefined") {
                            props.onFieldChange("order_quantity", value[0]);
                        }
                    } }), (0, jsx_runtime_1.jsxs)("div", { className: (0, css_1.cn)("orderly-hidden desktop:orderly-flex orderly-justify-between -orderly-mt-2", {
                        "orderly-text-trade-profit": side === types_1.OrderSide.BUY,
                        "orderly-text-trade-loss": side === types_1.OrderSide.SELL,
                    }), children: [(0, jsx_runtime_1.jsxs)("span", { children: [Number((0, utils_2.convertValueToPercentage)(Number(formattedOrder.order_quantity ?? 0), 0, maxQty).toFixed()), "%"] }), (0, jsx_runtime_1.jsxs)("button", { type: "button", className: "orderly-flex orderly-items-center orderly-gap-1 orderly-tabular-nums", onClick: () => {
                                props.onFieldChange("order_quantity", maxQty);
                            }, children: [(0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-54", children: formattedOrder.side === types_1.OrderSide.BUY ? "Max buy" : "Max sell" }), (0, jsx_runtime_1.jsx)(text_1.Numeral, { precision: 4, children: maxQty })] })] }), (0, jsx_runtime_1.jsx)(input_1.Input, { disabled: disabled, className: "orderly-text-right", containerClassName: "orderly-bg-base-600", prefix: "Total ≈", suffix: symbolConfig?.quote, type: "text", inputMode: "decimal", id: "order_total_input", name: "order_total_input", autoComplete: "off", autoFocus: false, value: (0, utils_1.commify)(currentFocusInput.current === InputType.TOTAL
                        ? formattedOrder.total
                        : totalAmount), onFocus: onFocus(InputType.TOTAL), onBlur: onBlur(InputType.TOTAL), onChange: (event) => {
                        // field.onChange(event.target.value);
                        props.onFieldChange("total", event.target.value);
                    } }), !isTablet && ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(divider_1.Divider, {}), (0, jsx_runtime_1.jsx)(setInfo_1.EstInfo, { estLiqPrice: props.estLiqPrice, precision: symbolConfig?.quote_dp, estLeverage: props.estLeverage })] })), (0, jsx_runtime_1.jsx)(divider_1.Divider, {}), (0, jsx_runtime_1.jsx)(orderOptions_1.OrderOptions, { formattedOrder: formattedOrder, showConfirm: needConfirm, onConfirmChange: setNeedConfirm, onReduceOnlyChange: (value) => props.onFieldChange("reduce_only", value), reduceOnly: formattedOrder.reduce_only, onFieldChange: props.onFieldChange }), (0, jsx_runtime_1.jsx)(statusGuardButton_1.StatusGuardButton, { children: (0, jsx_runtime_1.jsx)(button_1.default, { id: "orderly-order-entry-confirm-button", className: "orderly-text-xs desktop:orderly-font-bold desktop:orderly-text-sm", type: "submit", loading: props.submitting, color: side === types_1.OrderSide.BUY ? "buy" : "sell", fullWidth: true, children: buttonText }) })] }) }));
});
//# sourceMappingURL=index.js.map