"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderConfirmFooter = exports.OrderConfirmView = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const types_1 = require("@orderly.network/types");
const react_1 = require("react");
const text_1 = require("../../../text");
const icon_1 = require("../../../icon");
const checkbox_1 = require("../../../checkbox");
const hooks_1 = require("@orderly.network/hooks");
const label_1 = require("../../../label");
const button_1 = __importDefault(require("../../../button"));
const utils_1 = require("../../../utils");
const modal_1 = require("../../../modal");
const utils_2 = require("@orderly.network/utils");
const OrderConfirmView = (props) => {
    const { order, quote = "USDC", base } = props;
    const type = (0, react_1.useMemo)(() => {
        const type = (type) => {
            switch (type) {
                case types_1.OrderType.LIMIT:
                    return "Limit";
                case types_1.OrderType.MARKET:
                    return "Market";
                case types_1.OrderType.STOP_LIMIT:
                    return "Stop Limit";
                case types_1.OrderType.STOP_MARKET:
                    return "Stop Market";
            }
        };
        if (order.side === types_1.OrderSide.BUY) {
            return (0, jsx_runtime_1.jsx)(text_1.Text, { type: "buy", children: `${type(order.order_type)} Buy` });
        }
        return (0, jsx_runtime_1.jsx)(text_1.Text, { type: "sell", children: `${type(order.order_type)} Sell` });
    }, [order.side, order.order_type]);
    const priceNode = (0, react_1.useMemo)(() => {
        if (order.order_type === types_1.OrderType.MARKET ||
            order.order_type === types_1.OrderType.STOP_MARKET) {
            return (0, jsx_runtime_1.jsx)("span", { children: "Market" });
        }
        return ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-inline-block", children: [(0, jsx_runtime_1.jsx)("span", { children: (0, utils_2.commify)(order.order_price || "") }), (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-36 orderly-ml-1", children: quote })] }));
    }, [order]);
    return ((0, jsx_runtime_1.jsxs)("div", { children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center orderly-pb-4", children: [(0, jsx_runtime_1.jsx)(icon_1.NetworkImage, { symbol: props.symbol, type: "symbol", size: 20 }), (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-lg orderly-pl-2", children: `${base}-PERP` })] }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-text-base-contract-54 orderly-text-xs desktop:orderly-text-sm orderly-font-semibold", children: [(0, jsx_runtime_1.jsx)("div", { children: (0, jsx_runtime_1.jsx)("div", { className: "orderly-mr-3 orderly-w-[89px] desktop:orderly-w-[180px]", children: type }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex-1 orderly-gap-2", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between orderly-mb-1", children: [(0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-54", children: "Qty." }), (0, jsx_runtime_1.jsx)("span", { className: (0, utils_1.cn)(order.side === types_1.OrderSide.BUY
                                            ? "orderly-text-trade-profit"
                                            : "orderly-text-trade-loss"), children: (0, utils_2.commify)(order.order_quantity || "") })] }), order.isStopOrder === true && ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between orderly-mb-1", children: [(0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-54", children: "Trigger" }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-inline-block", children: [(0, jsx_runtime_1.jsx)("span", { children: (0, utils_2.commify)(order.trigger_price || "") }), (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-36 orderly-ml-1", children: quote })] })] })), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between orderly-mb-1", children: [(0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-54", children: "Price" }), priceNode] }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-between orderly-mb-1", children: [(0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-54", children: "Est. Total" }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-inline-block", children: [(0, jsx_runtime_1.jsx)("span", { children: (0, utils_2.commify)(order.total || "") }), (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-36 orderly-ml-1", children: quote })] })] })] })] }), props.isTable ? (0, jsx_runtime_1.jsx)(OrderConfirmCheckBox, {}) : undefined] }));
};
exports.OrderConfirmView = OrderConfirmView;
const OrderConfirmCheckBox = (props) => {
    const [needConfirm, setNeedConfirm] = (0, hooks_1.useLocalStorage)("orderly_order_confirm", true);
    return ((0, jsx_runtime_1.jsxs)("div", { className: (0, utils_1.cn)("orderly-flex orderly-items-center orderly-gap-2 orderly-pt-3", props.className), children: [(0, jsx_runtime_1.jsx)(checkbox_1.Checkbox, { id: "orderConfirm", checked: !needConfirm, onCheckedChange: (checked) => {
                    console.log("checked", checked);
                    setNeedConfirm(!!!checked);
                } }), (0, jsx_runtime_1.jsx)(label_1.Label, { htmlFor: "showAll", className: "orderly-text-base-contrast-54 orderly-text-3xs", onClick: () => {
                    setNeedConfirm(!needConfirm);
                }, children: "Disable order confirmation" })] }));
};
const OrderConfirmFooter = (props) => {
    const { visible, hide, resolve, reject, onOpenChange } = (0, modal_1.useModal)();
    const [loading, setLoading] = (0, react_1.useState)(false);
    return ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-gap-2 orderly-px-5", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-flex-1 orderly-items-center orderly-h-[32px]", children: (0, jsx_runtime_1.jsx)(OrderConfirmCheckBox, { className: "orderly-pt-[6px]" }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex-1 orderly-flex orderly-gap-3 orderly-grid-cols-2", children: [(0, jsx_runtime_1.jsx)(button_1.default, { className: "orderly-confirm-dialog-cancal-button orderly-h-[32px] orderly-text-xs desktop:orderly-text-xs orderly-font-bold", type: "button", variant: "contained", color: "tertiary", loading: loading, onClick: () => {
                            return props
                                .onCancel?.()
                                .then((data) => data, (reason) => {
                                reject(reason);
                            })
                                .finally(() => hide());
                        }, fullWidth: true, children: "Cancel" }, "cancel"), (0, jsx_runtime_1.jsx)(button_1.default, { className: "orderly-confirm-dialog-ok-button orderly-h-[32px] orderly-text-xs desktop:orderly-text-xs orderly-font-bold", type: "button", disabled: loading, loading: loading, fullWidth: true, onClick: () => {
                            return Promise.resolve()
                                .then(() => {
                                if (typeof props.onOk === "function") {
                                    return props.onOk();
                                }
                                return true;
                            })
                                .then((data) => {
                                resolve(data);
                                hide();
                            });
                        }, children: "Confirm" }, "ok")] })] }));
};
exports.OrderConfirmFooter = OrderConfirmFooter;
//# sourceMappingURL=orderConfirmView.new.js.map