"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DesktopOrderBookCell = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const cellBar_1 = require("../cellBar");
const orderContext_1 = require("../../../block/orderbook/orderContext");
const utils_1 = require("@orderly.network/utils");
const num_1 = require("../../../utils/num");
const numeral_1 = require("../../../text/numeral");
const provider_1 = require("../../../provider");
const utils_2 = require("../../../utils");
const types_1 = require("../types");
const DesktopOrderBookCell = (props) => {
    const { cellHeight, showTotal, onItemClick, depth, pendingOrders } = (0, react_1.useContext)(orderContext_1.OrderBookContext);
    const { base_dp, quote_dp } = (0, react_1.useContext)(provider_1.SymbolContext);
    const width = Number.isNaN(props.price)
        ? 0
        : (props.accumulated / props.count) * 100;
    const dp = (0, react_1.useMemo)(() => {
        return typeof depth === "number" ? (0, utils_1.getPrecisionByNumber)(depth) : quote_dp;
    }, [depth, quote_dp]);
    const totalAmount = Number.isNaN(props.accumulated)
        ? "-"
        : props.accumulatedAmount?.toString();
    const isPendingOrder = (0, react_1.useMemo)(() => {
        const priceStr = (0, num_1.parseNumber)(props.price, { precision: dp, padding: true });
        const index = pendingOrders.findIndex((item) => priceStr === (0, num_1.parseNumber)(item, { precision: dp, padding: true }));
        return index !== -1;
    }, [pendingOrders, props.price, depth]);
    return ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-flex-row orderly-tabular-nums orderly-justify-between orderly-text-base-contrast-80 orderly-text-3xs orderly-relative orderly-cursor-pointer", style: { height: `${cellHeight}px` }, onClick: () => {
            if (Number.isNaN(props.price) || Number.isNaN(props.quantity))
                return;
            onItemClick?.([props.price, props.quantity]);
        }, onMouseEnter: props.onMouseEnter, onMouseLeave: props.onMouseLeave, children: [(0, jsx_runtime_1.jsxs)("div", { className: (0, utils_2.cn)("orderly-basis-7/12 orderly-flex orderly-felx-row orderly-items-center orderly-mr-2", showTotal && "orderly-basis-5/12"), children: [(0, jsx_runtime_1.jsx)("div", { className: (0, utils_2.cn)("orderly-flex-1 orderly-text-left", props.type === types_1.OrderBookCellType.ASK
                            ? "orderly-text-trade-loss"
                            : "orderly-text-trade-profit"), children: (0, jsx_runtime_1.jsx)(numeral_1.Numeral, { precision: dp, children: props.price }) }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-flex-1 orderly-text-right orderly-text-base-contrast-80", children: (0, jsx_runtime_1.jsx)(numeral_1.Numeral, { precision: base_dp, children: props.quantity }) })] }), (0, jsx_runtime_1.jsxs)("div", { className: (0, utils_2.cn)("orderly-basis-5/12 orderly-flex orderly-items-center orderly-fex-row orderly-overflow-hidden orderly-relative", showTotal && "orderly-basis-7/12"), children: [(0, jsx_runtime_1.jsx)("div", { className: (0, utils_2.cn)("orderly-flex-1 orderly-pr-6 orderly-text-right", showTotal && "orderly-pr-3"), children: (0, jsx_runtime_1.jsx)(numeral_1.Numeral, { precision: base_dp, className: "orderly-z-10", children: props.accumulated }) }), showTotal && ((0, jsx_runtime_1.jsx)("div", { className: "orderly-flex-1 orderly-text-right orderly-pr-3", children: (0, jsx_runtime_1.jsx)(numeral_1.Numeral, { precision: 2, className: "orderly-z-10", children: totalAmount }) })), (0, jsx_runtime_1.jsx)(cellBar_1.CellBar, { width: width, direction: cellBar_1.CellBarDirection.LEFT_TO_RIGHT, className: props.type === types_1.OrderBookCellType.ASK
                            ? "orderly-bg-trade-loss/10"
                            : "orderly-bg-trade-profit/10" })] }), isPendingOrder && ((0, jsx_runtime_1.jsx)("div", { className: (0, utils_2.cn)("orderly-absolute orderly-rounded-full orderly-left-[-8px] orderly-h-[4px] orderly-w-[4px] orderly-pointer-events-none", props.type === types_1.OrderBookCellType.ASK && "orderly-bg-trade-loss", props.type === types_1.OrderBookCellType.BID && "orderly-bg-trade-profit"), style: { top: `${cellHeight / 2 - 2}px` } })), props.isHover && ((0, jsx_runtime_1.jsx)("div", { className: "orderly-absolute orderly-bg-white orderly-left-0 orderly-right-0 orderly-top-0 orderly-bottom-0 orderly-opacity-10" }))] }));
};
exports.DesktopOrderBookCell = DesktopOrderBookCell;
//# sourceMappingURL=cell.desktop.js.map