"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DesktopListBox = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const cell_desktop_1 = require("./cell.desktop");
const orderContext_1 = require("../orderContext");
const types_1 = require("../types");
const react_tooltip_1 = require("@radix-ui/react-tooltip");
const provider_1 = require("../../../provider");
const text_1 = require("../../../text");
const DesktopListBox = (props) => {
    const { data, type } = props;
    const { depth } = (0, react_1.useContext)(orderContext_1.OrderBookContext);
    const { base, quote, base_dp, quote_dp } = (0, react_1.useContext)(provider_1.SymbolContext);
    const findMaxItem = (0, react_1.useCallback)(() => {
        if ((data?.length || 0) === 0) {
            return null;
        }
        if (type === types_1.OrderBookCellType.ASK) {
            const index = data.findIndex((item) => !Number.isNaN(item[0]));
            if (index != -1) {
                return data[index];
            }
            return null;
        }
        else {
            for (let index = data.length - 1; index >= 0; index--) {
                const item = data[index];
                if (!Number.isNaN(item[0])) {
                    return item;
                }
            }
            return null;
        }
    }, [data, type]);
    const priceDp = (0, react_1.useMemo)(() => {
        if (depth?.toString().includes(".")) {
            return depth.toString().split(".")[1].length;
        }
        return 0;
    }, [depth]);
    const maxQty = (0, react_1.useMemo)(() => {
        return data.reduce((a, b) => Math.max(a, b[1]), 0);
    }, [data]);
    const [hoverIndex, setHoverIndex] = (0, react_1.useState)(-1);
    return (0, jsx_runtime_1.jsx)("div", { id: "orderly-order-book-list", className: "orderly-flex orderly-flex-col orderly-gap-[1px]", children: data.map((item, index) => {
            return ((0, jsx_runtime_1.jsx)(Tip, { index: index, item: item, countQty: props.countQty, setHoverIndex: setHoverIndex, hoverIndex: hoverIndex, type: type, maxQty: maxQty, base: base, quote: quote, priceDp: priceDp, baseDp: base_dp, quoteDp: quote_dp, findMaxItem: findMaxItem }, index));
        }) });
};
exports.DesktopListBox = DesktopListBox;
const Tip = (props) => {
    const { index, item, setHoverIndex, type, maxQty, hoverIndex, base, quote, priceDp, baseDp, quoteDp } = props;
    const isHover = hoverIndex !== -1 ? (type === types_1.OrderBookCellType.ASK ?
        index >= hoverIndex :
        index <= hoverIndex) : false;
    const [open, setOpen] = (0, react_1.useState)(false);
    const calcHintInfo = (item) => {
        if (item === null) {
            return {
                sumQty: 0,
                sumQtyAmount: 0,
                avgPrice: 0,
            };
        }
        let totalInfo = { sumQty: 0, sumQtyAmount: 0 };
        if (!Number.isNaN(item[2])) {
            totalInfo = {
                sumQty: item[2],
                sumQtyAmount: item[3]
            };
        }
        return {
            ...totalInfo,
            avgPrice: totalInfo.sumQtyAmount == 0 ? 0 : totalInfo.sumQtyAmount / totalInfo.sumQty
        };
    };
    let hintInfo = calcHintInfo(item);
    if (hintInfo.avgPrice === 0) {
        hintInfo = calcHintInfo(props.findMaxItem());
    }
    return ((0, jsx_runtime_1.jsxs)(react_tooltip_1.Tooltip, { open: open, onOpenChange: setOpen, children: [(0, jsx_runtime_1.jsx)(react_tooltip_1.TooltipTrigger, { children: (0, jsx_runtime_1.jsx)(cell_desktop_1.DesktopOrderBookCell, { background: "", price: item[0], quantity: item[1], accumulated: item[2], count: props.countQty, type: props.type, accumulatedAmount: item[3], maxQty: maxQty, isHover: isHover, onMouseEnter: () => {
                        setHoverIndex(index);
                        setOpen(true);
                    }, onMouseLeave: () => {
                        setHoverIndex(-1);
                        setOpen(false);
                    } }) }), (0, jsx_runtime_1.jsxs)(react_tooltip_1.TooltipContent, { className: "orderly-max-w-[400px] orderly-w-full orderly-text-3xs orderly-shadow-md orderly-rounded orderly-p-3 orderly-bg-base-700 orderly-animate-in orderly-fade-in-0 orderly-zoom-in-95 data-[state=closed]:orderly-animate-out data-[state=closed]:orderly-fade-out-0 data-[state=closed]:orderly-zoom-out-95 data-[side=bottom]:orderly-slide-in-from-top-2 data-[side=left]:orderly-slide-in-from-right-2 data-[side=right]:orderly-slide-in-from-left-2 data-[side=top]:orderly-slide-in-from-bottom-2", align: "center", side: "left", sideOffset: 12, onPointerEnter: (e) => e.preventDefault(), children: [(0, jsx_runtime_1.jsx)(Row, { title: "Avg. Price\u2248", content: hintInfo.avgPrice, contentDp: priceDp }), (0, jsx_runtime_1.jsx)(Row, { title: `Sum (${base})`, content: hintInfo.sumQty, contentDp: baseDp }), (0, jsx_runtime_1.jsx)(Row, { title: `Sum (${quote})`, content: hintInfo.sumQtyAmount, contentDp: quoteDp }), (0, jsx_runtime_1.jsx)(react_tooltip_1.TooltipArrow, { className: "orderly-fill-base-700" })] })] }));
};
const Row = (props) => {
    const { title, content, contentDp } = props;
    return ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-flex-row orderly-justify-between orderly-gap-4", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-text-base-contrast-36", children: title }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-text-right", children: (0, jsx_runtime_1.jsx)(text_1.Numeral, { precision: contentDp, children: content }) })] }));
};
//# sourceMappingURL=listBox.desktop.js.map