"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DesktopMarkPrice = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const provider_1 = require("../../../provider");
const text_1 = require("../../../text");
const css_1 = require("../../../utils/css");
const lucide_react_1 = require("lucide-react");
const react_1 = require("react");
const utils_1 = require("@orderly.network/utils");
const tooltip_1 = require("../../../tooltip");
const DesktopMarkPrice = (props) => {
    const { markPrice = 0, lastPrice, asks, bids } = props;
    return ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-py-1 orderly-flex orderly-justify-between orderly-text-xs orderly-text-base-contrast-80 desktop:orderly-h-[40px] desktop:orderly-text-[20px] desktop:orderly-justify-between orderly-tabular-nums", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-flex-1 orderly-flex-row orderly-gap-2", children: [(0, jsx_runtime_1.jsx)(Price, { markPrice: markPrice, lastPrice: lastPrice }), (0, jsx_runtime_1.jsx)(MarkPrice, { markPrice: markPrice })] }), (0, jsx_runtime_1.jsx)(Spread, { asks: asks, bids: bids })] }));
};
exports.DesktopMarkPrice = DesktopMarkPrice;
const Price = (props) => {
    const { markPrice = 0, lastPrice, } = props;
    const { quote_dp } = (0, react_1.useContext)(provider_1.SymbolContext);
    const [prevLastPrice, middlePrice] = lastPrice;
    return ((0, jsx_runtime_1.jsxs)("div", { className: (0, css_1.cn)("orderly-text-lg orderly-flex orderly-items-center desktop:orderly-font-normal", {
            "orderly-text-trade-profit": middlePrice > prevLastPrice,
            "orderly-text-trade-loss": middlePrice < prevLastPrice,
        }), children: [(0, jsx_runtime_1.jsx)(text_1.Numeral, { className: "orderly-font-bold", precision: quote_dp, children: middlePrice }), (0, jsx_runtime_1.jsx)(ArrowTopIcon, { size: 12, className: (0, css_1.cn)("orderly-ml-1", {
                    "orderly-rotate-180": middlePrice < prevLastPrice,
                    "orderly-fill-trade-profit": middlePrice > prevLastPrice,
                    "orderly-fill-trade-loss": middlePrice < prevLastPrice,
                    "orderly-fill-transparent": middlePrice === prevLastPrice
                }) })] }));
};
const MarkPrice = (props) => {
    const { quote_dp } = (0, react_1.useContext)(provider_1.SymbolContext);
    return ((0, jsx_runtime_1.jsx)(tooltip_1.Tooltip, { content: "Obtained from a third-party oracle, the mark price is calculated as the median of three prices: the last price, the fair price based on the funding rate basis, and the fair price based on the order books.", className: "orderly-max-w-[270px]", children: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center orderly-text-3xs desktop:orderly-text-2xs orderly-cursor-pointer", children: [(0, jsx_runtime_1.jsx)(lucide_react_1.Flag, { size: 14, className: "orderly-text-yellow-400" }), (0, jsx_runtime_1.jsx)(text_1.Numeral, { precision: quote_dp, className: "desktop:orderly-text-base-contrast-54", children: props.markPrice })] }) }));
};
const Spread = (props) => {
    const { asks, bids } = props;
    const spread = (0, react_1.useMemo)(() => {
        if (bids.length === 0 && asks.length === 0) {
            return 0;
        }
        const bid1 = Number.isNaN(bids[0][0]) ? 0 : bids[0][0];
        const index = asks.reverse().findIndex((item) => !Number.isNaN(item[0]));
        let ask1 = 0.0;
        if (index !== -1) {
            ask1 = Number.isNaN(asks[index][0]) ? 0 : asks[index][0];
        }
        const dValue = new utils_1.Decimal(ask1).sub(bid1).div(new utils_1.Decimal(ask1).add(bid1).div(2));
        // 0.00006416604461251195
        // 0.000065
        // 0.0065
        return Math.ceil(dValue.toNumber() * 1000000 + 0.1) / 10000;
    }, [asks, bids]);
    return ((0, jsx_runtime_1.jsx)("div", { children: (0, jsx_runtime_1.jsx)(tooltip_1.Tooltip, { content: "Spread Ratio of the ask1 and bid1.", className: "orderly-max-w-[240px]", children: (0, jsx_runtime_1.jsx)("div", { className: "orderly-text-3xs orderly-text-base-contrast-36 orderly-items-center orderly-h-full orderly-flex orderly-pr-3 orderly-cursor-pointer", children: `${spread}%` }) }) }));
};
const ArrowTopIcon = (props) => {
    const { size = 12, viewBox, ...rest } = props;
    return ((0, jsx_runtime_1.jsx)("svg", { xmlns: "http://www.w3.org/2000/svg", width: `${size}px`, height: `${size}px`, fill: "current", fillOpacity: 1, viewBox: `0 0 11.68 12.3`, ...rest, children: (0, jsx_runtime_1.jsx)("path", { d: "M12.3058 6.58699L13.1514 5.63574L7.42409 0.544834L7.00132 0.161367L6.57854 0.544834L0.851268 5.63574L1.69682 6.58699L6.36496 2.43753L6.36496 11.8386L7.63769 11.8386L7.63769 2.43755L12.3058 6.58699Z" }) }));
};
//# sourceMappingURL=markPrice.desktop.js.map