"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderCell = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const button_1 = __importDefault(require("../../button"));
const statistic_1 = require("../../statistic");
const tag_1 = require("../../tag");
const react_1 = require("react");
const types_1 = require("@orderly.network/types");
const text_1 = require("../../text");
const numeralTotal_1 = require("../../text/numeralTotal");
const orderListContext_1 = require("./shared/orderListContext");
const provider_1 = require("../../provider");
const OrderCell = (props) => {
    const { order } = props;
    const [loading, setLoading] = (0, react_1.useState)(false);
    const { onCancelOrder, onEditOrder } = (0, react_1.useContext)(orderListContext_1.OrderListContext);
    const { quote, quote_dp, base, base_dp } = (0, react_1.useContext)(provider_1.SymbolContext);
    const isAlgoOrder = order?.algo_order_id !== undefined;
    // console.log("price node", order);
    const isStopMarket = order?.type === "MARKET" && isAlgoOrder;
    const typeTag = (0, react_1.useMemo)(() => {
        return ((0, jsx_runtime_1.jsx)(tag_1.Tag, { color: order.side === "BUY" ? "buy" : "sell", size: "small", children: order.side === "BUY" ? "Buy" : "Sell" }));
    }, [order]);
    const cancelOrder = (0, react_1.useCallback)(() => {
        if (loading)
            return;
        setLoading(true);
        onCancelOrder(order).finally(() => setLoading(false));
    }, [loading, order]);
    const onSymbol = () => {
        props.onSymbolChange?.({ symbol: order.symbol });
        // go to the top of page
        window.scrollTo(0, 0);
    };
    return ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-px-4 orderly-py-2", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center orderly-gap-2 orderly-mb-1", children: [typeTag, (0, jsx_runtime_1.jsx)("div", { className: "orderly-flex-1 orderly-text-2xs", onClick: onSymbol, children: (0, jsx_runtime_1.jsx)(text_1.Text, { rule: "symbol", children: order.symbol }) }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-text-4xs orderly-text-base-contrast-36", children: (0, jsx_runtime_1.jsx)(text_1.Text, { rule: "date", children: order.created_time }) })] }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-grid orderly-grid-cols-3 orderly-gap-2", children: [(0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Qty.", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", value: order.quantity ?? "-", precision: base_dp, rule: "price", valueClassName: order.side === types_1.OrderSide.BUY
                            ? "orderly-text-trade-profit orderly-text-3xs"
                            : "orderly-text-trade-loss orderly-text-3xs" }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Filled", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", 
                        // @ts-ignore
                        value: order.total_executed_quantity ?? "-", rule: "price", precision: base_dp }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: (0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-36", children: "Est. total" }), (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-20", children: "(USDC)" })] }), labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", value: (0, jsx_runtime_1.jsx)(numeralTotal_1.NumeralTotal, { price: props.order.price ?? 1, quantity: props.order.quantity, precision: quote_dp }), align: "right" }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-36", children: "Trigger price" }) }), labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", rule: "price", precision: quote_dp, value: order.trigger_price }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-36", children: "Limit price" }) }), labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", value: isStopMarket ? (0, jsx_runtime_1.jsx)("span", { children: "Market" }) : order.price ?? "-", rule: "price", precision: quote_dp }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-36", children: "Mark price" }) }), labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-3xs orderly-text-base-contrast-80", rule: "price", precision: quote_dp, value: order.mark_price, align: "right" })] }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-gap-3 orderly-text-4xs orderly-justify-end orderly-mt-2", children: [(0, jsx_runtime_1.jsx)(button_1.default, { id: "orderly-pending-cell-edit-button", variant: "outlined", size: "small", color: "tertiary", className: "orderly-w-[120px] orderly-text-4xs", onClick: () => onEditOrder(order), children: "Edit" }), (0, jsx_runtime_1.jsx)(button_1.default, { id: "orderly-pending-cell-cancel-button", variant: "outlined", color: "tertiary", size: "small", className: "orderly-w-[120px] orderly-text-4xs", loading: loading, onClick: cancelOrder, children: "Cancel" })] })] }));
};
exports.OrderCell = OrderCell;
//# sourceMappingURL=cell.js.map