"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.columnsBasis = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const types_1 = require("@orderly.network/types");
const renew_1 = require("../orderHistory/full/renew");
const cancelButton_1 = require("./full/cancelButton");
const string_1 = require("../../utils/string");
const text_1 = require("../../text");
const class_variance_authority_1 = require("class-variance-authority");
const numeralWithCtx_1 = require("../../text/numeralWithCtx");
/// get columns for cancel/fill/reject/history
const columnsBasis = (props) => {
    const { status, onSymbolChange } = props || {};
    const columns = [
        {
            title: "Instrument",
            dataIndex: "symbol",
            width: 120,
            className: "orderly-h-[48px] orderly-font-semibold",
            render: (value) => ((0, jsx_runtime_1.jsx)(text_1.Text, { rule: "symbol", onClick: (e) => {
                    onSymbolChange?.({ symbol: value });
                    e.stopPropagation();
                    e.preventDefault();
                }, children: value })),
        },
        {
            title: "Type",
            width: 100,
            className: "orderly-h-[48px] orderly-font-semibold",
            dataIndex: "type",
            formatter: (value, record) => {
                if (record.algo_order_id) {
                    return `Stop ` + `${record.type}`.toLowerCase();
                }
                return (0, string_1.upperCaseFirstLetter)(value);
            },
        },
        {
            title: "Side",
            className: "orderly-h-[48px]",
            width: 100,
            dataIndex: "side",
            render: (value, record) => ((0, jsx_runtime_1.jsx)("span", { className: (0, class_variance_authority_1.cx)("orderly-font-semibold", value === types_1.OrderSide.BUY
                    ? "orderly-text-trade-profit"
                    : "orderly-text-trade-loss"), children: (0, string_1.upperCaseFirstLetter)(value) })),
        },
        {
            title: "Filled / Quantity",
            className: "orderly-h-[48px] orderly-font-semibold",
            dataIndex: "quantity",
            width: 200,
            render: (value, record) => {
                return ((0, jsx_runtime_1.jsx)("span", { className: (0, class_variance_authority_1.cx)("orderly-font-semibold", record.side === types_1.OrderSide.BUY
                        ? "orderly-text-trade-profit"
                        : "orderly-text-trade-loss"), children: `${record.total_executed_quantity} / ${record.quantity}` }));
            },
        },
        {
            title: "Order Price",
            className: "orderly-h-[48px] orderly-font-semibold",
            dataIndex: "price",
            width: 100,
            render: (value, record) => {
                if (record.type === "MARKET") {
                    return (0, jsx_runtime_1.jsx)("span", { children: "Market" });
                }
                return ((0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { className: "orderly-font-semibold orderly-text-2xs", children: value || "-" }));
            },
        },
        {
            title: "Avg. price",
            width: 100,
            className: "orderly-h-[48px] orderly-font-semibold",
            dataIndex: "average_executed_price",
            render: (value, record) => {
                return ((0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { className: "orderly-font-semibold orderly-text-2xs", children: value || "-" }));
            },
        },
        {
            title: "Trigger",
            width: 100,
            className: "orderly-h-[48px] orderly-font-semibold",
            dataIndex: "trigger_price",
            render: (value, record) => {
                return ((0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { className: "orderly-font-semibold orderly-text-2xs", children: value }));
            },
        },
        {
            title: "Est. total",
            width: 100,
            className: "orderly-h-[48px] orderly-font-semibold",
            dataIndex: "executed",
            render: (value, record) => {
                return ((0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { className: "orderly-font-semibold orderly-text-2xs", children: record.total_executed_quantity === 0 ||
                        Number.isNaN(record.average_executed_price) ||
                        record.average_executed_price === null
                        ? "-"
                        : `${record.total_executed_quantity * record.average_executed_price}` }));
            },
        },
        {
            title: "Fee",
            width: 100,
            className: "orderly-h-[48px] orderly-font-semibold",
            dataIndex: "total_fee",
        },
        {
            title: "Status",
            width: 120,
            className: "orderly-h-[48px] orderly-font-semibold",
            dataIndex: "status",
            formatter: (value, record) => {
                const status = value || record.algo_status;
                if (status === "NEW") {
                    return (0, string_1.upperCaseFirstLetter)("pending");
                }
                return (0, string_1.upperCaseFirstLetter)(status);
            },
        },
        {
            title: "Reduce",
            width: 80,
            dataIndex: "reduce_only",
            className: "orderly-h-[48px] orderly-font-semibold",
            render: (value) => {
                return (0, jsx_runtime_1.jsx)("span", { children: value ? "Yes" : "No" });
            },
        },
        {
            title: "Hidden",
            width: 80,
            dataIndex: "visible",
            className: "orderly-h-[48px] orderly-font-semibold",
            render: (value, record) => {
                return (0, jsx_runtime_1.jsx)("span", { children: record.visible_quantity !== 0 ? "No" : "Yes" });
            },
        },
        {
            title: "Order time",
            dataIndex: "created_time",
            width: 150,
            // onSort: status === OrderStatus.INCOMPLETE,
            className: "orderly-h-[48px]",
            render: (value) => ((0, jsx_runtime_1.jsx)(text_1.Text, { rule: "date", className: "orderly-break-normal orderly-whitespace-nowrap orderly-font-semibold", children: value })),
        },
    ];
    if (status !== types_1.OrderStatus.REJECTED && status !== types_1.OrderStatus.FILLED) {
        columns.push({
            title: "",
            dataIndex: "action",
            width: 120,
            className: "orderly-h-[48px] orderly-font-semibold !orderly-pr-2",
            align: "right",
            fixed: "right",
            render: (value, record) => {
                if (record.status === types_1.OrderStatus.CANCELLED) {
                    return (0, jsx_runtime_1.jsx)(renew_1.Renew, { record: record });
                }
                if (record.status === types_1.OrderStatus.NEW) {
                    return (0, jsx_runtime_1.jsx)(cancelButton_1.CancelButton, { order: record });
                }
                return null;
            },
        });
    }
    return columns;
};
exports.columnsBasis = columnsBasis;
//# sourceMappingURL=columnsUtil.js.map