"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderEditForm = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const button_1 = __importDefault(require("../../../../button"));
const divider_1 = require("../../../../divider");
const input_1 = require("../../../../input");
const slider_1 = require("../../../../slider");
const statistic_1 = require("../../../../statistic");
const text_1 = require("../../../../text");
const hooks_1 = require("@orderly.network/hooks");
const types_1 = require("@orderly.network/types");
const react_hook_form_1 = require("react-hook-form");
const modal_1 = require("../../../../modal");
const confirmContent_1 = require("../../shared/confirmContent");
const OrderEditForm = (props) => {
    const { order, onSubmit } = props;
    const isAlgoOrder = order.algo_order_id !== undefined;
    const isMarket = order.type === "MARKET";
    // const { hide, reject, resolve } = useModal();
    // @ts-ignore
    const { markPrice, maxQty, helper } = (0, hooks_1.useOrderEntry)(order.symbol, order.side);
    const orderType = (0, react_1.useMemo)(() => {
        if (isAlgoOrder) {
            return `STOP_${order.type}`;
        }
        return order.type;
    }, [order, isAlgoOrder]);
    const { handleSubmit, control, getValues, setValue, formState: { errors, submitCount, isSubmitting, isDirty, dirtyFields }, } = (0, react_hook_form_1.useForm)({
        defaultValues: {
            order_price: order.price?.toString(),
            order_quantity: order.quantity.toString(),
            trigger_price: order.trigger_price?.toString(),
            symbol: order.symbol,
            order_type: orderType,
            side: order.side,
            reduce_only: Boolean(order.reduce_only),
        },
        // values: {
        // },
        resolver: async (values) => {
            // @ts-ignore
            const errors = await helper.validator(values);
            return {
                values,
                errors,
            };
        },
    });
    // console.log("editor form ", order);
    const symbolInfo = (0, hooks_1.useSymbolsInfo)()[order.symbol];
    //
    const base = (0, react_1.useMemo)(() => symbolInfo("base"), [symbolInfo]);
    const quote = (0, react_1.useMemo)(() => symbolInfo("quote"), [symbolInfo]);
    const typeText = (0, react_1.useMemo)(() => {
        if (order.side === types_1.OrderSide.SELL)
            return (0, jsx_runtime_1.jsx)(text_1.Text, { type: "sell", children: "Limit Sell" });
        return (0, jsx_runtime_1.jsx)(text_1.Text, { type: "buy", children: "Limit Buy" });
    }, [order]);
    const onConfirm = (data, dirtyFields) => {
        return modal_1.modal.confirm({
            title: "Edit Order",
            content: (0, confirmContent_1.EditOrderConfirmContent)(isAlgoOrder, isMarket, data, dirtyFields, base, order.symbol),
            contentClassName: "desktop:orderly-w-[340px]",
            onOk: () => Promise.resolve(data),
            onCancel: () => {
                return Promise.reject();
            },
        });
    };
    const onFormSubmit = (0, react_1.useCallback)((data) => {
        return onConfirm(data, dirtyFields).then((data) => {
            return onSubmit(data);
        }, () => { });
    }, [quote, order, dirtyFields]);
    const onFieldChange = (name, value) => {
        // @ts-ignore
        const newValues = helper.calculate(getValues(), name, value);
        //
        if (name === "trigger_price") {
            // @ts-ignore
            setValue("trigger_price", newValues.trigger_price, {
                shouldValidate: submitCount > 0,
                shouldDirty: true,
            });
        }
        else {
            if (name === "order_price") {
                // @ts-ignore
                setValue("order_price", newValues.order_price, {
                    shouldValidate: submitCount > 0,
                    shouldDirty: true,
                });
            }
            // @ts-ignore
            setValue("order_quantity", newValues.order_quantity, {
                shouldValidate: submitCount > 0,
                shouldDirty: true,
            });
        }
    };
    if (!order)
        return null;
    return ((0, jsx_runtime_1.jsxs)("div", { children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-pb-3 orderly-pt-5 orderly-text-xs", children: (0, jsx_runtime_1.jsx)(text_1.Text, { rule: "symbol", children: order.symbol }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-grid orderly-grid-cols-2", children: [(0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Order type", value: typeText, valueClassName: "orderly-text-2xs", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36" }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Last price", value: markPrice, rule: "price", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-2xs" })] }), (0, jsx_runtime_1.jsx)(divider_1.Divider, { className: "orderly-py-5" }), (0, jsx_runtime_1.jsxs)("form", { onSubmit: handleSubmit(onFormSubmit), children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-flex-col orderly-gap-5", children: [isAlgoOrder && (0, jsx_runtime_1.jsx)(react_hook_form_1.Controller, { name: "trigger_price", control: control, render: ({ field }) => {
                                    return ((0, jsx_runtime_1.jsx)(input_1.Input, { prefix: "Trigger price", suffix: quote, type: "text", inputMode: "decimal", containerClassName: "orderly-bg-base-500 orderly-rounded-borderRadius", helpText: errors.trigger_price?.message, error: !!errors.trigger_price, className: "orderly-text-right orderly-text-3xs", value: field.value, onChange: (e) => {
                                            // field.onChange(e.target.value)
                                            onFieldChange("trigger_price", e.target.value);
                                        } }));
                                } }), (0, jsx_runtime_1.jsx)(react_hook_form_1.Controller, { name: "order_price", control: control, render: ({ field }) => {
                                    return ((0, jsx_runtime_1.jsx)(input_1.Input, { prefix: "Price", suffix: quote, type: "text", inputMode: "decimal", containerClassName: "orderly-bg-base-500 orderly-rounded-borderRadius", helpText: errors.order_price?.message, error: !!errors.order_price, className: "orderly-text-right orderly-text-3xs", value: isMarket ? "Market" : field.value, disabled: isMarket, onChange: (e) => {
                                            // field.onChange(e.target.value)
                                            onFieldChange("order_price", e.target.value);
                                        } }));
                                } }), (0, jsx_runtime_1.jsx)(react_hook_form_1.Controller, { name: "order_quantity", control: control, render: ({ field }) => {
                                    return ((0, jsx_runtime_1.jsx)(input_1.Input, { prefix: "Quantity", suffix: base, type: "text", inputMode: "decimal", containerClassName: "orderly-bg-base-500 orderly-rounded-borderRadius", helpText: errors.order_quantity?.message, error: !!errors.order_quantity, className: "orderly-text-right orderly-text-3xs", value: field.value, onChange: (e) => {
                                            // field.onChange(e.target.value)
                                            onFieldChange("order_quantity", e.target.value);
                                        } }));
                                } })] }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-py-5", children: (0, jsx_runtime_1.jsx)(react_hook_form_1.Controller, { name: "order_quantity", control: control, render: ({ field }) => {
                                //
                                return ((0, jsx_runtime_1.jsx)(slider_1.Slider, { step: symbolInfo("base_tick"), min: 0, max: maxQty, color: "buy", markCount: 4, value: [Number(field.value ?? 0)], onValueChange: (value) => {
                                        onFieldChange("order_quantity", value[0].toString());
                                    } }));
                            } }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-grid orderly-grid-cols-2 orderly-gap-3 orderly-py-5", children: [(0, jsx_runtime_1.jsx)(button_1.default, { fullWidth: true, variant: "contained", color: "tertiary", type: "button", onClick: () => {
                                    props.onCancel?.();
                                }, children: "Cancel" }), (0, jsx_runtime_1.jsx)(button_1.default, { fullWidth: true, type: "submit", loading: isSubmitting, disabled: !isDirty, children: "Confirm" })] })] })] }));
};
exports.OrderEditForm = OrderEditForm;
//# sourceMappingURL=editorForm.js.map