"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Listview = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const table_1 = require("../../../table");
const text_1 = require("../../../text");
const types_1 = require("@orderly.network/types");
const class_variance_authority_1 = require("class-variance-authority");
const string_1 = require("../../../utils/string");
const provider_1 = require("../../../provider");
const cancelButton_1 = require("./cancelButton");
const quantity_1 = require("./quantity");
const price_1 = require("./price");
const endReachedBox_1 = require("../../../listView/endReachedBox");
const css_1 = require("../../../utils/css");
const columnsUtil_1 = require("../columnsUtil");
const orderTrades_1 = require("../../../block/orderHistory/orderTrades");
const triggerPrice_1 = require("./triggerPrice");
const ordersEmptyView_1 = require("./ordersEmptyView");
const Listview = (props) => {
    const columns = (0, react_1.useMemo)(() => {
        // const columns = columnsBasis();
        if (props.status === types_1.OrderStatus.INCOMPLETE) {
            const columns = [
                {
                    title: "Instrument",
                    dataIndex: "symbol",
                    className: "orderly-h-[48px]",
                    width: 120,
                    onSort: props.status === types_1.OrderStatus.INCOMPLETE
                        ? (r1, r2, sortOrder) => {
                            if (sortOrder === "asc") {
                                return r1.symbol.localeCompare(r2.symbol);
                            }
                            return r2.symbol.localeCompare(r1.symbol);
                        }
                        : undefined,
                    render: (value) => ((0, jsx_runtime_1.jsx)(text_1.Text, { rule: "symbol", className: "orderly-font-semibold", onClick: (e) => {
                            props.onSymbolChange?.({ symbol: value });
                            e.stopPropagation();
                            e.preventDefault();
                        }, children: value })),
                },
                {
                    title: "Type",
                    width: 100,
                    className: "orderly-h-[48px] orderly-font-semibold",
                    dataIndex: "type",
                    formatter: (value, record) => {
                        const type = typeof record.type === "string"
                            ? record.type.replace("_ORDER", "").toLowerCase()
                            : record.type;
                        if (record.algo_order_id) {
                            return `Stop ${type}`;
                        }
                        return (0, string_1.upperCaseFirstLetter)(value);
                    },
                },
                {
                    title: "Side",
                    width: 100,
                    className: "orderly-h-[48px]",
                    dataIndex: "side",
                    onSort: props.status === types_1.OrderStatus.INCOMPLETE
                        ? (r1, r2, sortOrder) => {
                            if (sortOrder === "asc") {
                                return r2.side.localeCompare(r1.side);
                            }
                            return r1.side.localeCompare(r2.side);
                        }
                        : undefined,
                    render: (value) => ((0, jsx_runtime_1.jsx)("span", { className: (0, class_variance_authority_1.cx)("orderly-font-semibold", value === types_1.OrderSide.BUY
                            ? "orderly-text-trade-profit"
                            : "orderly-text-trade-loss"), children: (0, string_1.upperCaseFirstLetter)(value) })),
                },
                {
                    title: "Filled / Quantity",
                    className: "orderly-h-[48px] orderly-ui-pending-list-input-container orderly-ui-pending-list-quantity-input-container",
                    dataIndex: "quantity",
                    width: 120,
                    onSort: props.status === types_1.OrderStatus.INCOMPLETE,
                    render: (value, record) => ((0, jsx_runtime_1.jsx)(quantity_1.OrderQuantity, { order: record })),
                },
                {
                    title: "Price",
                    className: "orderly-h-[48px] orderly-ui-pending-list-input-container rderly-ui-pending-list-price-input-container",
                    dataIndex: "price",
                    width: 120,
                    onSort: props.status === types_1.OrderStatus.INCOMPLETE,
                    render: (value, record) => (0, jsx_runtime_1.jsx)(price_1.Price, { order: record }),
                },
                {
                    title: "Trigger",
                    className: "orderly-h-[48px] orderly-ui-pending-list-input-container orderly-ui-pending-list-trigger-input-container",
                    dataIndex: "trigger_price",
                    width: 120,
                    // onSort: props.status === OrderStatus.INCOMPLETE,
                    render: (value, record) => ((0, jsx_runtime_1.jsx)(triggerPrice_1.TriggerPrice, { order: record })),
                },
                {
                    title: "Est. total",
                    width: 100,
                    className: "orderly-h-[48px] orderly-font-semibold",
                    dataIndex: "executed",
                    render: (value, record) => {
                        return ((0, jsx_runtime_1.jsx)(text_1.Numeral, { className: "orderly-font-semibold orderly-text-2xs orderly-text-base-contrast-80", precision: 2, children: record.quantity === 0 ||
                                Number.isNaN(record.price) ||
                                record.price === null
                                ? "--"
                                : `${record.quantity * record.price}` }));
                    },
                },
                {
                    title: "Reduce",
                    dataIndex: "reduce_only",
                    width: 100,
                    className: "orderly-h-[48px] orderly-font-semibold",
                    render: (value) => {
                        return (0, jsx_runtime_1.jsx)("span", { children: value ? "Yes" : "No" });
                    },
                },
                {
                    title: "Hidden",
                    dataIndex: "visible",
                    width: 100,
                    className: "orderly-h-[48px] orderly-font-semibold",
                    render: (value, record) => {
                        // @ts-ignore
                        return (0, jsx_runtime_1.jsx)("span", { children: record.visible_quantity !== 0 ? "No" : "Yes" });
                    },
                },
                {
                    title: "Order time",
                    dataIndex: "created_time",
                    width: 150,
                    onSort: props.status === types_1.OrderStatus.INCOMPLETE,
                    className: "orderly-h-[48px]",
                    render: (value) => ((0, jsx_runtime_1.jsx)(text_1.Text, { rule: "date", className: "orderly-break-normal orderly-whitespace-nowrap orderly-font-semibold", children: value })),
                },
                {
                    title: "",
                    dataIndex: "action",
                    className: "orderly-h-[48px]",
                    align: "right",
                    fixed: "right",
                    width: 100,
                    render: (_, record) => {
                        if (props.status === types_1.OrderStatus.INCOMPLETE) {
                            return (0, jsx_runtime_1.jsx)(cancelButton_1.CancelButton, { order: record });
                        }
                        return null;
                    },
                },
            ];
            // columns.push();
            return columns;
        }
        else {
            return (0, columnsUtil_1.columnsBasis)({
                status: props.status,
                onSymbolChange: props.onSymbolChange,
            });
        }
    }, [props.status]);
    const divRef = (0, react_1.useRef)(null);
    return ((0, jsx_runtime_1.jsx)("div", { ref: divRef, className: "orderly-h-full orderly-overflow-y-auto", children: (0, jsx_runtime_1.jsxs)(endReachedBox_1.EndReachedBox, { onEndReached: () => {
                if (!props.loading) {
                    props.loadMore?.();
                }
            }, children: [(0, jsx_runtime_1.jsx)(table_1.Table, { bordered: true, justified: true, showMaskElement: false, columns: columns, dataSource: props.dataSource, headerClassName: "orderly-text-2xs orderly-text-base-contrast-54 orderly-py-3 orderly-bg-base-900", className: (0, css_1.cn)("orderly-text-2xs orderly-text-base-contrast-80", props.className), generatedRowKey: (record, index) => `${index}${record.order_id || record.algo_order_id}`, renderRowContainer: (record, index, children) => {
                        return ((0, jsx_runtime_1.jsx)(provider_1.SymbolProvider, { symbol: record.symbol, children: children }, index));
                    }, expandRowRender: props.status === "FILLED"
                        ? (record, index) => {
                            return (0, jsx_runtime_1.jsx)(orderTrades_1.OrderTrades, { record: record, index: index });
                        }
                        : undefined }), (!props.dataSource || props.dataSource.length <= 0) && ((0, jsx_runtime_1.jsx)(ordersEmptyView_1.OrdersEmptyView, { watchRef: divRef, left: 0, right: props.status === types_1.OrderStatus.INCOMPLETE ? 100 : 120 }))] }) }));
};
exports.Listview = Listview;
//# sourceMappingURL=listview.js.map