"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TriggerPrice = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const button_1 = __importDefault(require("../../../button"));
const popover_1 = require("../../../popover");
const symbolProvider_1 = require("../../../provider/symbolProvider");
const css_1 = require("../../../utils/css");
const utils_1 = require("@orderly.network/utils");
const lucide_react_1 = require("lucide-react");
const react_1 = require("react");
const orderListContext_1 = require("../shared/orderListContext");
const toast_1 = require("../../../toast");
const divider_1 = require("../../../divider");
const hooks_1 = require("@orderly.network/hooks");
const input_1 = require("../../../input");
const TriggerPrice = (props) => {
    const { order } = props;
    const [price, setPrice] = (0, react_1.useState)("");
    (0, react_1.useEffect)(() => {
        setPrice(order.trigger_price?.toString() ?? "0");
    }, [order.trigger_price]);
    const isAlgoOrder = order?.algo_order_id !== undefined;
    const [open, setOpen] = (0, react_1.useState)(0);
    const [editting, setEditting] = (0, react_1.useState)(false);
    if (!isAlgoOrder) {
        return (0, jsx_runtime_1.jsx)("div", { children: "-" });
    }
    if (!editting && open <= 0) {
        return (0, jsx_runtime_1.jsx)(NormalState, { order: order, price: price, setEditing: setEditting });
    }
    return ((0, jsx_runtime_1.jsx)(EditingState, { order: order, price: price, setPrice: setPrice, editting: editting, setEditting: setEditting, open: open, setOpen: setOpen }));
};
exports.TriggerPrice = TriggerPrice;
const NormalState = (props) => {
    const { order, price } = props;
    return ((0, jsx_runtime_1.jsx)("div", { className: (0, css_1.cn)("orderly-flex orderly-max-w-[110px] orderly-justify-start orderly-items-center orderly-gap-1 orderly-relative orderly-font-semibold"), onClick: (e) => {
            e.stopPropagation();
            e.preventDefault();
            props.setEditing(true);
        }, children: (0, jsx_runtime_1.jsx)("div", { className: "orderly-px-2 orderly-flex orderly-min-w-[70px] orderly-items-center orderly-h-[28px] orderly-bg-base-700 orderly-text-2xs orderly-font-semibold orderly-rounded-lg", children: price }) }));
};
const EditingState = (props) => {
    const { order, price, setPrice, editting, setEditting, setOpen, open } = props;
    const [isSubmitting, setIsSubmitting] = (0, react_1.useState)(false);
    const { editAlgoOrder } = (0, react_1.useContext)(orderListContext_1.OrderListContext);
    const ee = (0, hooks_1.useEventEmitter)();
    const boxRef = (0, react_1.useRef)(null);
    const confirmRef = (0, react_1.useRef)(null);
    const { base, base_dp } = (0, symbolProvider_1.useSymbolContext)();
    const closePopover = () => setOpen(0);
    const cancelPopover = () => {
        setOpen(-1);
        setPrice(order.trigger_price?.toString() ?? "0");
    };
    (0, react_1.useEffect)(() => {
        const clickHandler = (event) => {
            // close the input when click outside of boxRef
            const el = boxRef?.current;
            if (!el || el.contains(event.target)) {
                return;
            }
            const el2 = confirmRef?.current;
            if (!el2 || el2.contains(event.target)) {
                return;
            }
            setPrice(order.trigger_price?.toString() ?? "0");
            setEditting(false);
        };
        document.body.addEventListener("click", clickHandler);
        return () => {
            document.body.removeEventListener("click", clickHandler);
        };
    }, []);
    const onClick = () => {
        // event.stopPropagation();
        // event.preventDefault();
        setEditting(false);
        if (Number(price) === Number(order.trigger_price)) {
            return;
        }
        setOpen(1);
    };
    const handleKeyDown = (event) => {
        if (event.key === "Enter") {
            event.stopPropagation();
            event.preventDefault();
            onClick();
        }
    };
    const onClickCancel = (order) => {
        setPrice(order.trigger_price);
        setEditting(false);
    };
    const onConfirm = () => {
        // @ts-ignore
        const data = {
            // price: price,
            quantity: order.quantity,
            trigger_price: price,
            symbol: order.symbol,
            // order_type: order.type,
            // side: order.side,
            // reduce_only: Boolean(order.reduce_only),
            algo_order_id: order.algo_order_id,
        };
        // @ts-ignore
        editAlgoOrder(`${order.algo_order_id}`, data)
            .then((result) => {
            closePopover();
            setPrice(price);
            // setTimeout(() => inputRef.current?.blur(), 300);
        }, (err) => {
            toast_1.toast.error(err.message);
            // @ts-ignore
            setPrice(order.trigger_price?.toString());
            cancelPopover();
        })
            .finally(() => setIsSubmitting(false));
    };
    const inputRef = (0, react_1.useRef)(null);
    return ((0, jsx_runtime_1.jsx)(popover_1.Popover, { open: open > 0, onOpenChange: (open) => setOpen(open ? 1 : 0), children: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-justify-start orderly-items-center orderly-gap-1 orderly-relative orderly-font-semibold", ref: boxRef, children: [(0, jsx_runtime_1.jsxs)("div", { className: (0, css_1.cn)("orderly-absolute orderly-left-1 orderly-flex", {
                        "orderly-animate-in orderly-fade-in orderly-zoom-in": editting,
                        "orderly-animate-out orderly-fade-out orderly-zoom-out orderly-hidden": !editting,
                    }), children: [(0, jsx_runtime_1.jsx)("button", { className: "hover:orderly-bg-base-contrast/10 orderly-h-[25px] orderly-rounded orderly-px-1 orderly-text-base-contrast-54 hover:orderly-text-base-contrast-80", onClick: () => onClickCancel(order), children: (0, jsx_runtime_1.jsx)(lucide_react_1.X, { size: 14 }) }), (0, jsx_runtime_1.jsx)(divider_1.Divider, { vertical: true, className: "orderly-ml-[1px] before:orderly-h-[16px] orderly-min-w-[2px]" })] }), (0, jsx_runtime_1.jsx)(popover_1.PopoverAnchor, { asChild: true, children: (0, jsx_runtime_1.jsx)(input_1.Input, { ref: inputRef, type: "text", value: (0, utils_1.commify)(price), onChange: (e) => setPrice((0, hooks_1.cleanStringStyle)(e.target.value)), onFocus: () => setEditting(true), onBlur: () => {
                            setTimeout(() => {
                                setEditting(false);
                                if (open <= 0) {
                                    setPrice(order.trigger_price?.toString() ?? "0");
                                }
                            }, 100);
                        }, autoFocus: true, onKeyDown: handleKeyDown, containerClassName: "orderly-h-auto orderly-pl-7", className: "orderly-w-full orderly-flex-1 orderly-pl-9 orderly-pr-9 orderly-bg-base-700 orderly-px-2 orderly-py-1 orderly-rounded " }) }), (0, jsx_runtime_1.jsxs)("div", { className: (0, css_1.cn)("orderly-absolute orderly-right-1 orderly-flex", {
                        "orderly-animate-in orderly-fade-in orderly-zoom-in": editting,
                        "orderly-animate-out orderly-fade-out orderly-zoom-out  orderly-hidden": !editting,
                    }), children: [(0, jsx_runtime_1.jsx)(divider_1.Divider, { vertical: true, className: "before:orderly-h-[16px] orderly-min-w-[2px] orderly-mr-[1px]" }), (0, jsx_runtime_1.jsx)("button", { className: "hover:orderly-bg-base-contrast/10 orderly-h-[25px] orderly-rounded orderly-px-1 orderly-text-base-contrast-54 hover:orderly-text-base-contrast-80", 
                            // @ts-ignore
                            onMouseDown: onClick, children: (0, jsx_runtime_1.jsx)(lucide_react_1.Check, { size: 18 }) }), (0, jsx_runtime_1.jsx)(popover_1.PopoverContent, { align: "end", side: "top", className: "orderly-w-[340px]", onCloseAutoFocus: (e) => {
                                if (inputRef.current && open === -1) {
                                    inputRef.current.focus();
                                }
                            }, onOpenAutoFocus: (e) => e.preventDefault(), children: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-pt-5 orderly-relative", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-text-base-contrast-54 orderly-text-2xs desktop:orderly-text-sm", children: ["You agree changing the trigger price of ", base, "-PERP order to", " ", (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-warning", children: (0, utils_1.commify)(price) }), "."] }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-grid orderly-grid-cols-2 orderly-gap-2 orderly-mt-5", children: [(0, jsx_runtime_1.jsx)(button_1.default, { color: "tertiary", onClick: cancelPopover, disabled: isSubmitting, children: "Cancel" }), (0, jsx_runtime_1.jsx)(button_1.default
                                            // @ts-ignore
                                            , { 
                                                // @ts-ignore
                                                ref: confirmRef, loading: isSubmitting, onClick: onConfirm, children: "Confirm" })] }), (0, jsx_runtime_1.jsx)("button", { className: "orderly-absolute orderly-right-0 orderly-top-0 orderly-text-base-contrast-54", onClick: cancelPopover, children: (0, jsx_runtime_1.jsx)(lucide_react_1.X, { size: 18 }) })] }) })] })] }) }));
};
//# sourceMappingURL=triggerPrice.js.map