"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOrderExecutionReportMsg = void 0;
const utils_1 = require("@orderly.network/utils");
const num_1 = require("../../utils/num");
function getOrderExecutionReportMsg(data, symbolsInfo) {
    const { symbol, status, side, quantity, totalExecutedQuantity } = data;
    const getSymbolInfo = symbolsInfo[symbol];
    const base_dp = getSymbolInfo("base_dp");
    const displaySide = (0, utils_1.capitalizeString)(side);
    const displaySymbol = (0, utils_1.transSymbolformString)(symbol);
    const displayQuantity = base_dp === undefined
        ? quantity
        : (0, num_1.parseNumber)(quantity, { precision: base_dp });
    let title = "";
    let msg = "";
    switch (status) {
        case "NEW":
            title = "Order opened";
            msg = `${displaySide} ${displaySymbol} ${displayQuantity}`;
            break;
        case "FILLED":
        case "PARTIAL_FILLED":
            const displayTotalExecutedQuantity = base_dp === undefined
                ? totalExecutedQuantity
                : (0, num_1.parseNumber)(totalExecutedQuantity, { precision: base_dp });
            title = "Order filled";
            msg = `${displaySide} ${displaySymbol} ${displayTotalExecutedQuantity} / ${displayQuantity}`;
            break;
        case "CANCELLED":
            title = "Order cancelled";
            msg = `${displaySide} ${displaySymbol} ${displayQuantity}`;
            break;
        case "REJECTED":
            title = "Order rejected";
            msg = `${displaySide} ${displaySymbol} ${displayQuantity}`;
            break;
        case "REPLACED":
            title = "Order edited";
            msg = `${side} ${displaySymbol} ${totalExecutedQuantity} / ${displayQuantity}`;
            break;
        default:
            break;
    }
    return {
        title,
        msg,
    };
}
exports.getOrderExecutionReportMsg = getOrderExecutionReportMsg;
//# sourceMappingURL=getOrderExecutionReportMsg.js.map