"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChainSelect = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const hooks_1 = require("@orderly.network/hooks");
const icon_1 = require("../../../icon");
const lucide_react_1 = require("lucide-react");
const modal_1 = require("../../../modal");
const chainDialog_1 = require("./chainDialog");
const spinner_1 = require("../../../spinner");
const react_dropdown_menu_1 = require("@radix-ui/react-dropdown-menu");
const chainCell_1 = require("./chainCell");
const types_1 = require("@orderly.network/types");
const ChainSelect = (props) => {
    const isTable = (0, hooks_1.useMediaQuery)(types_1.MEDIA_TABLET);
    const networkId = (0, hooks_1.useConfig)("networkId");
    const [allChains, { findByChainId }] = (0, hooks_1.useChains)(undefined, {
        pick: "network_infos",
        filter: (chain) => chain.network_infos?.bridge_enable || chain.network_infos?.bridgeless,
        // filter: (chain: API.Chain) => isTestnet(chain.network_infos?.chain_id),
    });
    const { connectedChain } = (0, hooks_1.useWalletConnector)();
    const chains = (0, react_1.useMemo)(() => {
        let targetChains = allChains;
        if (props.chains) {
            targetChains.mainnet = props.chains.mainnet?.map((item) => item.network_infos);
            targetChains.testnet = props.chains.testnet?.map((item) => item.network_infos);
        }
        if (Array.isArray(targetChains))
            return targetChains;
        if (targetChains === undefined)
            return [];
        return targetChains[networkId];
    }, [allChains, props.chains, networkId]);
    const { value } = props;
    const currentChain = (0, react_1.useMemo)(() => {
        if (!value || !chains || !Array.isArray(chains))
            return undefined;
        if (chains.findIndex(
        // @ts-ignore
        (chain) => chain.chain_id === value.id) < 0) {
            return undefined;
        }
        return value.info?.network_infos;
    }, [value, chains]);
    const onChainChange = (chainId) => {
        if (!chainId)
            return;
        let chainInfo;
        if (props.chains) {
            chainInfo = [...props.chains?.mainnet, ...props.chains?.testnet].find(
            // @ts-ignore
            (item) => parseInt(item.network_infos?.chain_id) === parseInt(chainId));
        }
        else {
            chainInfo = findByChainId(chainId);
        }
        chainInfo && props?.onValueChange?.(chainInfo);
    };
    const onClick = (0, react_1.useCallback)(async () => {
        const result = await modal_1.modal.show(chainDialog_1.ChainDialog, {
            mainChains: chains,
            currentChainId: value?.id,
        });
        onChainChange(result?.id);
    }, [chains, value?.id, props.onValueChange, findByChainId, props.chains]);
    const onDropMenuItemClick = (0, react_1.useCallback)((chain) => {
        onChainChange(chain.chain_id);
    }, [props?.onValueChange, findByChainId, props.chains]);
    (0, react_1.useEffect)(() => {
        if (!!chains || !!props.chains) {
            let chainInfo;
            if (props.chains) {
                chainInfo = [...props.chains?.mainnet, ...props.chains?.testnet].find(
                // @ts-ignore
                (item) => 
                // @ts-ignore
                parseInt(item.network_infos?.chain_id) ===
                    // @ts-ignore
                    parseInt(props.value?.id));
            }
            else {
                chainInfo = findByChainId(props.value?.id);
            }
            if (!chainInfo)
                return;
            props.onChainInited?.(chainInfo);
        }
    }, [props.value?.id, chains?.length, props.chains]);
    // if chains is unknown, always can select chains
    const selectable = (!currentChain || chains?.length > 1) && !props.settingChain;
    const icon = (0, react_1.useMemo)(() => {
        if (props.settingChain) {
            return (0, jsx_runtime_1.jsx)(spinner_1.Spinner, { size: "small", className: "orderly-text-primary-light" });
        }
        // if chains is unknown, always show icon
        if (!currentChain || chains?.length > 1) {
            return (
            // @ts-ignore
            (0, jsx_runtime_1.jsx)(lucide_react_1.ArrowLeftRight, { size: 16, className: "orderly-text-primary-light" }));
        }
        return null;
    }, [chains?.length, props.settingChain, currentChain]);
    if (isTable) {
        return ((0, jsx_runtime_1.jsx)(MobileChainSelect, { chains: chains, onClick: onClick, currentChain: currentChain, icon: icon, selectable: selectable }));
    }
    return ((0, jsx_runtime_1.jsx)(DesktopChainSelect, { chains: chains, currentChain: currentChain, icon: icon, connectedChain: connectedChain, onDropMenuItemClick: onDropMenuItemClick, selectable: selectable }));
};
exports.ChainSelect = ChainSelect;
const MobileChainSelect = (props) => {
    const { onClick, currentChain, icon } = props;
    return ((0, jsx_runtime_1.jsxs)("button", { className: "orderly-flex orderly-w-full orderly-items-center orderly-px-2 orderly-rounded orderly-bg-base-500", disabled: !props.selectable, onClick: onClick, children: [(0, jsx_runtime_1.jsx)(icon_1.NetworkImage, { id: currentChain?.chain_id, type: currentChain ? "chain" : "unknown", size: "small", rounded: true }), (0, jsx_runtime_1.jsx)("span", { className: "orderly-flex-1 orderly-px-2 orderly-text-3xs orderly-text-left desktop:orderly-text-xs", children: currentChain?.name ?? "Unknown" }), icon] }));
};
const DesktopChainSelect = (props) => {
    const { chains, currentChain, icon, connectedChain } = props;
    const [open, setOpen] = (0, react_1.useState)(false);
    function parseChainId(id) {
        if (typeof id === "number") {
            return id;
        }
        if (typeof id === "string") {
            if (id.startsWith("0x")) {
                return parseInt(id, 16);
            }
            return parseInt(id, 10);
        }
    }
    const buttonElem = (0, react_1.useMemo)(() => {
        return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(icon_1.NetworkImage, { id: currentChain?.chain_id, type: currentChain ? "chain" : "unknown", size: "small", rounded: true }), (0, jsx_runtime_1.jsx)("span", { className: "orderly-flex-1 orderly-px-2 orderly-text-3xs orderly-text-left", children: currentChain?.name ?? "Unknown" }), icon] }));
    }, [currentChain]);
    if (!props.selectable) {
        return ((0, jsx_runtime_1.jsx)("div", { className: "orderly-flex orderly-w-full orderly-items-center orderly-px-2 orderly-rounded orderly-bg-base-500", children: buttonElem }));
    }
    return ((0, jsx_runtime_1.jsxs)(react_dropdown_menu_1.DropdownMenu, { open: open, onOpenChange: setOpen, children: [(0, jsx_runtime_1.jsx)(react_dropdown_menu_1.DropdownMenuTrigger, { asChild: true, children: (0, jsx_runtime_1.jsx)("button", { className: "orderly-flex orderly-w-full orderly-items-center orderly-px-2 orderly-rounded orderly-bg-base-500", children: buttonElem }) }), (0, jsx_runtime_1.jsx)(react_dropdown_menu_1.DropdownMenuContent, { align: "start", style: { width: "241px", zIndex: 100 }, className: "orderly-rounded-sm orderly-bg-base-700 orderly-max-h-[250px] orderly-overflow-y-auto orderly-overflow-hidden orderly-hide-scrollbar orderly-mt-2 orderly-shadow-[0_4px_4px_0px_rgba(0,0,0,0.25)]", children: chains.map((chain, index) => {
                    return ((0, jsx_runtime_1.jsx)(react_dropdown_menu_1.DropdownMenuItem, { onClick: () => {
                            props.onDropMenuItemClick?.(chain);
                        }, children: (0, jsx_runtime_1.jsx)(chainCell_1.ChainCell, { name: chain.name, id: chain.chain_id, bridgeless: chain.bridgeless, selected: parseChainId(connectedChain?.id) === chain.chain_id }, chain.chain_id) }, index));
                }) })] }));
};
//# sourceMappingURL=chainSelect.js.map