"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TokenSelect = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const types_1 = require("@orderly.network/types");
const hooks_1 = require("@orderly.network/hooks");
const tokenSelect_mobile_1 = require("./tokenSelect.mobile");
const tokenSelect_desktop_1 = require("./tokenSelect.desktop");
const icon_1 = require("../../../icon");
const utils_1 = require("../../../utils");
const TokenSelect = (props) => {
    const { tokens } = props;
    const [open, setOpen] = (0, react_1.useState)(false);
    const isMobile = (0, hooks_1.useMediaQuery)(types_1.MEDIA_TABLET);
    const token = (0, react_1.useMemo)(() => {
        if (!!props.token) {
            return props.token;
        }
        // default show USDC when no token selected
        return {
            symbol: "USDC",
        };
    }, [props.token]);
    const disabled = (tokens?.length ?? 0) < 2 || props.disabled;
    const trigger = (0, react_1.useMemo)(() => {
        return ((0, jsx_runtime_1.jsxs)("button", { disabled: disabled, className: "orderly-token-select orderly-flex orderly-items-center orderly-gap-2 orderly-text-3xs orderly-text-base-contrast-80 orderly-mr-2 desktop:orderly-text-xs", onClick: (event) => {
                event.preventDefault();
                event.stopPropagation();
                setOpen(!open);
            }, children: [(0, jsx_runtime_1.jsx)(icon_1.NetworkImage, { type: token ? "token" : "placeholder", name: token?.symbol, size: "small", rounded: true }), (0, jsx_runtime_1.jsx)("span", { children: token?.symbol }), tokens && tokens.length > 1 && ((0, jsx_runtime_1.jsx)(icon_1.ArrowDownIcon, { className: (0, utils_1.cn)("orderly-transition orderly-duration-300", open ? "orderly-rotate-180" : "orderly-rotate-0"), size: 16 }))] }));
    }, [tokens, token, disabled, open]);
    const commonProps = {
        open,
        onOpenChange: setOpen,
        trigger,
        tokens: props.tokens,
        fetchBalance: props.fetchBalance,
        onTokenChange: props.onTokenChange,
        disabled
    };
    if (isMobile) {
        return (0, jsx_runtime_1.jsx)(tokenSelect_mobile_1.MobileTokenSelect, { ...commonProps });
    }
    return (0, jsx_runtime_1.jsx)(tokenSelect_desktop_1.DesktopTokenSelect, { ...commonProps });
};
exports.TokenSelect = TokenSelect;
//# sourceMappingURL=tokenSelect.js.map