"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Listview = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const table_1 = require("../../../table");
const react_1 = require("react");
const text_1 = require("../../../text");
const positionRowContext_1 = require("./positionRowContext");
const priceInput_1 = require("./priceInput");
const closeButton_1 = require("./closeButton");
const provider_1 = require("../../../provider");
const quantityInput_1 = require("./quantityInput");
const numeralWithCtx_1 = require("../../../text/numeralWithCtx");
const tab_1 = require("../../../tab");
const tabContext_1 = require("../../../tab/tabContext");
const divider_1 = require("../../../divider");
const unrealPnLHover_1 = require("./unrealPnLHover");
const positionEmptyView_1 = require("./positionEmptyView");
const sharePnLIcon_1 = require("../../../block/shared/sharePnLIcon");
const Listview = (props) => {
    const { height } = (0, react_1.useContext)(tab_1.TabContext);
    // const { footerHeight } = useContext(LayoutContext);
    const { data: { pnlNotionalDecimalPrecision }, } = (0, tabContext_1.useTabContext)();
    const columns = (0, react_1.useMemo)(() => {
        return [
            {
                title: "Instrument",
                dataIndex: "symbol",
                className: "orderly-h-[48px]",
                fixed: "left",
                width: 120,
                onSort: (r1, r2, sortOrder) => {
                    if (sortOrder === "asc") {
                        return r1.symbol.localeCompare(r2.symbol);
                    }
                    return r2.symbol.localeCompare(r1.symbol);
                },
                render: (value) => ((0, jsx_runtime_1.jsx)(text_1.Text, { rule: "symbol", className: "orderly-font-semibold orderly-cursor-pointer", onClick: (e) => {
                        props.onSymbolChange?.({ symbol: value });
                        e.stopPropagation();
                        e.preventDefault();
                    }, children: value })),
            },
            {
                title: "Quantity",
                className: "orderly-h-[48px]",
                dataIndex: "position_qty",
                onSort: true,
                width: 100,
                render: (value) => ((0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { coloring: true, className: "orderly-font-semibold", tick: "base_dp", children: value })),
            },
            {
                title: "Avg. open",
                className: "orderly-h-[48px]",
                width: 120,
                onSort: true,
                dataIndex: "average_open_price",
                render: (value) => (0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { children: value }),
            },
            {
                title: "Mark price",
                dataIndex: "mark_price",
                width: 120,
                onSort: true,
                className: "orderly-h-[48px]",
                render: (value) => {
                    return ((0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { className: "orderly-font-semibold", children: value }));
                },
            },
            {
                title: "Liq. price",
                width: 100,
                onSort: true,
                className: "orderly-h-[48px]",
                hint: "Estimated price at which your position will be liquidated. Prices are estimated and depend on multiple factors across all positions.",
                dataIndex: "est_liq_price",
                render: (value) => {
                    return Number(value) === 0 ? ("--") : ((0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { className: "orderly-text-warning orderly-font-semibold", children: value }));
                },
            },
            {
                title: "Unreal. PnL",
                className: "orderly-h-[48px]",
                dataIndex: "unrealized_pnl",
                width: 150,
                onSort: true,
                hint: ((0, jsx_runtime_1.jsx)(unrealPnLHover_1.UnrealizedPnLPopoverCard, { unPnlPriceBasis: props.unPnlPriceBasis, setUnPnlPriceBasic: props.setUnPnlPriceBasic })),
                render: (value, record) => {
                    return ((0, jsx_runtime_1.jsxs)("span", { children: [(0, jsx_runtime_1.jsx)(text_1.Numeral, { precision: pnlNotionalDecimalPrecision, coloring: true, className: "orderly-font-semibold", children: value }), (0, jsx_runtime_1.jsx)(text_1.Numeral, { rule: "percentages", precision: pnlNotionalDecimalPrecision, coloring: true, className: "orderly-font-semibold", prefix: "(", surfix: ")", children: record.unrealized_pnl_ROI }), (0, jsx_runtime_1.jsx)(sharePnLIcon_1.SharePnLIcon, { className: "orderly-ml-2", position: record })] }));
                },
            },
            // {
            //   title: "Unreal. ROI",
            //   className: "orderly-h-[48px]",
            //   dataIndex: "unsettled_pnl_ROI",
            //   width: 120,
            //   onSort: true,
            //   render: (value: string) => (
            //   ),
            // },
            // {
            //   title: "Daily real.",
            //   className: "orderly-h-[48px]",
            //   dataIndex: "open_price",
            // },
            {
                title: "Est. total",
                dataIndex: "notional",
                className: "orderly-h-[48px]",
                width: 100,
                onSort: true,
                render: (value) => ((0, jsx_runtime_1.jsx)(text_1.Numeral, { precision: pnlNotionalDecimalPrecision, className: "orderly-font-semibold", children: value })),
            },
            {
                title: "Margin",
                className: "orderly-h-[48px]",
                dataIndex: "mm",
                onSort: true,
                width: 100,
                render: (value) => ((0, jsx_runtime_1.jsx)(text_1.Numeral, { className: "orderly-font-semibold", children: value })),
                hint: ((0, jsx_runtime_1.jsxs)("div", { children: [(0, jsx_runtime_1.jsx)("span", { children: "The minimum equity to keep your position. " }), (0, jsx_runtime_1.jsx)(divider_1.Divider, { className: "orderly-py-2 orderly-border-white/10" }), (0, jsx_runtime_1.jsx)("span", { children: "Margin = Position size * Mark price * MMR" })] })),
                hintClassName: "orderly-p-2",
            },
            {
                title: "Qty.",
                dataIndex: "close_qty",
                className: "orderly-h-[48px]",
                width: 100,
                fixed: "right",
                render: (value) => {
                    return (0, jsx_runtime_1.jsx)(quantityInput_1.QuantityInput, {});
                },
            },
            {
                title: "Price",
                dataIndex: "close_price",
                width: 100,
                fixed: "right",
                className: "orderly-w-[100px] orderly-h-[48px]",
                render: (value) => (0, jsx_runtime_1.jsx)(priceInput_1.PriceInput, {}),
            },
            {
                title: "",
                dataIndex: "close_position",
                align: "right",
                width: 80,
                fixed: "right",
                className: "orderly-h-[48px]",
                render: (value) => {
                    return (0, jsx_runtime_1.jsx)(closeButton_1.CloseButton, {});
                },
            },
        ];
    }, [pnlNotionalDecimalPrecision, props.unPnlPriceBasis]);
    const divRef = (0, react_1.useRef)(null);
    return ((0, jsx_runtime_1.jsxs)("div", { ref: divRef, 
        // className="orderly-overflow-y-auto"
        className: "orderly-relative", style: { height: `${(height?.content ?? 100) - 68}px` }, children: [(0, jsx_runtime_1.jsx)(table_1.Table, { bordered: true, justified: true, showMaskElement: false, columns: columns, dataSource: props.dataSource, headerClassName: "orderly-text-2xs orderly-text-base-contrast-54 orderly-py-3 orderly-bg-base-900", className: "orderly-text-2xs orderly-text-base-contrast-80", generatedRowKey: (record) => record.symbol, renderRowContainer: (record, index, children) => {
                    return ((0, jsx_runtime_1.jsx)(provider_1.SymbolProvider, { symbol: record.symbol, children: (0, jsx_runtime_1.jsx)(positionRowContext_1.PositionsRowProvider, { position: record, children: children }) }));
                } }), (!props.dataSource || props.dataSource.length <= 0) && ((0, jsx_runtime_1.jsx)(positionEmptyView_1.PositionEmptyView, { watchRef: divRef, left: 120, right: 280 }))] }));
};
exports.Listview = Listview;
//# sourceMappingURL=listview.js.map