"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PositionsRowProvider = exports.usePositionsRowContext = exports.PositionsRowContext = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const types_1 = require("@orderly.network/types");
const react_1 = require("react");
const types_2 = require("@orderly.network/types");
const hooks_1 = require("@orderly.network/hooks");
exports.PositionsRowContext = (0, react_1.createContext)({});
const usePositionsRowContext = () => {
    return (0, react_1.useContext)(exports.PositionsRowContext);
};
exports.usePositionsRowContext = usePositionsRowContext;
const PositionsRowProvider = (props) => {
    const [quantity, setQuantity] = (0, react_1.useState)(Math.abs(props.position.position_qty).toString());
    (0, react_1.useEffect)(() => {
        setQuantity(Math.abs(props.position.position_qty).toString());
    }, [props.position.position_qty]);
    const [price, setPrice] = (0, react_1.useState)("");
    const [side, setSide] = (0, react_1.useState)(props.position.position_qty > 0 ? types_2.OrderSide.SELL : types_2.OrderSide.BUY);
    const [type, setType] = (0, react_1.useState)(types_1.OrderType.MARKET);
    const { helper, onSubmit, submitting } = (0, hooks_1.useOrderEntry)(props.position?.symbol, side, true);
    const updateOrderType = (type, price) => {
        setType(type);
        if (type === types_1.OrderType.LIMIT) {
            if (!price) {
                throw new Error("price is required");
            }
            setPrice(price);
        }
        else {
            setPrice("");
        }
    };
    const closeOrderData = (0, react_1.useMemo)(() => {
        const { position } = props;
        if (!position)
            return null;
        const data = {
            //   order_price: undefined,
            order_quantity: quantity,
            symbol: props.position.symbol,
            order_type: type,
            side,
            reduce_only: true,
        };
        if (type === types_1.OrderType.LIMIT) {
            data.order_price = price;
        }
        return data;
    }, [props.position, price, type, quantity]);
    const onUpdateQuantity = (value) => {
        const newValues = helper.calculate({}, "order_quantity", value);
        setQuantity(newValues["order_quantity"]);
    };
    const onUpdatePrice = (value) => {
        const newValues = helper.calculate({}, "order_price", value);
        setPrice(newValues["order_price"]);
    };
    const postOrder = () => {
        return onSubmit(closeOrderData);
    };
    return ((0, jsx_runtime_1.jsx)(exports.PositionsRowContext.Provider, { value: {
            quantity,
            price,
            type,
            side,
            position: props.position,
            updatePriceChange: onUpdatePrice,
            updateQuantity: onUpdateQuantity,
            updateOrderType,
            onSubmit: postOrder,
            submitting,
            closeOrderData,
        }, children: props.children }));
};
exports.PositionsRowProvider = PositionsRowProvider;
//# sourceMappingURL=positionRowContext.js.map