"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClosePositionPane = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const button_1 = __importDefault(require("../../../button"));
const divider_1 = require("../../../divider");
const input_1 = require("../../../input");
const slider_1 = require("../../../slider");
const statistic_1 = require("../../../statistic");
const text_1 = require("../../../text");
const react_1 = require("react");
const limitConfirm_1 = require("./limitConfirm");
const modal_1 = require("../../../modal");
const hooks_1 = require("@orderly.network/hooks");
const react_hook_form_1 = require("react-hook-form");
const types_1 = require("@orderly.network/types");
const toast_1 = require("../../../toast");
const ClosePositionPane = (props) => {
    const { position, side } = props;
    // const { hide, reject, resolve } = useModal();
    const { markPrice, maxQty, helper, onSubmit } = (0, hooks_1.useOrderEntry)(position?.symbol, side, true);
    const { register, handleSubmit, control, getValues, setValue, formState: { errors, submitCount, isSubmitting }, } = (0, react_hook_form_1.useForm)({
        values: {
            order_price: Math.abs(position?.mark_price),
            order_quantity: Math.abs(position?.position_qty),
            symbol: position?.symbol,
            order_type: types_1.OrderType.LIMIT,
            side: side,
        },
        resolver: async (values) => {
            const errors = await helper.validator(values);
            return {
                values,
                errors,
            };
        },
    });
    (0, react_1.useEffect)(() => {
        // init order_price value
        if (getValues()?.order_price === undefined) {
            //@ts-ignore
            setValue("order_price", markPrice);
        }
    }, [markPrice]);
    const symbolInfo = (0, hooks_1.useSymbolsInfo)()[position?.symbol];
    //
    const base = (0, react_1.useMemo)(() => symbolInfo("base"), [symbolInfo]);
    const quote = (0, react_1.useMemo)(() => symbolInfo("quote"), [symbolInfo]);
    const typeText = (0, react_1.useMemo)(() => {
        if (side === types_1.OrderSide.SELL)
            return (0, jsx_runtime_1.jsx)(text_1.Text, { type: "sell", children: "Limit Sell" });
        return (0, jsx_runtime_1.jsx)(text_1.Text, { type: "buy", children: "Limit Buy" });
    }, [side]);
    const onConfirm = (data) => {
        return modal_1.modal.confirm({
            title: "Limit Close",
            onCancel: () => {
                return Promise.reject();
            },
            content: ((0, jsx_runtime_1.jsx)(limitConfirm_1.LimitConfirm, { order: data, base: base, quote: quote, side: side })),
        });
    };
    const onFormSubmit = (data) => {
        return onConfirm(data).then(() => {
            return onSubmit({ ...data, reduce_only: true }).then((res) => {
                //
                if (res.success) {
                    // toast.success("successfully");
                }
                props.onClose(res);
            }, (error) => {
                toast_1.toast.error(error.message);
            });
        }, () => { });
    };
    const onFieldChange = (name, value) => {
        const newValues = helper.calculate(getValues(), name, value);
        if (name === "order_price") {
            // @ts-ignore
            setValue("order_price", newValues.order_price, {
                shouldValidate: submitCount > 0,
            });
        }
        // @ts-ignore
        setValue("order_quantity", newValues.order_quantity, {
            shouldValidate: submitCount > 0,
        });
    };
    if (!position)
        return null;
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-pb-3 orderly-pt-5 orderly-text-xs", children: (0, jsx_runtime_1.jsx)(text_1.Text, { rule: "symbol", children: position.symbol }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-grid orderly-grid-cols-2", children: [(0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Order type", value: typeText, valueClassName: "orderly-text-2xs", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36" }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Last price", value: markPrice, rule: "price", labelClassName: "orderly-text-4xs orderly-text-base-contrast-36", valueClassName: "orderly-text-2xs" })] }), (0, jsx_runtime_1.jsx)(divider_1.Divider, { className: "orderly-py-5" }), (0, jsx_runtime_1.jsxs)("form", { onSubmit: handleSubmit(onFormSubmit), children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-flex-col orderly-gap-5", children: [(0, jsx_runtime_1.jsx)(react_hook_form_1.Controller, { name: "order_price", control: control, render: ({ field }) => {
                                    return ((0, jsx_runtime_1.jsx)(input_1.Input, { prefix: "Price", suffix: quote, type: "text", inputMode: "decimal", helpText: errors.order_price?.message, error: !!errors.order_price, className: "orderly-text-right orderly-text-3xs", containerClassName: "orderly-bg-base-500 orderly-rounded-borderRadius", value: field.value, onChange: (e) => {
                                            // field.onChange(e.target.value)
                                            onFieldChange("order_price", e.target.value);
                                        } }));
                                } }), (0, jsx_runtime_1.jsx)(react_hook_form_1.Controller, { name: "order_quantity", control: control, render: ({ field }) => {
                                    return ((0, jsx_runtime_1.jsx)(input_1.Input, { prefix: "Quantity", suffix: base, type: "text", inputMode: "decimal", containerClassName: "orderly-bg-base-500 orderly-rounded-borderRadius", helpText: errors.order_quantity?.message, error: !!errors.order_quantity, className: "orderly-text-right orderly-text-3xs", value: field.value, onChange: (e) => {
                                            // field.onChange(e.target.value)
                                            onFieldChange("order_quantity", e.target.value);
                                        } }));
                                } })] }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-py-5", children: (0, jsx_runtime_1.jsx)(react_hook_form_1.Controller, { name: "order_quantity", control: control, render: ({ field }) => {
                                //
                                return ((0, jsx_runtime_1.jsx)(slider_1.Slider, { step: symbolInfo("base_tick"), min: 0, max: Math.abs(position.position_qty), color: "buy", markCount: 4, value: [Number(field.value ?? 0)], onValueChange: (value) => {
                                        // if (typeof value[0] !== "undefined") {
                                        //   field.onChange(value[0]);
                                        // }
                                        setValue("order_quantity", value[0]);
                                    } }));
                            } }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-grid orderly-grid-cols-2 orderly-text-xs orderly-gap-3 orderly-py-5", children: [(0, jsx_runtime_1.jsx)(button_1.default, { variant: "contained", color: "tertiary", fullWidth: true, type: "button", onClick: () => {
                                    props.onCancel?.();
                                }, children: "Cancel" }), (0, jsx_runtime_1.jsx)(button_1.default, { fullWidth: true, type: "submit", loading: isSubmitting, children: "Confirm" })] })] })] }));
};
exports.ClosePositionPane = ClosePositionPane;
//# sourceMappingURL=closeForm.js.map