"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DesktopSharePnLContent = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const icon_1 = require("../../icon");
const react_1 = require("react");
const react_hot_toast_1 = __importDefault(require("react-hot-toast"));
const divider_1 = require("../../divider");
const poster_1 = require("../poster");
const provider_1 = require("../../provider");
const sharePnLUtils_1 = require("./sharePnLUtils");
const carousel_1 = require("./desktop/carousel");
const pnlFormat_1 = require("./desktop/pnlFormat");
const options_1 = require("./desktop/options");
const bottomBtns_1 = require("./desktop/bottomBtns");
const message_1 = require("./desktop/message");
const DesktopSharePnLContent = (props) => {
    const localPnlConfig = (0, sharePnLUtils_1.getPnlInfo)();
    const [pnlFormat, setPnlFormat] = (0, react_1.useState)(localPnlConfig.pnlFormat);
    const [shareOption, setShareOption] = (0, react_1.useState)(new Set(localPnlConfig.options));
    const [selectedSnap, setSelectedSnap] = (0, react_1.useState)(localPnlConfig.bgIndex);
    const [message, setMessage] = (0, react_1.useState)(localPnlConfig.message);
    const [check, setCheck] = (0, react_1.useState)(false);
    const { shareOptions } = (0, react_1.useContext)(provider_1.OrderlyAppContext);
    const { backgroundImages, ...resetOptions } = shareOptions.pnl;
    const [domain, setDomain] = (0, react_1.useState)("");
    const posterRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        const currentDomain = window.location.hostname;
        setDomain(currentDomain);
    }, []);
    const curBgImg = (0, react_1.useMemo)(() => {
        return shareOptions.pnl.backgroundImages[selectedSnap];
    }, [shareOptions.pnl.backgroundImages, selectedSnap]);
    const posterData = (0, sharePnLUtils_1.getPnLPosterData)(props.position, props.leverage, check ? message : "", domain, pnlFormat, shareOption, props.baseDp, props.quoteDp);
    const onCopy = () => {
        posterRef.current
            ?.copy()
            .then(() => {
            props.hide?.();
            react_hot_toast_1.default.success("Image copied");
        })
            .catch((e) => {
            react_hot_toast_1.default.error(() => {
                return ((0, jsx_runtime_1.jsxs)("div", { children: [(0, jsx_runtime_1.jsx)("div", { children: "Copy failed" }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-text-2xs orderly-max-w-[396px] orderly-mt-2 orderly-text-base-contrast-54", children: "Browser version outdated, please update in order to copy image to clipboard." })] }));
            });
        });
    };
    const onDownload = () => {
        posterRef.current?.download("Poster.png");
        props.hide?.();
    };
    const formats = ["roi_pnl", "roi", "pnl"];
    const options = ["openPrice", "markPrice", "openTime", "leverage", "quantity"];
    (0, sharePnLUtils_1.savePnlInfo)(pnlFormat, shareOption, selectedSnap, message);
    return ((0, jsx_runtime_1.jsxs)("div", { className: "orderly-h-full orderly-flex orderly-flex-col orderly-relative orderly-referral", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex-1 orderly-h-full orderly-overflow-y-auto", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-h-[422px] orderly-mt-[36px]", children: [(0, jsx_runtime_1.jsx)(poster_1.Poster, { className: "orderly-mx-11", width: 552, height: 310, data: {
                                    backgroundImg: curBgImg,
                                    ...resetOptions,
                                    data: posterData,
                                }, ref: posterRef }), (0, jsx_runtime_1.jsx)(carousel_1.CarouselBackgroundImage, { backgroundImages: shareOptions.pnl.backgroundImages, selectedSnap: selectedSnap, setSelectedSnap: setSelectedSnap })] }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-px-10", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-mt-4", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-text-lg orderly-h-[26px]", children: "PnL display format" }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-pt-4 orderly-flex orderly-justify-start orderly-gap-3", children: formats.map((e) => (0, jsx_runtime_1.jsx)(pnlFormat_1.PnlFormatView, { setPnlFormat: setPnlFormat, type: e, curType: pnlFormat })) })] }), (0, jsx_runtime_1.jsx)(divider_1.Divider, { className: "orderly-pt-6 orderly-border-white/10" }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-mt-4", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-text-lg orderly-h-[26px]", children: "Optional information to share" }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-mt-4 orderly-flex orderly-justify-start orderly-gap-4", children: options.map((item) => (0, jsx_runtime_1.jsx)(options_1.ShareOption, { setShareOption: setShareOption, type: item, curType: shareOption })) })] }), (0, jsx_runtime_1.jsx)(message_1.Message, { message: message, setMessage: setMessage, check: check, setCheck: setCheck })] })] }), (0, jsx_runtime_1.jsx)(bottomBtns_1.BottomButtons, { onClickCopy: onCopy, onClickDownload: onDownload }), (0, jsx_runtime_1.jsx)("button", { onClick: () => {
                    props.hide();
                }, className: "orderly-absolute orderly-top-0 orderly-right-0 orderly-w-[40px] orderly-h-[40px] orderly-flex orderly-justify-center orderly-items-center", children: (0, jsx_runtime_1.jsx)(icon_1.CloseIcon, { size: 12, className: "orderly-fill-base-contrast-54" }) })] }));
};
exports.DesktopSharePnLContent = DesktopSharePnLContent;
//# sourceMappingURL=desktopSharePnl.js.map