"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TradeHistory = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const table_1 = require("../../table");
const text_1 = require("../../text");
const types_1 = require("@orderly.network/types");
const provider_1 = require("../../provider");
const css_1 = require("../../utils/css");
const TradeHistory = (props) => {
    const { quote, quote_dp, base, base_dp } = (0, react_1.useContext)(provider_1.SymbolContext);
    const columns = (0, react_1.useMemo)(() => {
        return [
            {
                title: "Time",
                dataIndex: "ts",
                render(value, record, index) {
                    return ((0, jsx_runtime_1.jsx)(text_1.Text, { rule: "date", formatString: "HH:mm:ss", className: "orderly-text-base-contrast-80 orderly-text-3xs", children: value }));
                },
            },
            {
                title: `Price(${quote})`,
                dataIndex: "price",
                render(value, record, index) {
                    return ((0, jsx_runtime_1.jsx)(text_1.Numeral, { precision: quote_dp, className: record.side === types_1.OrderSide.BUY
                            ? "orderly-text-trade-profit orderly-text-3xs"
                            : "orderly-text-trade-loss orderly-text-3xs", children: value }));
                },
            },
            {
                title: `Qty(${base})`,
                dataIndex: "size",
                align: "right",
                render(value, record, index) {
                    return ((0, jsx_runtime_1.jsx)(text_1.Numeral, { precision: base_dp, className: record.side === types_1.OrderSide.BUY
                            ? "orderly-text-trade-profit orderly-text-3xs"
                            : "orderly-text-trade-loss orderly-text-3xs", children: value }));
                },
            },
        ];
    }, [base, quote]);
    return ((0, jsx_runtime_1.jsx)(table_1.Table, { dataSource: props.dataSource, columns: columns, loading: props.loading, className: "orderly-text-3xs desktop:orderly-text-2xs", headerClassName: (0, css_1.cn)("orderly-text-base-contrast-36 orderly-bg-base-900 orderly-p-0", props.headerClassName), generatedRowKey: (record, index) => 
        // @ts-ignore
        `record.ts_${record.price}_${record.size}_${index}` }));
};
exports.TradeHistory = TradeHistory;
//# sourceMappingURL=tradeHistory.js.map