"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WalletConnect = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const layout_1 = require("../../layout");
const listTile_1 = require("../../listView/listTile");
const switch_1 = require("../../switch");
const react_1 = require("react");
const types_1 = require("@orderly.network/types");
const step_1 = require("./sections/step");
const hooks_1 = require("@orderly.network/hooks");
const button_1 = __importDefault(require("../../button"));
const toast_1 = require("../../toast");
const rememberMe_1 = require("./sections/rememberMe");
const WalletConnect = (props) => {
    // const { status = AccountStatusEnum.NotConnected } = props;
    const { state: { status }, } = (0, hooks_1.useAccount)();
    const [handleStep, setHandleStep] = (0, react_1.useState)(0);
    const [remember, setRemember] = (0, react_1.useState)(true);
    const buttonLabel = (0, react_1.useMemo)(() => {
        if (status < types_1.AccountStatusEnum.SignedIn) {
            return "Sign in";
        }
        if (status < types_1.AccountStatusEnum.EnableTrading) {
            return "Enable Trading";
        }
        return "--";
    }, [status]);
    const onClick = (0, react_1.useCallback)(() => {
        if (status < types_1.AccountStatusEnum.SignedIn) {
            setHandleStep(1);
            return props.onSignIn?.().finally(() => {
                setHandleStep(0);
            });
        }
        if (status < types_1.AccountStatusEnum.EnableTrading) {
            setHandleStep(2);
            return props
                .onEnableTrading?.(remember)
                .then(() => {
                props.onComplete?.();
            }, (error) => {
                toast_1.toast.error(error.message);
            })
                .finally(() => {
                setHandleStep(0);
            });
        }
    }, [status, remember]);
    return ((0, jsx_runtime_1.jsxs)("div", { children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-text-base-contrast-54 orderly-text-2xs orderly-py-4 desktop:orderly-text-base", children: "Sign two requests to verify ownership of your wallet and enable trading. Signing is free." }), (0, jsx_runtime_1.jsxs)(layout_1.Paper, { className: "orderly-bg-base-500", children: [(0, jsx_runtime_1.jsx)(listTile_1.ListTile, { className: "orderly-text-xs desktop:orderly-text-base", avatar: (0, jsx_runtime_1.jsx)(step_1.StepItem, { active: status <= types_1.AccountStatusEnum.NotSignedIn, isLoading: handleStep === 1, isCompleted: status >= types_1.AccountStatusEnum.SignedIn, children: "1" }), title: "Sign in", disabled: status < types_1.AccountStatusEnum.NotConnected ||
                            status >= types_1.AccountStatusEnum.SignedIn, subtitle: "Confirm you own this wallet" }), (0, jsx_runtime_1.jsx)(listTile_1.ListTile, { className: "orderly-text-xs desktop:orderly-text-base", disabled: status < types_1.AccountStatusEnum.SignedIn, avatar: (0, jsx_runtime_1.jsx)(step_1.StepItem, { active: status >= types_1.AccountStatusEnum.SignedIn, isLoading: handleStep === 2, isCompleted: status >= types_1.AccountStatusEnum.EnableTrading, children: "2" }), title: "Enable Trading", subtitle: "Enable secure access to our API for lightning-fast trading" })] }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-pt-5 orderly-pb-7 orderly-flex orderly-justify-between orderly-items-center", children: [(0, jsx_runtime_1.jsx)(rememberMe_1.RememberMe, {}), (0, jsx_runtime_1.jsx)("div", { children: (0, jsx_runtime_1.jsx)(switch_1.Switch, { id: "orderly-remember-me-switch", checked: remember, onCheckedChange: setRemember }) })] }), (0, jsx_runtime_1.jsx)("div", { children: (0, jsx_runtime_1.jsx)(button_1.default, { className: "orderly-text-xs orderly-text-base-contrast", fullWidth: true, disabled: handleStep > 0, onClick: onClick, loading: handleStep > 0, children: buttonLabel }) })] }));
};
exports.WalletConnect = WalletConnect;
//# sourceMappingURL=walletConnect.js.map