"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.showAccountConnectorModal = exports.WalletConnectDialog = exports.WalletConnectSheet = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const modal_1 = require("../../modal");
const modalHelper_1 = require("../../modal/modalHelper");
const types_1 = require("@orderly.network/types");
const sheet_1 = require("../../sheet");
const toast_1 = require("../../toast");
const hooks_1 = require("@orderly.network/hooks");
const react_1 = require("react");
const walletConnect_1 = require("./walletConnect");
const logo_1 = require("../../logo");
const dialog_1 = require("../../dialog");
const useWalletConnect = () => {
    const { visible, hide, resolve, reject, onOpenChange } = (0, modal_1.useModal)();
    // get account status and handle sign in and enable trading
    const { account, createOrderlyKey, createAccount } = (0, hooks_1.useAccount)();
    const onSignIn = (0, react_1.useCallback)(() => {
        return createAccount().catch((err) => {
            reject();
            toast_1.toast.error(err.message);
            hide();
        });
    }, [account]);
    const onComplete = (0, react_1.useCallback)(() => {
        toast_1.toast.success("Wallet connected");
        resolve();
        hide();
    }, []);
    return {
        visible,
        hide,
        resolve,
        reject,
        onOpenChange,
        onSignIn,
        onComplete,
        createOrderlyKey,
    };
};
exports.WalletConnectSheet = (0, modalHelper_1.create)((props) => {
    // const { visible, hide, resolve, reject, onOpenChange } = useModal();
    // // get account status and handle sign in and enable trading
    // const { account, createOrderlyKey, createAccount } = useAccount();
    // // @ts-ignore
    // const { logoUrl } = useContext(OrderlyContext);
    // const onSignIn = useCallback(() => {
    //   return createAccount().catch((err: Error) => {
    //     reject();
    //     toast.error(err.message);
    //     hide();
    //   });
    // }, [account]);
    // const onComplete = useCallback(() => {
    //   toast.success("Wallet connected");
    //   resolve();
    //   hide();
    // }, []);
    const { visible, hide, resolve, reject, onOpenChange, onSignIn, onComplete, createOrderlyKey, } = useWalletConnect();
    return ((0, jsx_runtime_1.jsx)(sheet_1.Sheet, { open: visible, onOpenChange: onOpenChange, children: (0, jsx_runtime_1.jsxs)(sheet_1.SheetContent, { children: [(0, jsx_runtime_1.jsx)(sheet_1.SheetHeader, { leading: (0, jsx_runtime_1.jsx)(logo_1.Logo, {}), children: (0, jsx_runtime_1.jsx)(sheet_1.SheetTitle, { children: "Connect wallet" }) }), (0, jsx_runtime_1.jsx)(walletConnect_1.WalletConnect, { onEnableTrading: createOrderlyKey, onSignIn: onSignIn, onComplete: onComplete, ...props })] }) }));
});
exports.WalletConnectDialog = (0, modalHelper_1.create)((props) => {
    const { visible, hide, resolve, reject, onOpenChange, onSignIn, onComplete, createOrderlyKey, } = useWalletConnect();
    const _onOpenChange = (0, react_1.useCallback)((open) => {
        // console.log(open);
        if (!open)
            reject("cancel");
        onOpenChange(open);
    }, []);
    return ((0, jsx_runtime_1.jsx)(dialog_1.Dialog, { open: visible, onOpenChange: _onOpenChange, children: (0, jsx_runtime_1.jsxs)(dialog_1.DialogContent, { maxWidth: "sm", closable: true, children: [(0, jsx_runtime_1.jsx)(dialog_1.DialogHeader, { children: (0, jsx_runtime_1.jsx)(dialog_1.DialogTitle, { children: "Connect wallet" }) }), (0, jsx_runtime_1.jsx)(dialog_1.DialogBody, { children: (0, jsx_runtime_1.jsx)(walletConnect_1.WalletConnect, { onEnableTrading: createOrderlyKey, onSignIn: onSignIn, onComplete: onComplete, ...props }) })] }) }));
});
const showAccountConnectorModal = async (props) => {
    const matches = window.matchMedia(types_1.MEDIA_TABLET).matches;
    if (matches) {
        return await modal_1.modal.show(exports.WalletConnectSheet, props);
    }
    else {
        return await modal_1.modal.show(exports.WalletConnectDialog, props);
    }
};
exports.showAccountConnectorModal = showAccountConnectorModal;
//# sourceMappingURL=walletModal.js.map