"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActionButton = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const button_1 = __importDefault(require("../../../button"));
const statusGuardButton_1 = require("../../../button/statusGuardButton");
const toast_1 = require("../../../toast");
const utils_1 = require("@orderly.network/utils");
const hooks_1 = require("@orderly.network/hooks");
const modal_1 = require("../../../modal");
const crossChainConfirm_1 = require("./crossChainConfirm");
const useChainNotSupport_1 = require("../useChainNotSupport");
const ActionButton = (props) => {
    const { chain, chains, onWithdraw, switchChain, disabled, openChainPicker, quantity, loading, chainVaultBalance, maxAmount, crossChainWithdraw, address, fee, } = props;
    /// has cross chain withdraw transaction
    const [crossChainTrans, setCrossChainTrans] = (0, react_1.useState)(undefined);
    const chainNotSupport = (0, useChainNotSupport_1.useChainNotSupport)(chain, chains);
    const { data: assetHistory } = (0, hooks_1.usePrivateQuery)("/v1/asset/history", {
        revalidateOnMount: true,
    });
    const needCrossChain = (0, react_1.useRef)(false);
    (0, hooks_1.useWalletSubscription)({
        onMessage(data) {
            if (!crossChainTrans)
                return;
            console.log("subscribe wallet topic", data);
            const { trxId, transStatus } = data;
            if (trxId === crossChainTrans && transStatus === "COMPLETED") {
                setCrossChainTrans(undefined);
            }
        },
    });
    (0, react_1.useEffect)(() => {
        // const item = assetHistory?.find((e: any) => e.trans_status === "COMPLETED");
        const item = assetHistory?.find((e) => e.trans_status === "pending_rebalance".toUpperCase());
        setCrossChainTrans(item);
    }, [assetHistory]);
    const warningMessage = (0, react_1.useMemo)(() => {
        const networkName = chain?.info?.network_infos?.name;
        // check has cross chain withdraw
        if (crossChainTrans) {
            return `Your cross-chain withdrawal is being processed...`;
        }
        // check cur chain is support no not
        if (chainNotSupport) {
            if (chains?.length && chains.length > 1) {
                return `Withdrawals are not supported on ${networkName}. Please switch to any of the bridgeless networks.`;
            }
            return `Withdrawals are not supported on ${networkName}.`;
        }
        // check quantity and vaultBalance
        if (crossChainWithdraw) {
            needCrossChain.current = true;
            return `Withdrawal exceeds the balance of the ${networkName} vault ( ${chainVaultBalance} USDC ). Cross-chain rebalancing fee will be charged for withdrawal to ${networkName}.`;
        }
        return undefined;
    }, [
        chainNotSupport,
        chains,
        chain,
        quantity,
        maxAmount,
        crossChainWithdraw,
        chainVaultBalance,
    ]);
    const onClick = (0, react_1.useCallback)(() => {
        const qty = parseFloat(quantity);
        if (crossChainWithdraw) {
            modal_1.modal.confirm({
                title: "Confirm to withdraw",
                content: ((0, jsx_runtime_1.jsx)(crossChainConfirm_1.CrossChainConfirm, { address: address || "", amount: qty - fee, chain: chain })),
                onOk: async () => {
                    onWithdraw();
                },
                onCancel: async () => { },
            });
        }
        else {
            onWithdraw();
        }
    }, [crossChainWithdraw, quantity, fee]);
    const swtichChain = (chainId) => {
        toast_1.toast.promise(switchChain({ chainId: (0, utils_1.int2hex)(chainId) }), {
            loading: "Loading",
            success: (data) => `Successfully`,
            error: (err) => `Error: ${err.toString()}`,
        });
    };
    const actionButton = (0, react_1.useMemo)(() => {
        if (!chainNotSupport) {
            return ((0, jsx_runtime_1.jsx)(statusGuardButton_1.StatusGuardButton, { children: (0, jsx_runtime_1.jsx)(button_1.default, { id: "orderly-withdraw-confirm-button", className: "desktop:orderly-text-xs", fullWidth: true, onClick: onClick, disabled: props.disabled || props.loading || crossChainTrans !== undefined, loading: loading, children: "Withdraw" }) }));
        }
        return ((0, jsx_runtime_1.jsx)(button_1.default, { id: "orderly-withdraw-confirm-button", className: "desktop:orderly-text-xs", fullWidth: true, onClick: () => {
                openChainPicker?.().then(({ id }) => {
                    id && swtichChain(id);
                });
            }, children: "Switch network" }));
    }, [
        chainNotSupport,
        chains,
        switchChain,
        disabled,
        chain,
        quantity,
        loading,
    ]);
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-withdraw-warning-message", children: [warningMessage && ((0, jsx_runtime_1.jsx)("div", { className: "orderly-warning-msg orderly-text-warning orderly-text-4xs orderly-text-center orderly-px-[20px] orderly-pt-4 orderly-pb-3 desktop:orderly-text-2xs", children: warningMessage })), " "] }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-flex orderly-justify-center orderly-text-xs desktop:orderly-text-xs orderly-font-bold", children: (0, jsx_runtime_1.jsx)("div", { className: "orderly-withdraw-action-button-container orderly-w-full", children: actionButton }) })] }));
};
exports.ActionButton = ActionButton;
//# sourceMappingURL=actionButton.js.map