"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WithdrawForm = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const divider_1 = require("../../divider");
const icon_1 = require("../../icon");
const quantityInput_1 = require("../../block/quantityInput");
const tokenQtyInput_1 = require("../../input/tokenQtyInput");
const summary_1 = require("../../block/withdraw/sections/summary");
const walletPicker_1 = require("../pickers/walletPicker");
const css_1 = require("../../utils/css");
const networkImage_1 = require("../../icon/networkImage");
const types_1 = require("@orderly.network/types");
const toast_1 = require("../../toast");
const utils_1 = require("@orderly.network/utils");
const actionButton_1 = require("./sections/actionButton");
const settledInfo_1 = require("./sections/settledInfo");
const chainDialog_1 = require("../pickers/chainPicker/chainDialog");
const modal_1 = require("../../modal");
const provider_1 = require("../../provider");
const logo_1 = require("../../logo");
const hooks_1 = require("@orderly.network/hooks");
const numberReg = /^([0-9]{1,}[.]?[0-9]*)/;
const WithdrawForm = ({ status = types_1.WithdrawStatus.Normal, chains, chain, decimals, address, walletName, minAmount, availableBalance, unsettledPnL, hasPositions, maxAmount, onWithdraw, onOk, switchChain, }) => {
    const { brokerName } = (0, react_1.useContext)(provider_1.OrderlyAppContext);
    const [inputStatus, setInputStatus] = (0, react_1.useState)("default");
    const [hintMessage, setHintMessage] = (0, react_1.useState)();
    const [submitting, setSubmitting] = (0, react_1.useState)(false);
    const [quantity, setQuantity] = (0, react_1.useState)("");
    // @ts-ignore
    const { data: balanceList } = (0, hooks_1.useQuery)(`/v1/public/vault_balance`, {
        revalidateOnMount: true,
    });
    const chainVaultBalance = (0, react_1.useMemo)(() => {
        if (!balanceList || !chain)
            return null;
        // chain.id
        const vaultBalance = balanceList.find((item) => parseInt(item.chain_id) === chain?.id);
        if (vaultBalance) {
            return vaultBalance.balance;
        }
        return null;
    }, [chains, chain, balanceList]);
    // console.log("vault_balance data", balanceList, chain, chains, chainVaultBalance);
    const openChainPicker = (0, react_1.useCallback)(async () => {
        const result = await modal_1.modal.show(chainDialog_1.ChainDialog, {
            testChains: chains,
            currentChainId: chain?.id,
        });
        return { id: result?.id, name: result?.name };
    }, [chains, chain]);
    const onChainChange = (0, react_1.useCallback)((value) => {
        if (value.network_infos?.chain_id === chain?.id)
            return Promise.resolve();
        switchChain?.({
            chainId: (0, utils_1.int2hex)(Number(value.network_infos?.chain_id)),
        }).then(() => {
            toast_1.toast.success("Network switched");
            // clear data
            setQuantity("");
        }, (error) => {
            //
            toast_1.toast.error(`Switch chain failed: ${error.message}`);
        });
    }, [switchChain, chain]);
    const crossChainWithdraw = (0, react_1.useMemo)(() => {
        if (chainVaultBalance !== null) {
            const qtyNum = parseFloat(quantity);
            const value = qtyNum > chainVaultBalance && qtyNum <= maxAmount;
            return value;
        }
        return false;
    }, [quantity, maxAmount, chainVaultBalance]);
    const doWithdraw = (0, react_1.useCallback)(() => {
        if (submitting)
            return;
        const num = Number(quantity);
        if (num < minAmount) {
            toast_1.toast.error(`quantity must large than ${minAmount}`);
            return;
        }
        if (inputStatus !== "default") {
            return;
        }
        if (!chain || !chain.id) {
            throw new Error("chain is not set");
        }
        setSubmitting(true);
        return onWithdraw({
            amount: quantity,
            token: "USDC",
            chainId: chain?.id,
            allowCrossChainWithdraw: crossChainWithdraw,
        })
            .then((res) => {
            toast_1.toast.success("Withdrawal requested");
            setQuantity("");
            onOk?.(res);
        }, (error) => {
            toast_1.toast.error(error.message);
        })
            .finally(() => {
            setSubmitting(false);
        });
    }, [
        quantity,
        minAmount,
        inputStatus,
        chain?.id,
        submitting,
        onOk,
        crossChainWithdraw,
    ]);
    const onValueChange = (0, react_1.useCallback)((value) => {
        if (value.value === ".") {
            setQuantity("0.");
            return;
        }
        const result = value.value.match(numberReg);
        if (Array.isArray(result)) {
            value = result[0];
            // value = parseFloat(value);
            if (isNaN(parseFloat(value))) {
                setQuantity("");
            }
            else {
                let d = new utils_1.Decimal(value);
                // setQuantity(value);
                if (d.dp() > decimals) {
                    setQuantity(d.todp(Math.min(decimals, 8)).toString());
                }
                else {
                    setQuantity(value);
                }
            }
        }
        else {
            setQuantity("");
        }
    }, [decimals]);
    const fee = (0, react_1.useMemo)(() => {
        if (!chain)
            return 0;
        const item = chains?.find((c) => c.chain_id === chain.id);
        if (!item) {
            return 0;
        }
        if (crossChainWithdraw) {
            return (
            // @ts-ignore
            (item.withdrawal_fee || 0) + (item.cross_chain_withdrawal_fee || 0));
        }
        return item.withdrawal_fee || 0;
    }, [chain, chains, crossChainWithdraw]);
    (0, react_1.useEffect)(() => {
        // const num = Number(quantity);
        // if (num > maxAmount) {
        //   if (num <= availableBalance) {
        //     setInputStatus("warning");
        //     setHintMessage("Please settle your balance");
        //   } else {
        //     setInputStatus("error");
        //     setHintMessage("Insufficient balance");
        //   }
        // } else {
        //   setInputStatus("default");
        //   setHintMessage(undefined);
        // }
        const input = Number(quantity);
        const freeCollateral = maxAmount;
        if (unsettledPnL < 0) {
            if (input > freeCollateral) {
                setInputStatus("error");
                setHintMessage("Insufficient balance");
            }
            else {
                setInputStatus("default");
                setHintMessage(undefined);
            }
        }
        else {
            if (input > freeCollateral) {
                setInputStatus("error");
                setHintMessage("Insufficient balance");
            }
            else if (input > freeCollateral - unsettledPnL &&
                input <= freeCollateral) {
                setInputStatus("warning");
                setHintMessage("Please settle your balance");
            }
            else {
                setInputStatus("default");
                setHintMessage(undefined);
            }
        }
    }, [quantity, maxAmount, availableBalance]);
    return ((0, jsx_runtime_1.jsxs)("div", { id: "orderly-withdraw-form", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center orderly-py-2 orderly-text-2xs orderly-text-base-contrast desktop:orderly-text-base", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-flex-1", children: "Your " + brokerName + " account" }), (0, jsx_runtime_1.jsx)(logo_1.Logo.secondary, { size: 24 })] }), (0, jsx_runtime_1.jsx)(quantityInput_1.QuantityInput, { tokens: [], 
                // @ts-ignore
                token: {
                    symbol: "USDC",
                    decimals: 6,
                }, decimals: decimals, status: inputStatus, className: (0, css_1.cn)(status !== types_1.WithdrawStatus.Normal &&
                    "orderly-outline orderly-outline-1", {
                    "orderly-outline-trade-loss": status === types_1.WithdrawStatus.InsufficientBalance,
                    "orderly-outline-yellow-500": status === types_1.WithdrawStatus.Unsettle,
                }), quantity: quantity, onValueChange: onValueChange, maxAmount: maxAmount, hintMessage: hintMessage, markPrice: 1 }), (0, jsx_runtime_1.jsx)(settledInfo_1.UnsettledInfo, { unsettledPnL: unsettledPnL, hasPositions: hasPositions }), (0, jsx_runtime_1.jsx)(divider_1.Divider, { className: "orderly-py-3", children: (0, jsx_runtime_1.jsx)(icon_1.MoveDownIcon, { className: "orderly-text-primary-light" }) }), (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center orderly-text-2xs desktop:orderly-text-base", children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-flex-1", children: "Your web3 wallet" }), (0, jsx_runtime_1.jsx)(networkImage_1.NetworkImage, { type: typeof walletName === "undefined" ? "placeholder" : "wallet", name: walletName, rounded: true })] }), (0, jsx_runtime_1.jsx)("div", { className: "orderly-py-2", children: (0, jsx_runtime_1.jsx)(walletPicker_1.WalletPicker, { address: address, chain: chain, onChainChange: onChainChange }) }), (0, jsx_runtime_1.jsx)(tokenQtyInput_1.TokenQtyInput, { amount: quantity, fee: fee, needCalc: true, token: {
                    symbol: "USDC",
                    decimals: 6,
                } }), (0, jsx_runtime_1.jsx)(summary_1.Summary, { fee: fee }), (0, jsx_runtime_1.jsx)(actionButton_1.ActionButton, { chains: chains, chain: chain, onWithdraw: doWithdraw, disabled: !quantity || Number(quantity) - fee <= 0, switchChain: switchChain, quantity: quantity, loading: submitting, openChainPicker: openChainPicker, chainVaultBalance: chainVaultBalance, maxAmount: maxAmount, crossChainWithdraw: crossChainWithdraw, address: address, fee: fee })] }));
};
exports.WithdrawForm = WithdrawForm;
//# sourceMappingURL=withdrawForm.js.map