"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusGuardButton = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const button_1 = require("../button/button");
const hooks_1 = require("@orderly.network/hooks");
const types_1 = require("@orderly.network/types");
const provider_1 = require("../provider");
const walletModal_1 = require("../block/walletConnect/walletModal");
const StatusGuardButton = (props) => {
    const { state } = (0, hooks_1.useAccount)();
    const { onWalletConnect } = (0, react_1.useContext)(provider_1.OrderlyAppContext);
    const onClick = (0, react_1.useCallback)(async () => {
        if (state.status === types_1.AccountStatusEnum.NotConnected) {
            try {
                const result = await onWalletConnect();
                if (result && result.status < types_1.AccountStatusEnum.EnableTrading) {
                    return await (0, walletModal_1.showAccountConnectorModal)({
                        status: result.status,
                    });
                }
                else {
                    return result;
                }
            }
            catch (e) { }
        }
        else if (state.status < types_1.AccountStatusEnum.EnableTrading) {
            try {
                return await (0, walletModal_1.showAccountConnectorModal)({
                    status: state.status,
                });
            }
            catch (err) { }
        }
    }, [state]);
    const buttonLabel = (0, react_1.useMemo)(() => {
        if (state.status === types_1.AccountStatusEnum.NotConnected) {
            return "Connect wallet";
        }
        if (state.status < types_1.AccountStatusEnum.SignedIn) {
            return "Sign in";
        }
        if (state.status < types_1.AccountStatusEnum.EnableTrading) {
            return "Enable Trading";
        }
        return "-";
    }, [state.status]);
    if (state.status < types_1.AccountStatusEnum.EnableTrading) {
        if (typeof props.placeholder === "undefined") {
            return ((0, jsx_runtime_1.jsx)(button_1.Button, { type: "button", fullWidth: true, onClick: () => onClick(), className: "desktop:orderly-font-bold desktop:orderly-text-sm", children: buttonLabel }));
        }
        return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: props.placeholder });
    }
    return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: props.children });
};
exports.StatusGuardButton = StatusGuardButton;
//# sourceMappingURL=statusGuardButton.js.map