"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useCSSVariable = void 0;
const react_1 = require("react");
const useCSSVariable = (names) => {
    const [variables, setVariables] = (0, react_1.useState)(() => getCSSVariableValue(names ?? []));
    function getCSSVariableValue(names) {
        const root = document.documentElement;
        const styles = getComputedStyle(root);
        if (names) {
            const obj = names.reduce((acc, name, index) => {
                acc[name] = styles.getPropertyValue(name);
                return acc;
            }, {});
            return obj;
        }
        return {};
    }
    (0, react_1.useEffect)(() => {
        if (names?.length === 0)
            return;
        const styleObserver = new MutationObserver((mutations) => {
            console.info("document.documentElement.style changed");
            getCSSVariableValue(names);
        });
        styleObserver.observe(document.documentElement, {
            attributes: true,
            attributeFilter: ["style"],
        });
        return () => {
            styleObserver.disconnect();
        };
    }, [names]);
    return variables;
};
exports.useCSSVariable = useCSSVariable;
//# sourceMappingURL=useCSSVariable.js.map