"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Input = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const class_variance_authority_1 = require("class-variance-authority");
const css_1 = require("../utils/css");
const inputMask_1 = require("./inputMask");
const tooltip_1 = require("../tooltip");
const icon_1 = require("../icon");
const string_1 = require("../utils/string");
const inputVariants = (0, class_variance_authority_1.cva)(["orderly-rounded"], {
    variants: {
        variant: {
            outlined: "orderly-border orderly-border-slate-300",
            filled: "orderly-bg-base-700 orderly-border orderly-border-transparent",
        },
        size: {
            small: "orderly-h-[28px]",
            default: "orderly-h-[40px]",
        },
        fullWidth: {
            true: "orderly-w-full",
        },
        disabled: {
            true: "orderly-opacity-70 orderly-cursor-not-allowed",
        },
        error: {
            true: "orderly-border orderly-border-danger",
        },
        // readonly:{
        //     true: "opacity-70 cursor-not-allowed"
        // }
    },
    // compoundVariants: [
    //   {
    //     variant: "filled",
    //     error: true,
    //     class: "border border-danger",
    //   },
    //   {
    //     variant: "outlined",
    //   }
    // ],
    defaultVariants: {
        size: "default",
        variant: "filled",
    },
});
exports.Input = (0, react_1.forwardRef)(({ className, containerClassName, size, variant, fullWidth, disabled, prefix, suffix, error, onClean, helpText, loading, onChange, ...props }, ref) => {
    const [showTooltip, setShowTooltip] = (0, react_1.useState)(false);
    const [cursor, setCursor] = (0, react_1.useState)(null);
    const innerInputRef = (0, react_1.useRef)(null);
    const prevInputValue = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        if (!ref)
            return;
        if (typeof ref === "function") {
            ref(innerInputRef.current);
        }
        else {
            ref.current = innerInputRef.current;
        }
    }, [innerInputRef, ref]);
    (0, react_1.useEffect)(() => {
        if (typeof error === "undefined") {
            return;
        }
        setShowTooltip(!!error);
    }, [error]);
    // fix cursor pointer jump to end;
    (0, react_1.useEffect)(() => {
        if (document.activeElement !== innerInputRef.current)
            return;
        // filter the thousands separator
        const nextValueLen = `${props.value}`.length;
        const prevValueLen = prevInputValue.current?.length || 0;
        const next = cursor ? cursor + (nextValueLen - prevValueLen) : 0;
        innerInputRef.current?.setSelectionRange(next, next);
    }, [props.value]);
    const onInputChange = (event) => {
        if (event.target.value.length < props.value?.length) {
            const currentCursor = event.target.selectionStart;
            const diffIndex = (0, string_1.findLongestCommonSubString)(`${props.value}`, event.target.value);
            if (diffIndex > -1) {
                const diffStr = `${props.value}`.at(diffIndex);
                if (diffStr === ",") {
                    event.target.value = `${event.target.value.substring(0, diffIndex - 1)}${event.target.value.substring(diffIndex)}`;
                    event.target.selectionStart = currentCursor ? currentCursor - 1 : 0;
                }
            }
        }
        if (typeof onChange === "function") {
            onChange(event);
        }
        prevInputValue.current = event.target.value;
        setCursor(event.target.selectionStart);
    };
    const cleanButton = (0, react_1.useMemo)(() => {
        if (typeof onClean === "undefined") {
            return null;
        }
        return ((0, jsx_runtime_1.jsx)("button", { className: "orderly-hidden peer-focus:orderly-flex orderly-px-3 orderly-items-center orderly-justify-center", onMouseDown: (event) => {
                event.preventDefault();
                event.stopPropagation();
                onClean?.();
            }, children: (0, jsx_runtime_1.jsx)("span", { className: "orderly-inline-flex orderly-rounded-full orderly-w-[20px] orderly-h-[20px] orderly-items-center orderly-justify-center", children: (0, jsx_runtime_1.jsx)(icon_1.CircleCloseIcon, { size: 16 }) }) }));
    }, [onClean]);
    const onInputFocus = (event) => {
        setShowTooltip(!!error);
    };
    const onInputBlur = (event) => {
        setShowTooltip(false);
    };
    const prefixElement = (0, react_1.useMemo)(() => {
        if (typeof prefix === "undefined") {
            return null;
        }
        if (typeof prefix === "string") {
            return ((0, jsx_runtime_1.jsx)(inputMask_1.InputMask, { name: props.name, className: "orderly-text-3xs orderly-select-none orderly-text-base-contrast-54 orderly-font-semibold desktop:orderly-text-xs", children: prefix }));
        }
        return prefix;
    }, [prefix]);
    const suffixElement = (0, react_1.useMemo)(() => {
        if (typeof suffix === "undefined") {
            return null;
        }
        if (typeof suffix === "string") {
            return ((0, jsx_runtime_1.jsx)(inputMask_1.InputMask, { name: props.name, className: "orderly-text-3xs orderly-select-none orderly-text-base-contrast-54 orderly-font-semibold desktop:orderly-text-xs", children: suffix }));
        }
        return suffix;
    }, [suffix]);
    return ((0, jsx_runtime_1.jsx)(tooltip_1.Tooltip, { className: "orderly-text-base-contrast orderly-text-4xs", open: showTooltip, content: helpText ?? "input help text", sideOffset: 5, children: (0, jsx_runtime_1.jsxs)("div", { className: (0, css_1.cn)("orderly-input-container", props.readOnly && "orderly-input-container-readonly", "orderly-flex orderly-flex-row orderly-items-center orderly-rounded focus-within:orderly-outline focus-within:orderly-outline-1 orderly-outline-primary", inputVariants({
                size,
                fullWidth,
                disabled,
                variant,
                error,
            }), (props.readOnly || !!error) && "focus-within:orderly-outline-none", containerClassName), children: [prefixElement, (0, jsx_runtime_1.jsx)("input", { ref: innerInputRef, type: "text", onFocus: onInputFocus, onBlur: onInputBlur, onChange: onInputChange, ...props, disabled: !!disabled, className: (0, css_1.cn)("orderly-input", "orderly-bg-transparent orderly-px-3 orderly-flex-1 focus-visible:orderly-outline-none orderly-h-full orderly-w-full orderly-peer placeholder:orderly-text-base-contrast-20 orderly-tabular-nums", typeof prefix !== "undefined" && "orderly-px-0", className) }), cleanButton, suffixElement] }) }));
});
//# sourceMappingURL=index.js.map