"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.modalActions = exports.ModalProvider = exports.hideModalCallbacks = exports.modalCallbacks = exports.ModalIdContext = exports.ModalContext = exports.ALREADY_MOUNTED = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const utils_1 = require("./utils");
const modalHelper_1 = require("./modalHelper");
const initialState = {};
// const MODAL_STACK: string[] = [];
exports.ALREADY_MOUNTED = {};
exports.ModalContext = (0, react_1.createContext)(initialState);
exports.ModalIdContext = (0, react_1.createContext)(null);
exports.modalCallbacks = {};
exports.hideModalCallbacks = {};
let dispatch = () => {
    throw new Error("No dispatch method detected, did you embed your app with Modal.Provider?");
};
//------- reducer actions --------
/**
 * show modal
 * @param id string modalId
 * @param args Recored<string, unknown> modalArgs
 * @returns ModalAction
 */
function showModal(id, args) {
    return {
        type: "SHOW_MODAL",
        payload: {
            id,
            args,
        },
    };
}
/**
 * close modal
 * @param id string modalId
 * @returns ModalAction
 */
function hideModal(id) {
    return {
        type: "HIDE_MODAL",
        payload: {
            id,
        },
    };
}
function removeModal(id) {
    return {
        type: "DESTROY_MODAL",
        payload: {
            id,
        },
    };
}
function setModalStates(id, states) {
    return {
        type: "SET_MODAL_STATES",
        payload: {
            id,
            states,
        },
    };
}
//------- reducer actions --------
const reducer = (state, action) => {
    const { id, args } = action.payload;
    switch (action.type) {
        case "SHOW_MODAL": {
            return {
                ...state,
                [id]: {
                    ...state[id],
                    id,
                    args,
                    visible: !!exports.ALREADY_MOUNTED[id],
                    delayVisible: !exports.ALREADY_MOUNTED[id],
                },
            };
        }
        case "HIDE_MODAL": {
            return {
                ...state,
                [id]: {
                    ...state[id],
                    visible: false,
                },
            };
        }
        case "DESTROY_MODAL": {
            const newState = { ...state };
            delete newState[id];
            return newState;
        }
        case "SET_MODAL_STATES": {
            return {
                ...state,
                [id]: {
                    ...state[id],
                    ...action.payload.states,
                },
            };
        }
        default:
            return state;
    }
};
const ModalContainer = () => {
    const modals = (0, react_1.useContext)(exports.ModalContext);
    const visibleModalIds = Object.keys(modals).filter((id) => !!modals[id]);
    visibleModalIds.forEach((id) => {
        if (!modalHelper_1.MODAL_REGISTRY.has(id) && !exports.ALREADY_MOUNTED[id]) {
            console.warn(`No modal found for id: ${id}. Please check the id or if it is registered or declared via JSX.`);
            return;
        }
    });
    const components = visibleModalIds
        .filter((id) => modalHelper_1.MODAL_REGISTRY.has(id))
        .map((id) => {
        return {
            id,
            ...modalHelper_1.MODAL_REGISTRY.get(id),
        };
    });
    return ((0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: components.map((component) => {
            return ((0, jsx_runtime_1.jsx)(component.comp, { id: component.id, ...component.props }, component.id));
        }) }));
};
const ModalProvider = (props) => {
    const [state, dispatchOrigin] = (0, react_1.useReducer)(reducer, initialState);
    dispatch = dispatchOrigin;
    return ((0, jsx_runtime_1.jsxs)(exports.ModalContext.Provider, { value: state, children: [props.children, (0, jsx_runtime_1.jsx)(ModalContainer, {})] }));
};
exports.ModalProvider = ModalProvider;
function show(modal, args) {
    const modalId = (0, utils_1.getModalId)(modal);
    if (typeof modal !== "string" && !modalHelper_1.MODAL_REGISTRY.has(modalId)) {
        (0, modalHelper_1.register)(modalId, modal);
    }
    dispatch(showModal(modalId, args));
    if (!exports.modalCallbacks[modalId]) {
        let theResolve;
        // `!` tell ts that theResolve will be written before it is used
        let theReject;
        const promise = new Promise((resolve, reject) => {
            theResolve = resolve;
            theReject = reject;
        });
        exports.modalCallbacks[modalId] = {
            resolve: theResolve,
            reject: theReject,
            promise,
        };
    }
    return exports.modalCallbacks[modalId].promise;
}
function hide(modal) {
    const modalId = (0, utils_1.getModalId)(modal);
    dispatch(hideModal(modalId));
    delete exports.modalCallbacks[modalId];
    if (!exports.hideModalCallbacks[modalId]) {
        let theResolve;
        let theReject;
        const promise = new Promise((resolve, reject) => {
            theResolve = resolve;
            theReject = reject;
        });
        exports.hideModalCallbacks[modalId] = {
            resolve: theResolve,
            reject: theReject,
            promise,
        };
    }
    return exports.hideModalCallbacks[modalId].promise;
}
function remove(id) {
    dispatch(removeModal(id));
    delete exports.modalCallbacks[id];
    delete exports.hideModalCallbacks[id];
}
function setStates(id, states) {
    dispatch(setModalStates(id, states));
}
exports.modalActions = {
    show,
    hide,
    remove,
    setStates,
};
//# sourceMappingURL=modalContext.js.map