"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.unregister = exports.register = exports.create = exports.MODAL_REGISTRY = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const useModal_1 = require("./useModal");
const modalContext_1 = require("./modalContext");
exports.MODAL_REGISTRY = new Map();
const create = (Comp) => {
    // return higher order component
    return ({ id, defaultVisible, keepMounted, ...props }) => {
        const { args, show } = (0, useModal_1.useModal)(id);
        const modals = (0, react_1.useContext)(modalContext_1.ModalContext);
        const shouldMount = !!modals[id];
        (0, react_1.useEffect)(() => {
            if (defaultVisible) {
                show();
            }
            modalContext_1.ALREADY_MOUNTED[id] = true;
            return () => {
                // if(!keepMounted){
                delete modalContext_1.ALREADY_MOUNTED[id];
                // }
            };
        }, [id, show, defaultVisible]);
        (0, react_1.useEffect)(() => {
            if (keepMounted)
                modalContext_1.modalActions.setStates(id, { keepMounted: true });
        }, [id, keepMounted]);
        const delayVisible = modals[id]?.delayVisible;
        (0, react_1.useEffect)(() => {
            if (delayVisible) {
                show(args);
            }
        }, [delayVisible, args, show]);
        if (!shouldMount)
            return null;
        return ((0, jsx_runtime_1.jsx)(modalContext_1.ModalIdContext.Provider, { value: id, children: (0, jsx_runtime_1.jsx)(Comp, { ...props, ...args }) }));
    };
};
exports.create = create;
const register = (id, comp, props) => {
    if (!exports.MODAL_REGISTRY.has(id)) {
        exports.MODAL_REGISTRY.set(id, { comp, props });
    }
    else {
        exports.MODAL_REGISTRY.set(id, { comp: exports.MODAL_REGISTRY.get(id).comp, props });
    }
};
exports.register = register;
const unregister = (id) => {
    exports.MODAL_REGISTRY.delete(id);
};
exports.unregister = unregister;
//# sourceMappingURL=modalHelper.js.map