"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useModal = void 0;
const react_1 = require("react");
const modalContext_1 = require("./modalContext");
const utils_1 = require("./utils");
const modalHelper_1 = require("./modalHelper");
function useModal(modal, args) {
    const modals = (0, react_1.useContext)(modalContext_1.ModalContext);
    const modalIdFromContext = (0, react_1.useContext)(modalContext_1.ModalIdContext);
    let modalId;
    let isComponent = modal && typeof modal !== "string";
    if (!modal) {
        modalId = modalIdFromContext;
    }
    else {
        modalId = (0, utils_1.getModalId)(modal);
    }
    if (!modalId) {
        throw new Error("modalId is required");
    }
    const id = modalId;
    (0, react_1.useEffect)(() => {
        if (isComponent) {
            (0, modalHelper_1.register)(id, modal, args);
        }
    }, [isComponent, modalId, modal, args]);
    const modalInfo = modals[id];
    const show = (0, react_1.useCallback)((args) => modalContext_1.modalActions.show(id, args), [id]);
    const hide = (0, react_1.useCallback)(() => modalContext_1.modalActions.hide(id), [id]);
    const remove = (0, react_1.useCallback)(() => modalContext_1.modalActions.remove(id), [id]);
    const onOpenChange = (0, react_1.useCallback)((isOpen) => {
        isOpen ? () => { } : hide();
    }, [id]);
    const setStates = (0, react_1.useCallback)((states) => modalContext_1.modalActions.setStates(id, states), [id]);
    const resolve = (0, react_1.useCallback)((args) => {
        modalContext_1.modalCallbacks[id]?.resolve(args);
        delete modalContext_1.modalCallbacks[id];
    }, [id]);
    const reject = (0, react_1.useCallback)((args) => {
        modalContext_1.modalCallbacks[id]?.reject(args);
        delete modalContext_1.modalCallbacks[id];
    }, [id]);
    const resolveHide = (0, react_1.useCallback)((args) => {
        modalContext_1.hideModalCallbacks[id]?.resolve(args);
        delete modalContext_1.hideModalCallbacks[id];
    }, []);
    return {
        id,
        args: modalInfo?.args,
        visible: !!modalInfo?.visible,
        keepMounted: !!modalInfo?.keepMounted,
        show,
        hide,
        onOpenChange,
        setStates,
        remove,
        resolve,
        reject,
        resolveHide,
    };
}
exports.useModal = useModal;
//# sourceMappingURL=useModal.js.map