"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MyTradingView = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const trading_view_1 = require("@orderly.network/trading-view");
const popover_1 = require("../../../popover");
const react_1 = require("react");
const symbolProvider_1 = require("../../../provider/symbolProvider");
const toast_1 = require("../../../toast");
const hooks_1 = require("@orderly.network/hooks");
const marketConfirmDialog_1 = require("../../../block/positions/full/marketConfirmDialog");
const types_1 = require("@orderly.network/types");
const utils_1 = require("@orderly.network/utils");
const spinner_1 = require("../../../spinner");
const MyTradingView = ({ symbol, tradingViewConfig }) => {
    const [open, setOpen] = (0, react_1.useState)(false);
    const [side, setSide] = (0, react_1.useState)(types_1.OrderSide.BUY);
    const { helper, onSubmit, submitting } = (0, hooks_1.useOrderEntry)(symbol, side, true);
    const symbolInfo = (0, hooks_1.useSymbolsInfo)()[symbol];
    const [orderData, setOrderData] = (0, react_1.useState)();
    const closePositionConfirmCallback = (data) => {
        const side = new utils_1.Decimal(data.balance).greaterThan(0)
            ? types_1.OrderSide.SELL
            : types_1.OrderSide.BUY;
        const order = {
            //   order_price: undefined,
            order_quantity: data.balance,
            symbol: symbol,
            order_type: types_1.OrderType.MARKET,
            side,
            reduce_only: true,
        };
        setOrderData(order);
        setSide(side);
        setOpen(true);
    };
    const onConfirm = async () => {
        console.log("-- order data", orderData);
        orderData.order_quantity = Math.abs(orderData.order_quantity);
        return onSubmit(orderData).then((res) => {
            setOpen(false);
        }, (error) => {
            if (typeof error === "string") {
                toast_1.toast.error(error);
                return;
            }
            toast_1.toast.error(error.message);
        });
    };
    const onClose = () => {
        setOpen(false);
    };
    return ((0, jsx_runtime_1.jsx)("div", { style: { position: "relative", width: "100%", height: "100%" }, children: (0, jsx_runtime_1.jsxs)(symbolProvider_1.SymbolProvider, { symbol: symbol, children: [(0, jsx_runtime_1.jsx)(trading_view_1.TradingView, { symbol: symbol, libraryPath: tradingViewConfig?.library_path, tradingViewScriptSrc: tradingViewConfig?.scriptSRC, tradingViewCustomCssUrl: tradingViewConfig?.customCssUrl, overrides: tradingViewConfig?.overrides, closePositionConfirmCallback: closePositionConfirmCallback, onToast: toast_1.toast, loadingElement: (0, jsx_runtime_1.jsx)(spinner_1.Spinner, {}) }), (0, jsx_runtime_1.jsxs)(popover_1.Popover, { onOpenChange: setOpen, open: open, children: [(0, jsx_runtime_1.jsx)(popover_1.PopoverTrigger, { asChild: true, children: (0, jsx_runtime_1.jsx)("div", { style: {
                                    position: "absolute",
                                    width: "0",
                                    height: "0",
                                    left: "50%",
                                    top: "50%",
                                } }) }), (0, jsx_runtime_1.jsx)(popover_1.PopoverContent, { align: "start", side: "top", className: "orderly-w-[340px]", children: (0, jsx_runtime_1.jsx)(marketConfirmDialog_1.CloseBaseConfirm, { base: symbolInfo("base"), quantity: orderData?.order_quantity ?? 0, onClose: onClose, onConfirm: onConfirm, submitting: submitting }) })] })] }) }));
};
exports.MyTradingView = MyTradingView;
//# sourceMappingURL=myTradingview.js.map