"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Ticker = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const statistic_1 = require("../../../../../statistic");
const defaultStaticStyle_1 = require("../../../../../statistic/defaultStaticStyle");
const hooks_1 = require("@orderly.network/hooks");
const text_1 = require("../../../../../text");
const fundingRate_1 = require("./fundingRate");
const symbolProvider_1 = require("../../../../../provider/symbolProvider");
const tickerMask_1 = require("./tickerMask");
const numeralWithCtx_1 = require("../../../../../text/numeralWithCtx");
const icon_1 = require("../../../../../icon");
const utils_1 = require("@orderly.network/utils");
const Ticker = (props) => {
    const { symbol } = props;
    const data = (0, hooks_1.useTickerStream)(symbol);
    const [leadingVisible, setLeadingVisible] = (0, react_1.useState)(false);
    const [tailingVisible, setTailingVisible] = (0, react_1.useState)(false);
    const { base, quote } = (0, symbolProvider_1.useSymbolContext)();
    const containerRef = (0, react_1.useRef)(null);
    const leadingElementRef = (0, react_1.useRef)(null);
    const tailingElementRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        const intersectionObserver = new IntersectionObserver((entries) => {
            for (let index = 0; index < entries.length; index++) {
                const item = entries[index];
                if (item) {
                    if (item.target === leadingElementRef.current) {
                        setLeadingVisible(!item.isIntersecting);
                    }
                    if (item.target === tailingElementRef.current) {
                        setTailingVisible(!item.isIntersecting);
                    }
                }
            }
        });
        if (leadingElementRef.current) {
            intersectionObserver.observe(leadingElementRef.current);
        }
        if (tailingElementRef.current) {
            intersectionObserver.observe(tailingElementRef.current);
        }
        return () => {
            intersectionObserver.disconnect();
        };
    }, []);
    const onScollButtonClick = (direction) => {
        if (direction === "left")
            containerRef.current?.scrollBy({ left: -100, behavior: "smooth" });
        else
            containerRef.current?.scrollBy({ left: 100, behavior: "smooth" });
    };
    return ((0, jsx_runtime_1.jsx)(defaultStaticStyle_1.StatisticStyleProvider, { labelClassName: "orderly-text-4xs orderly-text-base-contrast-54 orderly-break-normal orderly-whitespace-nowrap", valueClassName: "orderly-text-2xs orderly-text-base-contrast-80 orderly-tabular-nums orderly-font-semibold", children: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-relative orderly-overflow-hidden", children: [(0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-space-x-5 orderly-relative orderly-items-center orderly-h-full orderly-overflow-x-auto orderly-hide-scrollbar", ref: containerRef, children: [(0, jsx_runtime_1.jsx)("div", { ref: leadingElementRef, children: (0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { className: "orderly-font-semibold", children: data?.["24h_close"] }) }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "24h change", value: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-space-x-1", children: [(0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { coloring: true, children: data?.["24h_change"] }), (0, jsx_runtime_1.jsx)("span", { className: "orderly-text-base-contrast-54", children: "/" }), (0, jsx_runtime_1.jsx)(text_1.Numeral, { coloring: true, rule: "percentages", children: data?.change || 0 })] }) }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Mark", value: (0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { children: data?.mark_price }), rule: "price", hint: "Price for the computation of unrealized PnL and liquidation." }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Index", value: (0, jsx_runtime_1.jsx)(numeralWithCtx_1.NumeralWithCtx, { children: data?.index_price }), 
                            // value={data?.index_price}
                            rule: "price", hint: "Average of the last prices across other exchanges." }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { hint: "24 hour total trading volume on the Orderly Network.", label: (0, jsx_runtime_1.jsxs)("div", { className: "orderly-flex orderly-items-center", children: [(0, jsx_runtime_1.jsx)(icon_1.OrderlyIcon, { size: 14, className: "orderly-mr-[6px]" }), (0, jsx_runtime_1.jsx)("div", { children: "24h volume" })] }), value: (0, jsx_runtime_1.jsx)(text_1.Numeral, { rule: "human", children: data?.["24h_amount"] }) }), (0, jsx_runtime_1.jsx)(fundingRate_1.MemoizedCompnent, { symbol: props.symbol }), (0, jsx_runtime_1.jsx)(statistic_1.Statistic, { label: "Open interest", value: (0, jsx_runtime_1.jsx)(text_1.Numeral, { rule: "human", unit: quote, children: new utils_1.Decimal(data?.open_interest ?? 0)
                                    .mul(data?.index_price ?? 0)
                                    .toDecimalPlaces(2)
                                    .valueOf() }), rule: "price", hint: "Total size of positions per side." }), (0, jsx_runtime_1.jsx)("div", { ref: tailingElementRef, className: "orderly-pr-[20px]" })] }), (0, jsx_runtime_1.jsx)(tickerMask_1.TickerMask, { leading: true, visible: leadingVisible, onClick: onScollButtonClick }), (0, jsx_runtime_1.jsx)(tickerMask_1.TickerMask, { tailing: true, visible: tailingVisible, onClick: onScollButtonClick })] }) }));
};
exports.Ticker = Ticker;
//# sourceMappingURL=ticker.js.map