"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearOrderEntrySessionData = exports.setEntrySessionStorage = exports.getEntrySessionStorageInfo = void 0;
const hooks_1 = require("@orderly.network/hooks");
const types_1 = require("@orderly.network/types");
function readValue(key, initialValue) {
    // Prevent build error "window is undefined" but keep keep working
    if (typeof window === "undefined") {
        return initialValue;
    }
    try {
        const item = window.sessionStorage.getItem(key);
        return item ? (0, hooks_1.parseJSON)(item) : initialValue;
    }
    catch (error) {
        console.warn(`Error reading sessionStorage key “${key}”:`, error);
        return initialValue;
    }
}
function getEntrySessionStorageInfo() {
    const orderType = readValue("order_type_key", types_1.OrderType.LIMIT);
    const reduceOnly = readValue("reduce_only_key", false);
    const orderSide = readValue("side_key", types_1.OrderSide.BUY);
    const orderTypeExt = readValue("order_type_ext_key", undefined);
    const sessionOrderEntry = readValue("order_entry_info", {
        "order_price": "",
        "order_quantity": "",
        "trigger_price": "",
    });
    return {
        orderType,
        reduceOnly,
        orderSide,
        orderTypeExt,
        sessionOrderEntry,
    };
}
exports.getEntrySessionStorageInfo = getEntrySessionStorageInfo;
function setEntrySessionStorage(key, value) {
    const keys = [
        "order_type",
        "reduce_only",
        "side",
        "order_type_ext",
    ];
    if (keys.includes(key)) {
        sessionStorage.setItem(`${key}_key`, JSON.stringify(value));
    }
    const include = ["order_price", "order_quantity", "trigger_price"].includes(key);
    if (include) {
        const sessionOrderEntry = readValue("order_entry_info", {
            "order_price": "",
            "order_quantity": "",
            "trigger_price": "",
        });
        sessionOrderEntry[key] = value;
        sessionStorage.setItem("order_entry_info", JSON.stringify(sessionOrderEntry));
    }
}
exports.setEntrySessionStorage = setEntrySessionStorage;
function clearOrderEntrySessionData() {
    setEntrySessionStorage("order_price", {
        "order_price": "",
        "order_quantity": "",
        "trigger_price": "",
    });
}
exports.clearOrderEntrySessionData = clearOrderEntrySessionData;
//# sourceMappingURL=entrySessionStorageUtils.js.map