"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MyOrderEntry = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const orderEntry_1 = require("../../../../../block/orderEntry");
const react_1 = require("react");
const hooks_1 = require("@orderly.network/hooks");
const types_1 = require("@orderly.network/types");
const assetsProvider_1 = require("../../../../../provider/assetsProvider");
const entrySessionStorageUtils_1 = require("./entrySessionStorageUtils");
const MyOrderEntry = (props) => {
    const { symbol } = props;
    const { onDeposit } = (0, react_1.useContext)(assetsProvider_1.AssetsContext);
    const { state } = (0, hooks_1.useAccount)();
    const ee = (0, hooks_1.useEventEmitter)();
    const containerRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        const observer = new ResizeObserver(function (entries) {
            if (Array.isArray(entries) && entries[0]) {
                ee.emit("dom:orderEntry:resize", {
                    height: entries[0].contentBoxSize[0].blockSize,
                    width: entries[0].contentBoxSize[0].inlineSize,
                });
            }
        });
        observer.observe(containerRef.current);
        return () => {
            //
            if (containerRef.current) {
                observer.unobserve(containerRef.current);
            }
        };
    }, []);
    /// local storage hidden check box
    const [visibleQuantity, setVisibleQuantity] = (0, hooks_1.useLocalStorage)("visible_quantity_key", 0);
    /// session storage
    const sessionData = (0, entrySessionStorageUtils_1.getEntrySessionStorageInfo)();
    const orderType = sessionData.orderType;
    const reduceOnly = sessionData.reduceOnly;
    const orderSide = sessionData.orderSide;
    const orderTypeExt = sessionData.orderTypeExt;
    const sessionOrderEntry = sessionData.sessionOrderEntry;
    const [order, setOrder] = (0, react_1.useState)({
        reduce_only: reduceOnly,
        side: orderSide,
        order_type: orderType,
        isStopOrder: orderType === types_1.OrderType.STOP_LIMIT || orderType === types_1.OrderType.STOP_MARKET,
        symbol,
        visible_quantity: visibleQuantity,
        order_type_ext: orderType === types_1.OrderType.LIMIT ? orderTypeExt : undefined,
        // timestamp: Date.now(),
        ...sessionOrderEntry,
    });
    // const [reduceOnly, setReduceOnly] = useState(false);
    const formState = (0, hooks_1.useOrderEntry)(order, {
        watchOrderbook: true,
    });
    (0, react_1.useEffect)(() => {
        setOrder((order) => ({
            ...order,
            order_price: "",
            order_quantity: "",
            trigger_price: "",
            symbol,
        }));
        (0, entrySessionStorageUtils_1.clearOrderEntrySessionData)();
    }, [symbol]);
    (0, react_1.useEffect)(() => {
        // console.log(
        //   "=======>>>>>>>>formState.formattedOrder",
        //   formState.formattedOrder.total,
        //   formState.formattedOrder.order_quantity
        // );
        order.order_quantity = formState.formattedOrder.order_quantity;
        order.total = formState.formattedOrder.total;
    }, [formState.formattedOrder.total, formState.formattedOrder.order_quantity]);
    return ((0, jsx_runtime_1.jsx)("div", { id: "orderly-order-entry", className: "orderly-pl-1", ref: containerRef, children: (0, jsx_runtime_1.jsx)(orderEntry_1.OrderEntry, { ...formState, showConfirm: true, 
            // side={side}
            symbol: symbol, onFieldChange: (field, value) => {
                console.log("=======>>>>>>>>field", field, value);
                /// save to local storage and refresh ui
                if (field === "visible_quantity") {
                    setVisibleQuantity(value);
                }
                /// save to session storage and not refresh ui
                (0, entrySessionStorageUtils_1.setEntrySessionStorage)(field, value);
                // if (field === "reduce_only") {
                //   setOrder((order) => ({
                //     ...order,
                //     order_quantity: "",
                //     order_price: "",
                //     [field]: value,
                //     // timestamp: Date.now(),
                //   }));
                // } else {
                setOrder((order) => ({
                    ...order,
                    [field]: value,
                    // timestamp: Date.now(),
                }));
                // }
            }, setValues: (values) => {
                setOrder((order) => ({
                    ...order,
                    ...values,
                }));
            }, 
            // onReduceOnlyChange={setReduceOnly}
            disabled: state.status < types_1.AccountStatusEnum.EnableTrading, onDeposit: onDeposit }) }));
};
exports.MyOrderEntry = MyOrderEntry;
//# sourceMappingURL=index.js.map