"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AssetsProvider = exports.AssetsContext = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const modal_1 = require("../modal");
const react_1 = require("react");
const hooks_1 = require("@orderly.network/hooks");
const toast_1 = require("../toast");
const depositAndwithdraw_1 = require("../block/depositAndwithdraw/depositAndwithdraw");
const utils_1 = require("@orderly.network/utils");
const types_1 = require("@orderly.network/types");
exports.AssetsContext = (0, react_1.createContext)({});
const AssetsProvider = (props) => {
    const account = (0, hooks_1.useAccountInstance)();
    const matches = (0, hooks_1.useMediaQuery)(types_1.MEDIA_TABLET);
    const openDepositAndWithdraw = (0, react_1.useCallback)(async (viewName) => {
        let result;
        if (matches) {
            result = await modal_1.modal.show(depositAndwithdraw_1.DepositAndWithdrawWithSheet, {
                activeTab: viewName,
            });
        }
        else {
            result = await modal_1.modal.show(depositAndwithdraw_1.DepositAndWithdrawWithDialog, {
                activeTab: viewName,
            });
        }
        return result;
    }, [matches]);
    const onDeposit = (0, react_1.useCallback)(async () => {
        return openDepositAndWithdraw("deposit");
    }, [matches]);
    const ee = (0, hooks_1.useEventEmitter)();
    const onWithdraw = (0, react_1.useCallback)(async () => {
        return openDepositAndWithdraw("withdraw");
    }, [matches]);
    const onSettle = (0, react_1.useCallback)(async () => {
        return account
            .settle()
            .catch((e) => {
            if (e.code == -1104) {
                toast_1.toast.error("Settlement is only allowed once every 10 minutes. Please try again later.");
                return Promise.reject(e);
            }
        })
            .then((res) => {
            toast_1.toast.success("Settlement requested");
            return Promise.resolve(res);
        });
    }, []);
    const [visible, setVisible] = (0, hooks_1.useLocalStorage)("orderly_assets_visible", true);
    const toggleVisible = (0, react_1.useCallback)(() => {
        // @ts-ignore
        setVisible((visible) => {
            return !visible;
        });
    }, [visible]);
    (0, hooks_1.useWalletSubscription)({
        onMessage: (data) => {
            //
            const { side, transStatus } = data;
            if (transStatus === "COMPLETED") {
                let msg = `${(0, utils_1.capitalizeString)(side)} completed`;
                toast_1.toast.success(msg);
            }
            else if (transStatus === "FAILED") {
                let msg = `${(0, utils_1.capitalizeString)(side)} failed`;
                toast_1.toast.error(msg);
            }
            ee.emit("wallet:changed", data);
        },
    });
    (0, hooks_1.useSettleSubscription)({
        onMessage: (data) => {
            const { status } = data;
            // console.log("settle ws: ", data);
            switch (status) {
                case "COMPLETED":
                    toast_1.toast.success("Settlement completed");
                    break;
                case "FAILED":
                    toast_1.toast.error("Settlement failed");
                    break;
                default:
                    break;
            }
        },
    });
    return ((0, jsx_runtime_1.jsx)(exports.AssetsContext.Provider, { value: {
            onDeposit,
            onWithdraw,
            onSettle,
            visible,
            toggleVisible,
            // getBalance,
        }, children: props.children }));
};
exports.AssetsProvider = AssetsProvider;
//# sourceMappingURL=assetsProvider.js.map