"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.selectVariants = exports.Select = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const class_variance_authority_1 = require("class-variance-authority");
const react_1 = require("react");
const css_1 = require("../utils/css");
const icon_1 = require("../icon");
const dropdown_1 = require("../dropdown/dropdown");
const react_2 = __importDefault(require("react"));
const selectVariants = (0, class_variance_authority_1.cva)(["orderly-rounded orderly-transition-colors orderly-bg-base-600"], {
    variants: {
        size: {
            small: "orderly-px-2 orderly-h-[28px]",
            default: "orderly-px-2 orderly-py-1 orderly-h-[40px]",
            large: "orderly-px-6 orderly-py-3",
        },
        fullWidth: {
            true: "orderly-w-full",
        },
        color: {
            // primary: "text-primary",
            default: "orderly-text-base-contract",
            buy: "orderly-text-trade-profit",
            sell: "orderly-text-trade-loss",
        },
        disabled: {
            true: "orderly-opacity-50 orderly-cursor-not-allowed",
        },
    },
    defaultVariants: {
        size: "default",
    },
});
exports.selectVariants = selectVariants;
const Select = ({ className, contentClassName, size, disabled, color, fullWidth, ...props }) => {
    const [open, setOpen] = (0, react_1.useState)(false);
    const [width, setWidth] = (0, react_1.useState)(0);
    // const uid = useId();
    const label = (0, react_1.useMemo)(() => {
        if (typeof props.value !== "undefined") {
            const activeItem = props.options?.find((item) => item.value === props.value);
            if (activeItem)
                return activeItem.label;
        }
        return props.value || props.label || props.placeholder;
    }, [props.value]);
    const options = (0, react_1.useMemo)(() => {
        return props.options || [];
    }, [props]);
    const triggerRef = react_2.default.useRef(null);
    // const containerRef = React.useRef<HTMLDivElement | null>(null);
    (0, react_1.useEffect)(() => {
        if (triggerRef.current) {
            setWidth(triggerRef.current.offsetWidth);
        }
    }, []);
    (0, react_1.useEffect)(() => {
        if (triggerRef.current) {
            const resizeObserver = new ResizeObserver(entries => {
                if (triggerRef.current) {
                    setWidth(triggerRef.current.offsetWidth);
                }
            });
            resizeObserver.observe(triggerRef.current);
            return () => {
                if (triggerRef.current) {
                    resizeObserver.unobserve(triggerRef.current);
                }
            };
        }
    }, []);
    return ((0, jsx_runtime_1.jsxs)(dropdown_1.DropdownMenu, { open: open, onOpenChange: setOpen, modal: false, children: [(0, jsx_runtime_1.jsx)(dropdown_1.DropdownMenuTrigger, { asChild: true, children: (0, jsx_runtime_1.jsxs)("div", { ref: triggerRef, className: (0, css_1.cn)("orderly-inline-flex orderly-flex-row orderly-items-center orderly-rounded focus-within:orderly-outline orderly-space-x-2 orderly-cursor-pointer", selectVariants({
                        size,
                        disabled: disabled || options.length === 0,
                        className,
                        color,
                        fullWidth,
                    }), open && "orderly-bg-base-600"), children: [(0, jsx_runtime_1.jsx)("div", { className: "orderly-flex-1 orderly-text-3xs desktop:orderly-text-2xs orderly-text-inherit", children: typeof label !== "undefined" && (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: label }) }), (0, jsx_runtime_1.jsx)(icon_1.ArrowIcon, { size: 12, className: (0, class_variance_authority_1.cx)("orderly-transition-transform", open && "orderly-rotate-180") })] }) }), (0, jsx_runtime_1.jsx)(dropdown_1.DropdownMenuContent
            // @ts-ignore
            // container={containerRef.current}
            , { 
                // @ts-ignore
                // container={containerRef.current}
                align: "start", style: { minWidth: `${width}px` }, className: contentClassName, children: props.options?.map((option, index) => {
                    return ((0, jsx_runtime_1.jsx)(dropdown_1.DropdownMenuItem
                    // @ts-ignore
                    , { 
                        // @ts-ignore
                        textValue: option.value, className: (0, css_1.cn)("orderly-text-base-contrast/60 hover:orderly-bg-base-700 orderly-text-3xs desktop:orderly-text-2xs", option.value === props.value &&
                            (color === "buy"
                                ? "orderly-text-trade-profit"
                                : (color === "sell" ? "orderly-text-trade-loss" : "orderly-text-base-contract"))), onSelect: (evnet) => {
                            // @ts-ignore
                            props.onChange?.(option.value);
                        }, children: option.label }, index));
                }) })] }));
};
exports.Select = Select;
//# sourceMappingURL=select.js.map