"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Statistic = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const css_1 = require("../utils/css");
const text_1 = require("../text");
const defaultStaticStyle_1 = require("./defaultStaticStyle");
const tooltip_1 = require("../tooltip");
const alignClasses = {
    left: "orderly-text-left",
    right: "orderly-text-right",
    center: "orderly-text-center",
};
const coloringClasses = {
    lose: "orderly-text-trade-loss",
    profit: "orderly-text-trade-profit",
    neutral: "orderly-text-base-contrast/50",
};
const Statistic = (props) => {
    const { align = "left", rule: rule, asChild } = props;
    const { labelClassName, valueClassName } = (0, react_1.useContext)(defaultStaticStyle_1.StatisticStyleContext);
    const labelElement = (0, react_1.useMemo)(() => {
        if (typeof props.label === "string") {
            return props.label;
        }
        return props.label;
    }, [props.label]);
    // lose, profit, neutral
    const colorClassName = (0, react_1.useMemo)(() => {
        if (!props.coloring)
            return "";
        if (typeof props.value !== "number" && typeof props.value !== "string")
            return "";
        // if (props.value === 0) return coloringClasses.neutral;
        const num = Number(props.value);
        if (Number.isNaN(num)) {
            // console.warn(`if coloring, value is need number: ${props.value}`);
            return "";
        }
        if (num === 0)
            return coloringClasses.neutral;
        if (num < 0)
            return coloringClasses.lose;
        // const firstChar = String(props.value).charAt(0);
        // if (firstChar === "-") return coloringClasses.lose;
        return coloringClasses.profit;
    }, [props.coloring, props.value]);
    // ---------- create value element ----------
    const valueElement = (0, react_1.useMemo)(() => {
        if (typeof props.value === "string" || typeof props.value === "number") {
            if (rule === "price" || rule === "percentages") {
                return ((0, jsx_runtime_1.jsx)(text_1.Numeral, { rule: rule, precision: props.precision, visible: props.visible, children: props.value }));
            }
            // "date" | "address" | "text" | "symbol"
            if (rule === "date" ||
                rule === "address" ||
                rule === "text" ||
                rule === "symbol" ||
                rule === "status") {
                return (0, jsx_runtime_1.jsx)(text_1.Text, { rule: rule, children: props.value });
            }
            return (0, jsx_runtime_1.jsx)("span", { children: props.value });
        }
        return props.value ?? "--";
    }, [props.value, rule, props.precision, props.visible]);
    let label;
    if (typeof props.hint === "undefined") {
        label = ((0, jsx_runtime_1.jsx)("div", { className: (0, css_1.cn)(labelClassName, props.labelClassName), children: labelElement }));
    }
    else {
        label = ((0, jsx_runtime_1.jsx)(tooltip_1.Tooltip, { content: props.hint, className: "orderly-max-w-[200px]", children: (0, jsx_runtime_1.jsx)("div", { className: (0, css_1.cn)(labelClassName, props.labelClassName), children: labelElement }) }));
    }
    return ((0, jsx_runtime_1.jsxs)("div", { className: (0, css_1.cn)(props.className, alignClasses[align], props.hint && "orderly-cursor-pointer hover:orderly-text-base-contrast"), children: [label, (0, jsx_runtime_1.jsx)("div", { className: (0, css_1.cn)(valueClassName, props.valueClassName, colorClassName), children: valueElement })] }));
};
exports.Statistic = Statistic;
//# sourceMappingURL=statistic.js.map