"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Table = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const thead_1 = require("./thead");
const css_1 = require("../utils/css");
const spinner_1 = require("../spinner");
const emptyView_1 = require("../listView/emptyView");
const colgroup_1 = require("./colgroup");
const tableContext_1 = require("./tableContext");
const hooks_1 = require("@orderly.network/hooks");
const fixedDivide_1 = require("./fixedDivide");
const tbody_1 = require("./tbody");
const Table = (props) => {
    const wrapRef = (0, react_1.useRef)(null);
    const { dataSource, columns, showMaskElement = true, ...rest } = props;
    // console.log("props sortable:: ", props.sortable);
    const maskElement = (0, react_1.useMemo)(() => {
        if (Array.isArray(props.dataSource) && props.dataSource?.length > 0) {
            return null;
        }
        let content = (0, jsx_runtime_1.jsx)(spinner_1.Spinner, {});
        if (props.dataSource?.length === 0 && !props.loading) {
            content = (0, jsx_runtime_1.jsx)(emptyView_1.EmptyView, {});
        }
        return ((0, jsx_runtime_1.jsx)("div", { className: "orderly-absolute orderly-w-full orderly-z-20 orderly-left-0 orderly-top-0 orderly-bottom-0 orderly-right-0 orderly-flex orderly-justify-center orderly-items-center orderly-bg-base-900/30 orderly-backdrop-blur-sm", children: content }));
    }, [props.dataSource, props.loading]);
    const needFixed = (0, react_1.useMemo)(() => {
        return props.columns.some((col) => col.fixed === "left" || col.fixed === "right");
    }, [props.columns]);
    const onScroll = (0, hooks_1.useDebouncedCallback)((scrollLeft) => {
        // console.log(scrollLeft);
        if (!wrapRef.current || !needFixed) {
            return;
        }
        if (scrollLeft > 0) {
            // setLeftFixed(true);
            wrapRef.current?.setAttribute("data-left", "fixed");
        }
        else {
            wrapRef.current?.setAttribute("data-left", "free");
        }
        if (
        // wrapRef.current.scrollWidth - wrapRef.current.scrollLeft === wrapRef.current.clientWidth
        wrapRef.current.scrollLeft + wrapRef.current.clientWidth >=
            wrapRef.current.scrollWidth) {
            wrapRef.current.setAttribute("data-right", "free");
        }
        else {
            wrapRef.current.setAttribute("data-right", "fixed");
        }
    }, 50);
    (0, react_1.useEffect)(() => {
        if (!wrapRef.current) {
            return;
        }
        onScroll(0);
        // use ResizeObserver observe wrapRef
        const resizeObserver = new ResizeObserver((entries) => {
            for (const entry of entries) {
                onScroll(entry.target.scrollLeft);
            }
        });
        resizeObserver.observe(wrapRef.current);
        return () => {
            resizeObserver.disconnect();
        };
    }, []);
    (0, react_1.useEffect)(() => {
        if (!wrapRef.current)
            return;
        const bodyBgColor = window.getComputedStyle(document.body).backgroundColor;
        // body.style.setProperty("--table-header-height", "48px");
        wrapRef.current.style.setProperty("--table-background-color", bodyBgColor);
    }, []);
    return ((0, jsx_runtime_1.jsxs)(tableContext_1.TableProvider, { columns: props.columns, dataSource: props.dataSource, canExpand: typeof props.expandRowRender === "function", children: [(0, jsx_runtime_1.jsxs)("div", { ref: wrapRef, className: (0, css_1.cn)("orderly-ui-table orderly-relative orderly-flex-col orderly-overflow-x-auto orderly-peer", props.loading && "orderly-overflow-hidden", props.className), style: { height: "calc(100% - 2px)" }, onScroll: (e) => onScroll(e.currentTarget.scrollLeft), children: [(0, jsx_runtime_1.jsx)(thead_1.TableHeader, { columns: props.columns, className: props.headerClassName, bordered: props.bordered, justified: props.justified }), (0, jsx_runtime_1.jsxs)("table", { className: (0, css_1.cn)("orderly-table-fixed orderly-border-collapse orderly-w-full"), children: [(0, jsx_runtime_1.jsx)(colgroup_1.ColGroup, { columns: props.columns }), (0, jsx_runtime_1.jsx)(tbody_1.TBody, { ...rest })] }), showMaskElement && maskElement] }), (0, jsx_runtime_1.jsx)(fixedDivide_1.FixedDivide, {})] }));
};
exports.Table = Table;
//# sourceMappingURL=table.js.map