"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Text = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const class_variance_authority_1 = require("class-variance-authority");
const css_1 = require("../utils/css");
const react_slot_1 = require("@radix-ui/react-slot");
const utils_1 = require("@orderly.network/utils");
const string_1 = require("../utils/string");
const types_1 = require("@orderly.network/types");
const textVariants = (0, class_variance_authority_1.cva)([], {
    variants: {
        variant: {},
        type: {
            primary: "orderly-text-primary",
            secondary: "orderly-text-secondary",
            tertiary: "orderly-text-tertiary",
            quaternary: "orderly-text-gray-300",
            warning: "orderly-text-warning",
            danger: "orderly-text-danger",
            success: "orderly-text-success",
            buy: "orderly-text-trade-profit",
            sell: "orderly-text-trade-loss",
        },
    },
});
const Text = (props) => {
    const { variant, rule, asChildren, type, className, children, symbolElement, surfix, formatString, ...rest } = props;
    const Comp = asChildren ? react_slot_1.Slot : "span";
    const content = (0, react_1.useMemo)(() => {
        if (typeof children === "undefined")
            return "--";
        if (typeof rule === "undefined" || rule === "text")
            return children;
        if (rule === "address") {
            const address = children;
            const [start, end] = props.range ?? [6, 4];
            const reg = new RegExp(`^(.{${start}})(.*)(.{${end}})$`);
            return `${address.replace(reg, "$1...$3")}`;
        }
        if (rule === "date") {
            // return new Date(children as string).toLocaleString();
            return (0, utils_1.dayjs)(children).format(formatString ?? "YYYY-MM-DD HH:mm:ss");
        }
        if (rule === "symbol") {
            const arr = children.split("_");
            if (typeof symbolElement !== "undefined") {
                if (symbolElement === "base") {
                    return arr[1];
                }
                return arr[2];
            }
            return `${arr[1]}-${arr[0]}`;
        }
        if (rule === "status") {
            const status = children;
            if (status === types_1.OrderStatus.NEW || status === types_1.OrderStatus.OPEN) {
                return "Pending";
            }
            const text = (0, string_1.firstLetterToUpperCase)(status);
            return text;
        }
        return children;
    }, [children, rule]);
    const contentWithSurfix = (0, react_1.useMemo)(() => {
        if (typeof surfix === "undefined")
            return content;
        return ((0, jsx_runtime_1.jsxs)("span", { className: "orderly-flex orderly-gap-1", children: [content, surfix] }));
    }, [content, surfix]);
    return ((0, jsx_runtime_1.jsx)(Comp, { ...rest, className: (0, css_1.cn)(textVariants({ variant, type, className })), children: contentWithSurfix }));
};
exports.Text = Text;
//# sourceMappingURL=text.js.map