"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumberReg = exports.parseNumber = void 0;
const utils_1 = require("@orderly.network/utils");
const parseNumber = (value, options = {}) => {
    let { rule, precision, tick, truncate, padding, abs } = options;
    if (Number.isNaN(value)) {
        return "--";
    }
    const dp = typeof precision !== "undefined"
        ? precision
        : tick
            ? (0, utils_1.getPrecisionByNumber)(tick)
            : 2;
    if (rule === "human") {
        return (0, utils_1.numberToHumanStyle)(typeof value === "number" ? value : Number(value), dp);
    }
    let d = new utils_1.Decimal(value);
    if (abs) {
        d = d.abs();
    }
    if (rule === "percentages") {
        return `${d.mul(100).toFixed(2)}%`;
    }
    let truncatedNum;
    if (truncate === "round") {
        if (padding) {
            truncatedNum = d.toFixed(dp, utils_1.Decimal.ROUND_HALF_EVEN);
        }
        else {
            truncatedNum = d.todp(dp, utils_1.Decimal.ROUND_HALF_EVEN).toString();
        }
    }
    else {
        if (padding) {
            truncatedNum = d.toFixed(dp);
        }
        else {
            truncatedNum = d.todp(dp).toString();
        }
    }
    if (rule === "price") {
        return (0, utils_1.commify)(truncatedNum);
    }
    if (truncatedNum?.includes("e")) {
        // If dp is omitted, the return value will be unrounded and in normal notation.
        // https://mikemcl.github.io/decimal.js/#toFixed
        return new utils_1.Decimal(truncatedNum)?.toFixed();
    }
    return truncatedNum;
};
exports.parseNumber = parseNumber;
exports.NumberReg = /^([0-9]{1,}[.]?[0-9]*)/;
//# sourceMappingURL=num.js.map